<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'beijo: pessoa, pessoa, pele clara e pele morena clara',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'beijo: pessoa, pessoa, pele clara e pele morena',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'beijo: pessoa, pessoa, pele clara e pele morena escura',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'beijo: pessoa, pessoa, pele clara e pele escura',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'beijo: pessoa, pessoa, pele morena clara e pele clara',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'beijo: pessoa, pessoa, pele morena clara e pele morena',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'beijo: pessoa, pessoa, pele morena clara e pele morena escura',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'beijo: pessoa, pessoa, pele morena clara e pele escura',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'beijo: pessoa, pessoa, pele morena e pele clara',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'beijo: pessoa, pessoa, pele morena e pele morena clara',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'beijo: pessoa, pessoa, pele morena e pele morena escura',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'beijo: pessoa, pessoa, pele morena e pele escura',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'beijo: pessoa, pessoa, pele morena escura e pele clara',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'beijo: pessoa, pessoa, pele morena escura e pele morena clara',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'beijo: pessoa, pessoa, pele morena escura e pele morena',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'beijo: pessoa, pessoa, pele morena escura e pele escura',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'beijo: pessoa, pessoa, pele escura e pele clara',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'beijo: pessoa, pessoa, pele escura e pele morena clara',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'beijo: pessoa, pessoa, pele escura e pele morena',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'beijo: pessoa, pessoa, pele escura e pele morena escura',
    '👨🏻‍❤‍💋‍👨🏻' => 'beijo: homem, homem e pele clara',
    '👨🏻‍❤‍💋‍👨🏼' => 'beijo: homem, homem, pele clara e pele morena clara',
    '👨🏻‍❤‍💋‍👨🏽' => 'beijo: homem, homem, pele clara e pele morena',
    '👨🏻‍❤‍💋‍👨🏾' => 'beijo: homem, homem, pele clara e pele morena escura',
    '👨🏻‍❤‍💋‍👨🏿' => 'beijo: homem, homem, pele clara e pele escura',
    '👨🏼‍❤‍💋‍👨🏻' => 'beijo: homem, homem, pele morena clara e pele clara',
    '👨🏼‍❤‍💋‍👨🏼' => 'beijo: homem, homem e pele morena clara',
    '👨🏼‍❤‍💋‍👨🏽' => 'beijo: homem, homem, pele morena clara e pele morena',
    '👨🏼‍❤‍💋‍👨🏾' => 'beijo: homem, homem, pele morena clara e pele morena escura',
    '👨🏼‍❤‍💋‍👨🏿' => 'beijo: homem, homem, pele morena clara e pele escura',
    '👨🏽‍❤‍💋‍👨🏻' => 'beijo: homem, homem, pele morena e pele clara',
    '👨🏽‍❤‍💋‍👨🏼' => 'beijo: homem, homem, pele morena e pele morena clara',
    '👨🏽‍❤‍💋‍👨🏽' => 'beijo: homem, homem e pele morena',
    '👨🏽‍❤‍💋‍👨🏾' => 'beijo: homem, homem, pele morena e pele morena escura',
    '👨🏽‍❤‍💋‍👨🏿' => 'beijo: homem, homem, pele morena e pele escura',
    '👨🏾‍❤‍💋‍👨🏻' => 'beijo: homem, homem, pele morena escura e pele clara',
    '👨🏾‍❤‍💋‍👨🏼' => 'beijo: homem, homem, pele morena escura e pele morena clara',
    '👨🏾‍❤‍💋‍👨🏽' => 'beijo: homem, homem, pele morena escura e pele morena',
    '👨🏾‍❤‍💋‍👨🏾' => 'beijo: homem, homem e pele morena escura',
    '👨🏾‍❤‍💋‍👨🏿' => 'beijo: homem, homem, pele morena escura e pele escura',
    '👨🏿‍❤‍💋‍👨🏻' => 'beijo: homem, homem, pele escura e pele clara',
    '👨🏿‍❤‍💋‍👨🏼' => 'beijo: homem, homem, pele escura e pele morena clara',
    '👨🏿‍❤‍💋‍👨🏽' => 'beijo: homem, homem, pele escura e pele morena',
    '👨🏿‍❤‍💋‍👨🏾' => 'beijo: homem, homem, pele escura e pele morena escura',
    '👨🏿‍❤‍💋‍👨🏿' => 'beijo: homem, homem e pele escura',
    '👩🏻‍❤‍💋‍👨🏻' => 'beijo: mulher, homem e pele clara',
    '👩🏻‍❤‍💋‍👨🏼' => 'beijo: mulher, homem, pele clara e pele morena clara',
    '👩🏻‍❤‍💋‍👨🏽' => 'beijo: mulher, homem, pele clara e pele morena',
    '👩🏻‍❤‍💋‍👨🏾' => 'beijo: mulher, homem, pele clara e pele morena escura',
    '👩🏻‍❤‍💋‍👨🏿' => 'beijo: mulher, homem, pele clara e pele escura',
    '👩🏼‍❤‍💋‍👨🏻' => 'beijo: mulher, homem, pele morena clara e pele clara',
    '👩🏼‍❤‍💋‍👨🏼' => 'beijo: mulher, homem e pele morena clara',
    '👩🏼‍❤‍💋‍👨🏽' => 'beijo: mulher, homem, pele morena clara e pele morena',
    '👩🏼‍❤‍💋‍👨🏾' => 'beijo: mulher, homem, pele morena clara e pele morena escura',
    '👩🏼‍❤‍💋‍👨🏿' => 'beijo: mulher, homem, pele morena clara e pele escura',
    '👩🏽‍❤‍💋‍👨🏻' => 'beijo: mulher, homem, pele morena e pele clara',
    '👩🏽‍❤‍💋‍👨🏼' => 'beijo: mulher, homem, pele morena e pele morena clara',
    '👩🏽‍❤‍💋‍👨🏽' => 'beijo: mulher, homem e pele morena',
    '👩🏽‍❤‍💋‍👨🏾' => 'beijo: mulher, homem, pele morena e pele morena escura',
    '👩🏽‍❤‍💋‍👨🏿' => 'beijo: mulher, homem, pele morena e pele escura',
    '👩🏾‍❤‍💋‍👨🏻' => 'beijo: mulher, homem, pele morena escura e pele clara',
    '👩🏾‍❤‍💋‍👨🏼' => 'beijo: mulher, homem, pele morena escura e pele morena clara',
    '👩🏾‍❤‍💋‍👨🏽' => 'beijo: mulher, homem, pele morena escura e pele morena',
    '👩🏾‍❤‍💋‍👨🏾' => 'beijo: mulher, homem e pele morena escura',
    '👩🏾‍❤‍💋‍👨🏿' => 'beijo: mulher, homem, pele morena escura e pele escura',
    '👩🏿‍❤‍💋‍👨🏻' => 'beijo: mulher, homem, pele escura e pele clara',
    '👩🏿‍❤‍💋‍👨🏼' => 'beijo: mulher, homem, pele escura e pele morena clara',
    '👩🏿‍❤‍💋‍👨🏽' => 'beijo: mulher, homem, pele escura e pele morena',
    '👩🏿‍❤‍💋‍👨🏾' => 'beijo: mulher, homem, pele escura e pele morena escura',
    '👩🏿‍❤‍💋‍👨🏿' => 'beijo: mulher, homem e pele escura',
    '👩🏻‍❤‍💋‍👩🏻' => 'beijo: mulher, mulher e pele clara',
    '👩🏻‍❤‍💋‍👩🏼' => 'beijo: mulher, mulher, pele clara e pele morena clara',
    '👩🏻‍❤‍💋‍👩🏽' => 'beijo: mulher, mulher, pele clara e pele morena',
    '👩🏻‍❤‍💋‍👩🏾' => 'beijo: mulher, mulher, pele clara e pele morena escura',
    '👩🏻‍❤‍💋‍👩🏿' => 'beijo: mulher, mulher, pele clara e pele escura',
    '👩🏼‍❤‍💋‍👩🏻' => 'beijo: mulher, mulher, pele morena clara e pele clara',
    '👩🏼‍❤‍💋‍👩🏼' => 'beijo: mulher, mulher e pele morena clara',
    '👩🏼‍❤‍💋‍👩🏽' => 'beijo: mulher, mulher, pele morena clara e pele morena',
    '👩🏼‍❤‍💋‍👩🏾' => 'beijo: mulher, mulher, pele morena clara e pele morena escura',
    '👩🏼‍❤‍💋‍👩🏿' => 'beijo: mulher, mulher, pele morena clara e pele escura',
    '👩🏽‍❤‍💋‍👩🏻' => 'beijo: mulher, mulher, pele morena e pele clara',
    '👩🏽‍❤‍💋‍👩🏼' => 'beijo: mulher, mulher, pele morena e pele morena clara',
    '👩🏽‍❤‍💋‍👩🏽' => 'beijo: mulher, mulher e pele morena',
    '👩🏽‍❤‍💋‍👩🏾' => 'beijo: mulher, mulher, pele morena e pele morena escura',
    '👩🏽‍❤‍💋‍👩🏿' => 'beijo: mulher, mulher, pele morena e pele escura',
    '👩🏾‍❤‍💋‍👩🏻' => 'beijo: mulher, mulher, pele morena escura e pele clara',
    '👩🏾‍❤‍💋‍👩🏼' => 'beijo: mulher, mulher, pele morena escura e pele morena clara',
    '👩🏾‍❤‍💋‍👩🏽' => 'beijo: mulher, mulher, pele morena escura e pele morena',
    '👩🏾‍❤‍💋‍👩🏾' => 'beijo: mulher, mulher e pele morena escura',
    '👩🏾‍❤‍💋‍👩🏿' => 'beijo: mulher, mulher, pele morena escura e pele escura',
    '👩🏿‍❤‍💋‍👩🏻' => 'beijo: mulher, mulher, pele escura e pele clara',
    '👩🏿‍❤‍💋‍👩🏼' => 'beijo: mulher, mulher, pele escura e pele morena clara',
    '👩🏿‍❤‍💋‍👩🏽' => 'beijo: mulher, mulher, pele escura e pele morena',
    '👩🏿‍❤‍💋‍👩🏾' => 'beijo: mulher, mulher, pele escura e pele morena escura',
    '👩🏿‍❤‍💋‍👩🏿' => 'beijo: mulher, mulher e pele escura',
    '🧑🏻‍🫯‍🧑🏼' => 'pessoas lutando: pele clara e pele morena clara',
    '🧑🏻‍🫯‍🧑🏽' => 'pessoas lutando: pele clara e pele morena',
    '🧑🏻‍🫯‍🧑🏾' => 'pessoas lutando: pele clara e pele morena escura',
    '🧑🏻‍🫯‍🧑🏿' => 'pessoas lutando: pele clara e pele escura',
    '🧑🏼‍🫯‍🧑🏻' => 'pessoas lutando: pele morena clara e pele clara',
    '🧑🏼‍🫯‍🧑🏽' => 'pessoas lutando: pele morena clara e pele morena',
    '🧑🏼‍🫯‍🧑🏾' => 'pessoas lutando: pele morena clara e pele morena escura',
    '🧑🏼‍🫯‍🧑🏿' => 'pessoas lutando: pele morena clara e pele escura',
    '🧑🏽‍🫯‍🧑🏻' => 'pessoas lutando: pele morena e pele clara',
    '🧑🏽‍🫯‍🧑🏼' => 'pessoas lutando: pele morena e pele morena clara',
    '🧑🏽‍🫯‍🧑🏾' => 'pessoas lutando: pele morena e pele morena escura',
    '🧑🏽‍🫯‍🧑🏿' => 'pessoas lutando: pele morena e pele escura',
    '🧑🏾‍🫯‍🧑🏻' => 'pessoas lutando: pele morena escura e pele clara',
    '🧑🏾‍🫯‍🧑🏼' => 'pessoas lutando: pele morena escura e pele morena clara',
    '🧑🏾‍🫯‍🧑🏽' => 'pessoas lutando: pele morena escura e pele morena',
    '🧑🏾‍🫯‍🧑🏿' => 'pessoas lutando: pele morena escura e pele escura',
    '🧑🏿‍🫯‍🧑🏻' => 'pessoas lutando: pele escura e pele clara',
    '🧑🏿‍🫯‍🧑🏼' => 'pessoas lutando: pele escura e pele morena clara',
    '🧑🏿‍🫯‍🧑🏽' => 'pessoas lutando: pele escura e pele morena',
    '🧑🏿‍🫯‍🧑🏾' => 'pessoas lutando: pele escura e pele morena escura',
    '🧑🏻‍❤‍🧑🏼' => 'casal apaixonado: pessoa, pessoa, pele clara e pele morena clara',
    '🧑🏻‍❤‍🧑🏽' => 'casal apaixonado: pessoa, pessoa, pele clara e pele morena',
    '🧑🏻‍❤‍🧑🏾' => 'casal apaixonado: pessoa, pessoa, pele clara e pele morena escura',
    '🧑🏻‍❤‍🧑🏿' => 'casal apaixonado: pessoa, pessoa, pele clara e pele escura',
    '🧑🏼‍❤‍🧑🏻' => 'casal apaixonado: pessoa, pessoa, pele morena clara e pele clara',
    '🧑🏼‍❤‍🧑🏽' => 'casal apaixonado: pessoa, pessoa, pele morena clara e pele morena',
    '🧑🏼‍❤‍🧑🏾' => 'casal apaixonado: pessoa, pessoa, pele morena clara e pele morena escura',
    '🧑🏼‍❤‍🧑🏿' => 'casal apaixonado: pessoa, pessoa, pele morena clara e pele escura',
    '🧑🏽‍❤‍🧑🏻' => 'casal apaixonado: pessoa, pessoa, pele morena e pele clara',
    '🧑🏽‍❤‍🧑🏼' => 'casal apaixonado: pessoa, pessoa, pele morena e pele morena clara',
    '🧑🏽‍❤‍🧑🏾' => 'casal apaixonado: pessoa, pessoa, pele morena e pele morena escura',
    '🧑🏽‍❤‍🧑🏿' => 'casal apaixonado: pessoa, pessoa, pele morena e pele escura',
    '🧑🏾‍❤‍🧑🏻' => 'casal apaixonado: pessoa, pessoa, pele morena escura e pele clara',
    '🧑🏾‍❤‍🧑🏼' => 'casal apaixonado: pessoa, pessoa, pele morena escura e pele morena clara',
    '🧑🏾‍❤‍🧑🏽' => 'casal apaixonado: pessoa, pessoa, pele morena escura e pele morena',
    '🧑🏾‍❤‍🧑🏿' => 'casal apaixonado: pessoa, pessoa, pele morena escura e pele escura',
    '🧑🏿‍❤‍🧑🏻' => 'casal apaixonado: pessoa, pessoa, pele escura e pele clara',
    '🧑🏿‍❤‍🧑🏼' => 'casal apaixonado: pessoa, pessoa, pele escura e pele morena clara',
    '🧑🏿‍❤‍🧑🏽' => 'casal apaixonado: pessoa, pessoa, pele escura e pele morena',
    '🧑🏿‍❤‍🧑🏾' => 'casal apaixonado: pessoa, pessoa, pele escura e pele morena escura',
    '🧑🏻‍🐰‍🧑🏼' => 'pessoas com orelhas de coelho: pele clara e pele morena clara',
    '🧑🏻‍🐰‍🧑🏽' => 'pessoas com orelhas de coelho: pele clara e pele morena',
    '🧑🏻‍🐰‍🧑🏾' => 'pessoas com orelhas de coelho: pele clara e pele morena escura',
    '🧑🏻‍🐰‍🧑🏿' => 'pessoas com orelhas de coelho: pele clara e pele escura',
    '🧑🏼‍🐰‍🧑🏻' => 'pessoas com orelhas de coelho: pele morena clara e pele clara',
    '🧑🏼‍🐰‍🧑🏽' => 'pessoas com orelhas de coelho: pele morena clara e pele morena',
    '🧑🏼‍🐰‍🧑🏾' => 'pessoas com orelhas de coelho: pele morena clara e pele morena escura',
    '🧑🏼‍🐰‍🧑🏿' => 'pessoas com orelhas de coelho: pele morena clara e pele escura',
    '🧑🏽‍🐰‍🧑🏻' => 'pessoas com orelhas de coelho: pele morena e pele clara',
    '🧑🏽‍🐰‍🧑🏼' => 'pessoas com orelhas de coelho: pele morena e pele morena clara',
    '🧑🏽‍🐰‍🧑🏾' => 'pessoas com orelhas de coelho: pele morena e pele morena escura',
    '🧑🏽‍🐰‍🧑🏿' => 'pessoas com orelhas de coelho: pele morena e pele escura',
    '🧑🏾‍🐰‍🧑🏻' => 'pessoas com orelhas de coelho: pele morena escura e pele clara',
    '🧑🏾‍🐰‍🧑🏼' => 'pessoas com orelhas de coelho: pele morena escura e pele morena clara',
    '🧑🏾‍🐰‍🧑🏽' => 'pessoas com orelhas de coelho: pele morena escura e pele morena',
    '🧑🏾‍🐰‍🧑🏿' => 'pessoas com orelhas de coelho: pele morena escura e pele escura',
    '🧑🏿‍🐰‍🧑🏻' => 'pessoas com orelhas de coelho: pele escura e pele clara',
    '🧑🏿‍🐰‍🧑🏼' => 'pessoas com orelhas de coelho: pele escura e pele morena clara',
    '🧑🏿‍🐰‍🧑🏽' => 'pessoas com orelhas de coelho: pele escura e pele morena',
    '🧑🏿‍🐰‍🧑🏾' => 'pessoas com orelhas de coelho: pele escura e pele morena escura',
    '👨🏻‍🫯‍👨🏼' => 'homens lutando: pele clara e pele morena clara',
    '👨🏻‍🫯‍👨🏽' => 'homens lutando: pele clara e pele morena',
    '👨🏻‍🫯‍👨🏾' => 'homens lutando: pele clara e pele morena escura',
    '👨🏻‍🫯‍👨🏿' => 'homens lutando: pele clara e pele escura',
    '👨🏼‍🫯‍👨🏻' => 'homens lutando: pele morena clara e pele clara',
    '👨🏼‍🫯‍👨🏽' => 'homens lutando: pele morena clara e pele morena',
    '👨🏼‍🫯‍👨🏾' => 'homens lutando: pele morena clara e pele morena escura',
    '👨🏼‍🫯‍👨🏿' => 'homens lutando: pele morena clara e pele escura',
    '👨🏽‍🫯‍👨🏻' => 'homens lutando: pele morena e pele clara',
    '👨🏽‍🫯‍👨🏼' => 'homens lutando: pele morena e pele morena clara',
    '👨🏽‍🫯‍👨🏾' => 'homens lutando: pele morena e pele morena escura',
    '👨🏽‍🫯‍👨🏿' => 'homens lutando: pele morena e pele escura',
    '👨🏾‍🫯‍👨🏻' => 'homens lutando: pele morena escura e pele clara',
    '👨🏾‍🫯‍👨🏼' => 'homens lutando: pele morena escura e pele morena clara',
    '👨🏾‍🫯‍👨🏽' => 'homens lutando: pele morena escura e pele morena',
    '👨🏾‍🫯‍👨🏿' => 'homens lutando: pele morena escura e pele escura',
    '👨🏿‍🫯‍👨🏻' => 'homens lutando: pele escura e pele clara',
    '👨🏿‍🫯‍👨🏼' => 'homens lutando: pele escura e pele morena clara',
    '👨🏿‍🫯‍👨🏽' => 'homens lutando: pele escura e pele morena',
    '👨🏿‍🫯‍👨🏾' => 'homens lutando: pele escura e pele morena escura',
    '👨🏻‍❤‍👨🏻' => 'casal apaixonado: homem, homem e pele clara',
    '👨🏻‍❤‍👨🏼' => 'casal apaixonado: homem, homem, pele clara e pele morena clara',
    '👨🏻‍❤‍👨🏽' => 'casal apaixonado: homem, homem, pele clara e pele morena',
    '👨🏻‍❤‍👨🏾' => 'casal apaixonado: homem, homem, pele clara e pele morena escura',
    '👨🏻‍❤‍👨🏿' => 'casal apaixonado: homem, homem, pele clara e pele escura',
    '👨🏼‍❤‍👨🏻' => 'casal apaixonado: homem, homem, pele morena clara e pele clara',
    '👨🏼‍❤‍👨🏼' => 'casal apaixonado: homem, homem e pele morena clara',
    '👨🏼‍❤‍👨🏽' => 'casal apaixonado: homem, homem, pele morena clara e pele morena',
    '👨🏼‍❤‍👨🏾' => 'casal apaixonado: homem, homem, pele morena clara e pele morena escura',
    '👨🏼‍❤‍👨🏿' => 'casal apaixonado: homem, homem, pele morena clara e pele escura',
    '👨🏽‍❤‍👨🏻' => 'casal apaixonado: homem, homem, pele morena e pele clara',
    '👨🏽‍❤‍👨🏼' => 'casal apaixonado: homem, homem, pele morena e pele morena clara',
    '👨🏽‍❤‍👨🏽' => 'casal apaixonado: homem, homem e pele morena',
    '👨🏽‍❤‍👨🏾' => 'casal apaixonado: homem, homem, pele morena e pele morena escura',
    '👨🏽‍❤‍👨🏿' => 'casal apaixonado: homem, homem, pele morena e pele escura',
    '👨🏾‍❤‍👨🏻' => 'casal apaixonado: homem, homem, pele morena escura e pele clara',
    '👨🏾‍❤‍👨🏼' => 'casal apaixonado: homem, homem, pele morena escura e pele morena clara',
    '👨🏾‍❤‍👨🏽' => 'casal apaixonado: homem, homem, pele morena escura e pele morena',
    '👨🏾‍❤‍👨🏾' => 'casal apaixonado: homem, homem e pele morena escura',
    '👨🏾‍❤‍👨🏿' => 'casal apaixonado: homem, homem, pele morena escura e pele escura',
    '👨🏿‍❤‍👨🏻' => 'casal apaixonado: homem, homem, pele escura e pele clara',
    '👨🏿‍❤‍👨🏼' => 'casal apaixonado: homem, homem, pele escura e pele morena clara',
    '👨🏿‍❤‍👨🏽' => 'casal apaixonado: homem, homem, pele escura e pele morena',
    '👨🏿‍❤‍👨🏾' => 'casal apaixonado: homem, homem, pele escura e pele morena escura',
    '👨🏿‍❤‍👨🏿' => 'casal apaixonado: homem, homem e pele escura',
    '👨🏻‍🐰‍👨🏼' => 'homens com orelhas de coelho: pele clara e pele morena clara',
    '👨🏻‍🐰‍👨🏽' => 'homens com orelhas de coelho: pele clara e pele morena',
    '👨🏻‍🐰‍👨🏾' => 'homens com orelhas de coelho: pele clara e pele morena escura',
    '👨🏻‍🐰‍👨🏿' => 'homens com orelhas de coelho: pele clara e pele escura',
    '👨🏼‍🐰‍👨🏻' => 'homens com orelhas de coelho: pele morena clara e pele clara',
    '👨🏼‍🐰‍👨🏽' => 'homens com orelhas de coelho: pele morena clara e pele morena',
    '👨🏼‍🐰‍👨🏾' => 'homens com orelhas de coelho: pele morena clara e pele morena escura',
    '👨🏼‍🐰‍👨🏿' => 'homens com orelhas de coelho: pele morena clara e pele escura',
    '👨🏽‍🐰‍👨🏻' => 'homens com orelhas de coelho: pele morena e pele clara',
    '👨🏽‍🐰‍👨🏼' => 'homens com orelhas de coelho: pele morena e pele morena clara',
    '👨🏽‍🐰‍👨🏾' => 'homens com orelhas de coelho: pele morena e pele morena escura',
    '👨🏽‍🐰‍👨🏿' => 'homens com orelhas de coelho: pele morena e pele escura',
    '👨🏾‍🐰‍👨🏻' => 'homens com orelhas de coelho: pele morena escura e pele clara',
    '👨🏾‍🐰‍👨🏼' => 'homens com orelhas de coelho: pele morena escura e pele morena clara',
    '👨🏾‍🐰‍👨🏽' => 'homens com orelhas de coelho: pele morena escura e pele morena',
    '👨🏾‍🐰‍👨🏿' => 'homens com orelhas de coelho: pele morena escura e pele escura',
    '👨🏿‍🐰‍👨🏻' => 'homens com orelhas de coelho: pele escura e pele clara',
    '👨🏿‍🐰‍👨🏼' => 'homens com orelhas de coelho: pele escura e pele morena clara',
    '👨🏿‍🐰‍👨🏽' => 'homens com orelhas de coelho: pele escura e pele morena',
    '👨🏿‍🐰‍👨🏾' => 'homens com orelhas de coelho: pele escura e pele morena escura',
    '👩🏻‍🫯‍👩🏼' => 'mulheres lutando: pele clara e pele morena clara',
    '👩🏻‍🫯‍👩🏽' => 'mulheres lutando: pele clara e pele morena',
    '👩🏻‍🫯‍👩🏾' => 'mulheres lutando: pele clara e pele morena escura',
    '👩🏻‍🫯‍👩🏿' => 'mulheres lutando: pele clara e pele escura',
    '👩🏼‍🫯‍👩🏻' => 'mulheres lutando: pele morena clara e pele clara',
    '👩🏼‍🫯‍👩🏽' => 'mulheres lutando: pele morena clara e pele morena',
    '👩🏼‍🫯‍👩🏾' => 'mulheres lutando: pele morena clara e pele morena escura',
    '👩🏼‍🫯‍👩🏿' => 'mulheres lutando: pele morena clara e pele escura',
    '👩🏽‍🫯‍👩🏻' => 'mulheres lutando: pele morena e pele clara',
    '👩🏽‍🫯‍👩🏼' => 'mulheres lutando: pele morena e pele morena clara',
    '👩🏽‍🫯‍👩🏾' => 'mulheres lutando: pele morena e pele morena escura',
    '👩🏽‍🫯‍👩🏿' => 'mulheres lutando: pele morena e pele escura',
    '👩🏾‍🫯‍👩🏻' => 'mulheres lutando: pele morena escura e pele clara',
    '👩🏾‍🫯‍👩🏼' => 'mulheres lutando: pele morena escura e pele morena clara',
    '👩🏾‍🫯‍👩🏽' => 'mulheres lutando: pele morena escura e pele morena',
    '👩🏾‍🫯‍👩🏿' => 'mulheres lutando: pele morena escura e pele escura',
    '👩🏿‍🫯‍👩🏻' => 'mulheres lutando: pele escura e pele clara',
    '👩🏿‍🫯‍👩🏼' => 'mulheres lutando: pele escura e pele morena clara',
    '👩🏿‍🫯‍👩🏽' => 'mulheres lutando: pele escura e pele morena',
    '👩🏿‍🫯‍👩🏾' => 'mulheres lutando: pele escura e pele morena escura',
    '👩🏻‍❤‍👨🏻' => 'casal apaixonado: mulher, homem e pele clara',
    '👩🏻‍❤‍👨🏼' => 'casal apaixonado: mulher, homem, pele clara e pele morena clara',
    '👩🏻‍❤‍👨🏽' => 'casal apaixonado: mulher, homem, pele clara e pele morena',
    '👩🏻‍❤‍👨🏾' => 'casal apaixonado: mulher, homem, pele clara e pele morena escura',
    '👩🏻‍❤‍👨🏿' => 'casal apaixonado: mulher, homem, pele clara e pele escura',
    '👩🏼‍❤‍👨🏻' => 'casal apaixonado: mulher, homem, pele morena clara e pele clara',
    '👩🏼‍❤‍👨🏼' => 'casal apaixonado: mulher, homem e pele morena clara',
    '👩🏼‍❤‍👨🏽' => 'casal apaixonado: mulher, homem, pele morena clara e pele morena',
    '👩🏼‍❤‍👨🏾' => 'casal apaixonado: mulher, homem, pele morena clara e pele morena escura',
    '👩🏼‍❤‍👨🏿' => 'casal apaixonado: mulher, homem, pele morena clara e pele escura',
    '👩🏽‍❤‍👨🏻' => 'casal apaixonado: mulher, homem, pele morena e pele clara',
    '👩🏽‍❤‍👨🏼' => 'casal apaixonado: mulher, homem, pele morena e pele morena clara',
    '👩🏽‍❤‍👨🏽' => 'casal apaixonado: mulher, homem e pele morena',
    '👩🏽‍❤‍👨🏾' => 'casal apaixonado: mulher, homem, pele morena e pele morena escura',
    '👩🏽‍❤‍👨🏿' => 'casal apaixonado: mulher, homem, pele morena e pele escura',
    '👩🏾‍❤‍👨🏻' => 'casal apaixonado: mulher, homem, pele morena escura e pele clara',
    '👩🏾‍❤‍👨🏼' => 'casal apaixonado: mulher, homem, pele morena escura e pele morena clara',
    '👩🏾‍❤‍👨🏽' => 'casal apaixonado: mulher, homem, pele morena escura e pele morena',
    '👩🏾‍❤‍👨🏾' => 'casal apaixonado: mulher, homem e pele morena escura',
    '👩🏾‍❤‍👨🏿' => 'casal apaixonado: mulher, homem, pele morena escura e pele escura',
    '👩🏿‍❤‍👨🏻' => 'casal apaixonado: mulher, homem, pele escura e pele clara',
    '👩🏿‍❤‍👨🏼' => 'casal apaixonado: mulher, homem, pele escura e pele morena clara',
    '👩🏿‍❤‍👨🏽' => 'casal apaixonado: mulher, homem, pele escura e pele morena',
    '👩🏿‍❤‍👨🏾' => 'casal apaixonado: mulher, homem, pele escura e pele morena escura',
    '👩🏿‍❤‍👨🏿' => 'casal apaixonado: mulher, homem e pele escura',
    '👩🏻‍❤‍👩🏻' => 'casal apaixonado: mulher, mulher e pele clara',
    '👩🏻‍❤‍👩🏼' => 'casal apaixonado: mulher, mulher, pele clara e pele morena clara',
    '👩🏻‍❤‍👩🏽' => 'casal apaixonado: mulher, mulher, pele clara e pele morena',
    '👩🏻‍❤‍👩🏾' => 'casal apaixonado: mulher, mulher, pele clara e pele morena escura',
    '👩🏻‍❤‍👩🏿' => 'casal apaixonado: mulher, mulher, pele clara e pele escura',
    '👩🏼‍❤‍👩🏻' => 'casal apaixonado: mulher, mulher, pele morena clara e pele clara',
    '👩🏼‍❤‍👩🏼' => 'casal apaixonado: mulher, mulher e pele morena clara',
    '👩🏼‍❤‍👩🏽' => 'casal apaixonado: mulher, mulher, pele morena clara e pele morena',
    '👩🏼‍❤‍👩🏾' => 'casal apaixonado: mulher, mulher, pele morena clara e pele morena escura',
    '👩🏼‍❤‍👩🏿' => 'casal apaixonado: mulher, mulher, pele morena clara e pele escura',
    '👩🏽‍❤‍👩🏻' => 'casal apaixonado: mulher, mulher, pele morena e pele clara',
    '👩🏽‍❤‍👩🏼' => 'casal apaixonado: mulher, mulher, pele morena e pele morena clara',
    '👩🏽‍❤‍👩🏽' => 'casal apaixonado: mulher, mulher e pele morena',
    '👩🏽‍❤‍👩🏾' => 'casal apaixonado: mulher, mulher, pele morena e pele morena escura',
    '👩🏽‍❤‍👩🏿' => 'casal apaixonado: mulher, mulher, pele morena e pele escura',
    '👩🏾‍❤‍👩🏻' => 'casal apaixonado: mulher, mulher, pele morena escura e pele clara',
    '👩🏾‍❤‍👩🏼' => 'casal apaixonado: mulher, mulher, pele morena escura e pele morena clara',
    '👩🏾‍❤‍👩🏽' => 'casal apaixonado: mulher, mulher, pele morena escura e pele morena',
    '👩🏾‍❤‍👩🏾' => 'casal apaixonado: mulher, mulher e pele morena escura',
    '👩🏾‍❤‍👩🏿' => 'casal apaixonado: mulher, mulher, pele morena escura e pele escura',
    '👩🏿‍❤‍👩🏻' => 'casal apaixonado: mulher, mulher, pele escura e pele clara',
    '👩🏿‍❤‍👩🏼' => 'casal apaixonado: mulher, mulher, pele escura e pele morena clara',
    '👩🏿‍❤‍👩🏽' => 'casal apaixonado: mulher, mulher, pele escura e pele morena',
    '👩🏿‍❤‍👩🏾' => 'casal apaixonado: mulher, mulher, pele escura e pele morena escura',
    '👩🏿‍❤‍👩🏿' => 'casal apaixonado: mulher, mulher e pele escura',
    '👩🏻‍🐰‍👩🏼' => 'mulheres com orelhas de coelho: pele clara e pele morena clara',
    '👩🏻‍🐰‍👩🏽' => 'mulheres com orelhas de coelho: pele clara e pele morena',
    '👩🏻‍🐰‍👩🏾' => 'mulheres com orelhas de coelho: pele clara e pele morena escura',
    '👩🏻‍🐰‍👩🏿' => 'mulheres com orelhas de coelho: pele clara e pele escura',
    '👩🏼‍🐰‍👩🏻' => 'mulheres com orelhas de coelho: pele morena clara e pele clara',
    '👩🏼‍🐰‍👩🏽' => 'mulheres com orelhas de coelho: pele morena clara e pele morena',
    '👩🏼‍🐰‍👩🏾' => 'mulheres com orelhas de coelho: pele morena clara e pele morena escura',
    '👩🏼‍🐰‍👩🏿' => 'mulheres com orelhas de coelho: pele morena clara e pele escura',
    '👩🏽‍🐰‍👩🏻' => 'mulheres com orelhas de coelho: pele morena e pele clara',
    '👩🏽‍🐰‍👩🏼' => 'mulheres com orelhas de coelho: pele morena e pele morena clara',
    '👩🏽‍🐰‍👩🏾' => 'mulheres com orelhas de coelho: pele morena e pele morena escura',
    '👩🏽‍🐰‍👩🏿' => 'mulheres com orelhas de coelho: pele morena e pele escura',
    '👩🏾‍🐰‍👩🏻' => 'mulheres com orelhas de coelho: pele morena escura e pele clara',
    '👩🏾‍🐰‍👩🏼' => 'mulheres com orelhas de coelho: pele morena escura e pele morena clara',
    '👩🏾‍🐰‍👩🏽' => 'mulheres com orelhas de coelho: pele morena escura e pele morena',
    '👩🏾‍🐰‍👩🏿' => 'mulheres com orelhas de coelho: pele morena escura e pele escura',
    '👩🏿‍🐰‍👩🏻' => 'mulheres com orelhas de coelho: pele escura e pele clara',
    '👩🏿‍🐰‍👩🏼' => 'mulheres com orelhas de coelho: pele escura e pele morena clara',
    '👩🏿‍🐰‍👩🏽' => 'mulheres com orelhas de coelho: pele escura e pele morena',
    '👩🏿‍🐰‍👩🏾' => 'mulheres com orelhas de coelho: pele escura e pele morena escura',
    '🧑🏻‍🤝‍🧑🏻' => 'pessoas de mãos dadas: pele clara',
    '🧑🏻‍🤝‍🧑🏼' => 'pessoas de mãos dadas: pele clara e pele morena clara',
    '🧑🏻‍🤝‍🧑🏽' => 'pessoas de mãos dadas: pele clara e pele morena',
    '🧑🏻‍🤝‍🧑🏾' => 'pessoas de mãos dadas: pele clara e pele morena escura',
    '🧑🏻‍🤝‍🧑🏿' => 'pessoas de mãos dadas: pele clara e pele escura',
    '🧑🏼‍🤝‍🧑🏻' => 'pessoas de mãos dadas: pele morena clara e pele clara',
    '🧑🏼‍🤝‍🧑🏼' => 'pessoas de mãos dadas: pele morena clara',
    '🧑🏼‍🤝‍🧑🏽' => 'pessoas de mãos dadas: pele morena clara e pele morena',
    '🧑🏼‍🤝‍🧑🏾' => 'pessoas de mãos dadas: pele morena clara e pele morena escura',
    '🧑🏼‍🤝‍🧑🏿' => 'pessoas de mãos dadas: pele morena clara e pele escura',
    '🧑🏽‍🤝‍🧑🏻' => 'pessoas de mãos dadas: pele morena e pele clara',
    '🧑🏽‍🤝‍🧑🏼' => 'pessoas de mãos dadas: pele morena e pele morena clara',
    '🧑🏽‍🤝‍🧑🏽' => 'pessoas de mãos dadas: pele morena',
    '🧑🏽‍🤝‍🧑🏾' => 'pessoas de mãos dadas: pele morena e pele morena escura',
    '🧑🏽‍🤝‍🧑🏿' => 'pessoas de mãos dadas: pele morena e pele escura',
    '🧑🏾‍🤝‍🧑🏻' => 'pessoas de mãos dadas: pele morena escura e pele clara',
    '🧑🏾‍🤝‍🧑🏼' => 'pessoas de mãos dadas: pele morena escura e pele morena clara',
    '🧑🏾‍🤝‍🧑🏽' => 'pessoas de mãos dadas: pele morena escura e pele morena',
    '🧑🏾‍🤝‍🧑🏾' => 'pessoas de mãos dadas: pele morena escura',
    '🧑🏾‍🤝‍🧑🏿' => 'pessoas de mãos dadas: pele morena escura e pele escura',
    '🧑🏿‍🤝‍🧑🏻' => 'pessoas de mãos dadas: pele escura e pele clara',
    '🧑🏿‍🤝‍🧑🏼' => 'pessoas de mãos dadas: pele escura e pele morena clara',
    '🧑🏿‍🤝‍🧑🏽' => 'pessoas de mãos dadas: pele escura e pele morena',
    '🧑🏿‍🤝‍🧑🏾' => 'pessoas de mãos dadas: pele escura e pele morena escura',
    '🧑🏿‍🤝‍🧑🏿' => 'pessoas de mãos dadas: pele escura',
    '👩🏻‍🤝‍👩🏼' => 'duas mulheres de mãos dadas: pele clara e pele morena clara',
    '👩🏻‍🤝‍👩🏽' => 'duas mulheres de mãos dadas: pele clara e pele morena',
    '👩🏻‍🤝‍👩🏾' => 'duas mulheres de mãos dadas: pele clara e pele morena escura',
    '👩🏻‍🤝‍👩🏿' => 'duas mulheres de mãos dadas: pele clara e pele escura',
    '👩🏼‍🤝‍👩🏻' => 'duas mulheres de mãos dadas: pele morena clara e pele clara',
    '👩🏼‍🤝‍👩🏽' => 'duas mulheres de mãos dadas: pele morena clara e pele morena',
    '👩🏼‍🤝‍👩🏾' => 'duas mulheres de mãos dadas: pele morena clara e pele morena escura',
    '👩🏼‍🤝‍👩🏿' => 'duas mulheres de mãos dadas: pele morena clara e pele escura',
    '👩🏽‍🤝‍👩🏻' => 'duas mulheres de mãos dadas: pele morena e pele clara',
    '👩🏽‍🤝‍👩🏼' => 'duas mulheres de mãos dadas: pele morena e pele morena clara',
    '👩🏽‍🤝‍👩🏾' => 'duas mulheres de mãos dadas: pele morena e pele morena escura',
    '👩🏽‍🤝‍👩🏿' => 'duas mulheres de mãos dadas: pele morena e pele escura',
    '👩🏾‍🤝‍👩🏻' => 'duas mulheres de mãos dadas: pele morena escura e pele clara',
    '👩🏾‍🤝‍👩🏼' => 'duas mulheres de mãos dadas: pele morena escura e pele morena clara',
    '👩🏾‍🤝‍👩🏽' => 'duas mulheres de mãos dadas: pele morena escura e pele morena',
    '👩🏾‍🤝‍👩🏿' => 'duas mulheres de mãos dadas: pele morena escura e pele escura',
    '👩🏿‍🤝‍👩🏻' => 'duas mulheres de mãos dadas: pele escura e pele clara',
    '👩🏿‍🤝‍👩🏼' => 'duas mulheres de mãos dadas: pele escura e pele morena clara',
    '👩🏿‍🤝‍👩🏽' => 'duas mulheres de mãos dadas: pele escura e pele morena',
    '👩🏿‍🤝‍👩🏾' => 'duas mulheres de mãos dadas: pele escura e pele morena escura',
    '👩🏻‍🤝‍👨🏼' => 'homem e mulher de mãos dadas: pele clara e pele morena clara',
    '👩🏻‍🤝‍👨🏽' => 'homem e mulher de mãos dadas: pele clara e pele morena',
    '👩🏻‍🤝‍👨🏾' => 'homem e mulher de mãos dadas: pele clara e pele morena escura',
    '👩🏻‍🤝‍👨🏿' => 'homem e mulher de mãos dadas: pele clara e pele escura',
    '👩🏼‍🤝‍👨🏻' => 'homem e mulher de mãos dadas: pele morena clara e pele clara',
    '👩🏼‍🤝‍👨🏽' => 'homem e mulher de mãos dadas: pele morena clara e pele morena',
    '👩🏼‍🤝‍👨🏾' => 'homem e mulher de mãos dadas: pele morena clara e pele morena escura',
    '👩🏼‍🤝‍👨🏿' => 'homem e mulher de mãos dadas: pele morena clara e pele escura',
    '👩🏽‍🤝‍👨🏻' => 'homem e mulher de mãos dadas: pele morena e pele clara',
    '👩🏽‍🤝‍👨🏼' => 'homem e mulher de mãos dadas: pele morena e pele morena clara',
    '👩🏽‍🤝‍👨🏾' => 'homem e mulher de mãos dadas: pele morena e pele morena escura',
    '👩🏽‍🤝‍👨🏿' => 'homem e mulher de mãos dadas: pele morena e pele escura',
    '👩🏾‍🤝‍👨🏻' => 'homem e mulher de mãos dadas: pele morena escura e pele clara',
    '👩🏾‍🤝‍👨🏼' => 'homem e mulher de mãos dadas: pele morena escura e pele morena clara',
    '👩🏾‍🤝‍👨🏽' => 'homem e mulher de mãos dadas: pele morena escura e pele morena',
    '👩🏾‍🤝‍👨🏿' => 'homem e mulher de mãos dadas: pele morena escura e pele escura',
    '👩🏿‍🤝‍👨🏻' => 'homem e mulher de mãos dadas: pele escura e pele clara',
    '👩🏿‍🤝‍👨🏼' => 'homem e mulher de mãos dadas: pele escura e pele morena clara',
    '👩🏿‍🤝‍👨🏽' => 'homem e mulher de mãos dadas: pele escura e pele morena',
    '👩🏿‍🤝‍👨🏾' => 'homem e mulher de mãos dadas: pele escura e pele morena escura',
    '👨🏻‍🤝‍👨🏼' => 'dois homens de mãos dadas: pele clara e pele morena clara',
    '👨🏻‍🤝‍👨🏽' => 'dois homens de mãos dadas: pele clara e pele morena',
    '👨🏻‍🤝‍👨🏾' => 'dois homens de mãos dadas: pele clara e pele morena escura',
    '👨🏻‍🤝‍👨🏿' => 'dois homens de mãos dadas: pele clara e pele escura',
    '👨🏼‍🤝‍👨🏻' => 'dois homens de mãos dadas: pele morena clara e pele clara',
    '👨🏼‍🤝‍👨🏽' => 'dois homens de mãos dadas: pele morena clara e pele morena',
    '👨🏼‍🤝‍👨🏾' => 'dois homens de mãos dadas: pele morena clara e pele morena escura',
    '👨🏼‍🤝‍👨🏿' => 'dois homens de mãos dadas: pele morena clara e pele escura',
    '👨🏽‍🤝‍👨🏻' => 'dois homens de mãos dadas: pele morena e pele clara',
    '👨🏽‍🤝‍👨🏼' => 'dois homens de mãos dadas: pele morena e pele morena clara',
    '👨🏽‍🤝‍👨🏾' => 'dois homens de mãos dadas: pele morena e pele morena escura',
    '👨🏽‍🤝‍👨🏿' => 'dois homens de mãos dadas: pele morena e pele escura',
    '👨🏾‍🤝‍👨🏻' => 'dois homens de mãos dadas: pele morena escura e pele clara',
    '👨🏾‍🤝‍👨🏼' => 'dois homens de mãos dadas: pele morena escura e pele morena clara',
    '👨🏾‍🤝‍👨🏽' => 'dois homens de mãos dadas: pele morena escura e pele morena',
    '👨🏾‍🤝‍👨🏿' => 'dois homens de mãos dadas: pele morena escura e pele escura',
    '👨🏿‍🤝‍👨🏻' => 'dois homens de mãos dadas: pele escura e pele clara',
    '👨🏿‍🤝‍👨🏼' => 'dois homens de mãos dadas: pele escura e pele morena clara',
    '👨🏿‍🤝‍👨🏽' => 'dois homens de mãos dadas: pele escura e pele morena',
    '👨🏿‍🤝‍👨🏾' => 'dois homens de mãos dadas: pele escura e pele morena escura',
    '👩‍❤‍💋‍👨' => 'beijo: mulher e homem',
    '👨‍❤‍💋‍👨' => 'beijo: homem e homem',
    '👩‍❤‍💋‍👩' => 'beijo: mulher e mulher',
    '👨‍👩‍👧‍👦' => 'família: homem, mulher, menina e menino',
    '👨‍👩‍👦‍👦' => 'família: homem, mulher, menino e menino',
    '👨‍👩‍👧‍👧' => 'família: homem, mulher, menina e menina',
    '👨‍👨‍👧‍👦' => 'família: homem, homem, menina e menino',
    '👨‍👨‍👦‍👦' => 'família: homem, homem, menino e menino',
    '👨‍👨‍👧‍👧' => 'família: homem, homem, menina e menina',
    '👩‍👩‍👧‍👦' => 'família: mulher, mulher, menina e menino',
    '👩‍👩‍👦‍👦' => 'família: mulher, mulher, menino e menino',
    '👩‍👩‍👧‍👧' => 'família: mulher, mulher, menina e menina',
    '🏴󠁧󠁢󠁥󠁮󠁧󠁿' => 'bandeira: Inglaterra',
    '🏴󠁧󠁢󠁳󠁣󠁴󠁿' => 'bandeira: Escócia',
    '🏴󠁧󠁢󠁷󠁬󠁳󠁿' => 'bandeira: País de Gales',
    '🧑‍🧑‍🧒‍🧒' => 'família: adulto, adulto, criança, criança',
    '🚶🏻‍♀‍➡' => 'mulher andando: pele clara e de frente para a direita',
    '🚶🏼‍♀‍➡' => 'mulher andando: pele morena clara e de frente para a direita',
    '🚶🏽‍♀‍➡' => 'mulher andando: pele morena e de frente para a direita',
    '🚶🏾‍♀‍➡' => 'mulher andando: pele morena escura e de frente para a direita',
    '🚶🏿‍♀‍➡' => 'mulher andando: pele escura e de frente para a direita',
    '🚶🏻‍♂‍➡' => 'homem andando: pele clara e de frente para a direita',
    '🚶🏼‍♂‍➡' => 'homem andando: pele morena clara e de frente para a direita',
    '🚶🏽‍♂‍➡' => 'homem andando: pele morena e de frente para a direita',
    '🚶🏾‍♂‍➡' => 'homem andando: pele morena escura e de frente para a direita',
    '🚶🏿‍♂‍➡' => 'homem andando: pele escura e de frente para a direita',
    '🧎🏻‍♀‍➡' => 'mulher ajoelhando: pele clara e de frente para a direita',
    '🧎🏼‍♀‍➡' => 'mulher ajoelhando: pele morena clara e de frente para a direita',
    '🧎🏽‍♀‍➡' => 'mulher ajoelhando: pele morena e de frente para a direita',
    '🧎🏾‍♀‍➡' => 'mulher ajoelhando: pele morena escura e de frente para a direita',
    '🧎🏿‍♀‍➡' => 'mulher ajoelhando: pele escura e de frente para a direita',
    '🧎🏻‍♂‍➡' => 'homem ajoelhando: pele clara e de frente para a direita',
    '🧎🏼‍♂‍➡' => 'homem ajoelhando: pele morena clara e de frente para a direita',
    '🧎🏽‍♂‍➡' => 'homem ajoelhando: pele morena e de frente para a direita',
    '🧎🏾‍♂‍➡' => 'homem ajoelhando: pele morena escura e de frente para a direita',
    '🧎🏿‍♂‍➡' => 'homem ajoelhando: pele escura e de frente para a direita',
    '🧑🏻‍🦯‍➡' => 'pessoa com bengala para cego: pele clara e de frente para a direita',
    '🧑🏼‍🦯‍➡' => 'pessoa com bengala para cego: pele morena clara e de frente para a direita',
    '🧑🏽‍🦯‍➡' => 'pessoa com bengala para cego: pele morena e de frente para a direita',
    '🧑🏾‍🦯‍➡' => 'pessoa com bengala para cego: pele morena escura e de frente para a direita',
    '🧑🏿‍🦯‍➡' => 'pessoa com bengala para cego: pele escura e de frente para a direita',
    '👨🏻‍🦯‍➡' => 'homem com bengala para cego: pele clara e de frente para a direita',
    '👨🏼‍🦯‍➡' => 'homem com bengala para cego: pele morena clara e de frente para a direita',
    '👨🏽‍🦯‍➡' => 'homem com bengala para cego: pele morena e de frente para a direita',
    '👨🏾‍🦯‍➡' => 'homem com bengala para cego: pele morena escura e de frente para a direita',
    '👨🏿‍🦯‍➡' => 'homem com bengala para cego: pele escura e de frente para a direita',
    '👩🏻‍🦯‍➡' => 'mulher com bengala para cego: pele clara e de frente para a direita',
    '👩🏼‍🦯‍➡' => 'mulher com bengala para cego: pele morena clara e de frente para a direita',
    '👩🏽‍🦯‍➡' => 'mulher com bengala para cego: pele morena e de frente para a direita',
    '👩🏾‍🦯‍➡' => 'mulher com bengala para cego: pele morena escura e de frente para a direita',
    '👩🏿‍🦯‍➡' => 'mulher com bengala para cego: pele escura e de frente para a direita',
    '🧑🏻‍🦼‍➡' => 'pessoa em cadeira de rodas motorizada: pele clara e de frente para a direita',
    '🧑🏼‍🦼‍➡' => 'pessoa em cadeira de rodas motorizada: pele morena clara e de frente para a direita',
    '🧑🏽‍🦼‍➡' => 'pessoa em cadeira de rodas motorizada: pele morena e de frente para a direita',
    '🧑🏾‍🦼‍➡' => 'pessoa em cadeira de rodas motorizada: pele morena escura e de frente para a direita',
    '🧑🏿‍🦼‍➡' => 'pessoa em cadeira de rodas motorizada: pele escura e de frente para a direita',
    '👨🏻‍🦼‍➡' => 'homem em cadeira de rodas motorizada: pele clara e de frente para a direita',
    '👨🏼‍🦼‍➡' => 'homem em cadeira de rodas motorizada: pele morena clara e de frente para a direita',
    '👨🏽‍🦼‍➡' => 'homem em cadeira de rodas motorizada: pele morena e de frente para a direita',
    '👨🏾‍🦼‍➡' => 'homem em cadeira de rodas motorizada: pele morena escura e de frente para a direita',
    '👨🏿‍🦼‍➡' => 'homem em cadeira de rodas motorizada: pele escura e de frente para a direita',
    '👩🏻‍🦼‍➡' => 'mulher em cadeira de rodas motorizada: pele clara e de frente para a direita',
    '👩🏼‍🦼‍➡' => 'mulher em cadeira de rodas motorizada: pele morena clara e de frente para a direita',
    '👩🏽‍🦼‍➡' => 'mulher em cadeira de rodas motorizada: pele morena e de frente para a direita',
    '👩🏾‍🦼‍➡' => 'mulher em cadeira de rodas motorizada: pele morena escura e de frente para a direita',
    '👩🏿‍🦼‍➡' => 'mulher em cadeira de rodas motorizada: pele escura e de frente para a direita',
    '🧑🏻‍🦽‍➡' => 'pessoa em cadeira de rodas manual: pele clara e de frente para a direita',
    '🧑🏼‍🦽‍➡' => 'pessoa em cadeira de rodas manual: pele morena clara e de frente para a direita',
    '🧑🏽‍🦽‍➡' => 'pessoa em cadeira de rodas manual: pele morena e de frente para a direita',
    '🧑🏾‍🦽‍➡' => 'pessoa em cadeira de rodas manual: pele morena escura e de frente para a direita',
    '🧑🏿‍🦽‍➡' => 'pessoa em cadeira de rodas manual: pele escura e de frente para a direita',
    '👨🏻‍🦽‍➡' => 'homem em cadeira de rodas manual: pele clara e de frente para a direita',
    '👨🏼‍🦽‍➡' => 'homem em cadeira de rodas manual: pele morena clara e de frente para a direita',
    '👨🏽‍🦽‍➡' => 'homem em cadeira de rodas manual: pele morena e de frente para a direita',
    '👨🏾‍🦽‍➡' => 'homem em cadeira de rodas manual: pele morena escura e de frente para a direita',
    '👨🏿‍🦽‍➡' => 'homem em cadeira de rodas manual: pele escura e de frente para a direita',
    '👩🏻‍🦽‍➡' => 'mulher em cadeira de rodas manual: pele clara e de frente para a direita',
    '👩🏼‍🦽‍➡' => 'mulher em cadeira de rodas manual: pele morena clara e de frente para a direita',
    '👩🏽‍🦽‍➡' => 'mulher em cadeira de rodas manual: pele morena e de frente para a direita',
    '👩🏾‍🦽‍➡' => 'mulher em cadeira de rodas manual: pele morena escura e de frente para a direita',
    '👩🏿‍🦽‍➡' => 'mulher em cadeira de rodas manual: pele escura e de frente para a direita',
    '🏃🏻‍♀‍➡' => 'mulher correndo: pele clara e de frente para a direita',
    '🏃🏼‍♀‍➡' => 'mulher correndo: pele morena clara e de frente para a direita',
    '🏃🏽‍♀‍➡' => 'mulher correndo: pele morena e de frente para a direita',
    '🏃🏾‍♀‍➡' => 'mulher correndo: pele morena escura e de frente para a direita',
    '🏃🏿‍♀‍➡' => 'mulher correndo: pele escura e de frente para a direita',
    '🏃🏻‍♂‍➡' => 'homem correndo: pele clara e de frente para a direita',
    '🏃🏼‍♂‍➡' => 'homem correndo: pele morena clara e de frente para a direita',
    '🏃🏽‍♂‍➡' => 'homem correndo: pele morena e de frente para a direita',
    '🏃🏾‍♂‍➡' => 'homem correndo: pele morena escura e de frente para a direita',
    '🏃🏿‍♂‍➡' => 'homem correndo: pele escura e de frente para a direita',
    '🫱🏻‍🫲🏼' => 'aperto de mãos: pele clara e pele morena clara',
    '🫱🏻‍🫲🏽' => 'aperto de mãos: pele clara e pele morena',
    '🫱🏻‍🫲🏾' => 'aperto de mãos: pele clara e pele morena escura',
    '🫱🏻‍🫲🏿' => 'aperto de mãos: pele clara e pele escura',
    '🫱🏼‍🫲🏻' => 'aperto de mãos: pele morena clara e pele clara',
    '🫱🏼‍🫲🏽' => 'aperto de mãos: pele morena clara e pele morena',
    '🫱🏼‍🫲🏾' => 'aperto de mãos: pele morena clara e pele morena escura',
    '🫱🏼‍🫲🏿' => 'aperto de mãos: pele morena clara e pele escura',
    '🫱🏽‍🫲🏻' => 'aperto de mãos: pele morena e pele clara',
    '🫱🏽‍🫲🏼' => 'aperto de mãos: pele morena e pele morena clara',
    '🫱🏽‍🫲🏾' => 'aperto de mãos: pele morena e pele morena escura',
    '🫱🏽‍🫲🏿' => 'aperto de mãos: pele morena e pele escura',
    '🫱🏾‍🫲🏻' => 'aperto de mãos: pele morena escura e pele clara',
    '🫱🏾‍🫲🏼' => 'aperto de mãos: pele morena escura e pele morena clara',
    '🫱🏾‍🫲🏽' => 'aperto de mãos: pele morena escura e pele morena',
    '🫱🏾‍🫲🏿' => 'aperto de mãos: pele morena escura e pele escura',
    '🫱🏿‍🫲🏻' => 'aperto de mãos: pele escura e pele clara',
    '🫱🏿‍🫲🏼' => 'aperto de mãos: pele escura e pele morena clara',
    '🫱🏿‍🫲🏽' => 'aperto de mãos: pele escura e pele morena',
    '🫱🏿‍🫲🏾' => 'aperto de mãos: pele escura e pele morena escura',
    '🚶‍♀‍➡' => 'mulher andando: de frente para a direita',
    '🚶‍♂‍➡' => 'homem andando: de frente para a direita',
    '🧎‍♀‍➡' => 'mulher ajoelhando: de frente para a direita',
    '🧎‍♂‍➡' => 'homem ajoelhando: de frente para a direita',
    '🧑‍🦯‍➡' => 'pessoa com bengala para cego: de frente para a direita',
    '👨‍🦯‍➡' => 'homem com bengala para cego: de frente para a direita',
    '👩‍🦯‍➡' => 'mulher com bengala para cego: de frente para a direita',
    '🧑‍🦼‍➡' => 'pessoa em cadeira de rodas motorizada: de frente para a direita',
    '👨‍🦼‍➡' => 'homem em cadeira de rodas motorizada: de frente para a direita',
    '👩‍🦼‍➡' => 'mulher em cadeira de rodas motorizada: de frente para a direita',
    '🧑‍🦽‍➡' => 'pessoa em cadeira de rodas manual: de frente para a direita',
    '👨‍🦽‍➡' => 'homem em cadeira de rodas manual: de frente para a direita',
    '👩‍🦽‍➡' => 'mulher em cadeira de rodas manual: de frente para a direita',
    '🏃‍♀‍➡' => 'mulher correndo: de frente para a direita',
    '🏃‍♂‍➡' => 'homem correndo: de frente para a direita',
    '👩‍❤‍👨' => 'casal apaixonado: mulher e homem',
    '👨‍❤‍👨' => 'casal apaixonado: homem e homem',
    '👩‍❤‍👩' => 'casal apaixonado: mulher e mulher',
    '👨‍👩‍👦' => 'família: homem, mulher e menino',
    '👨‍👩‍👧' => 'família: homem, mulher e menina',
    '👨‍👨‍👦' => 'família: homem, homem e menino',
    '👨‍👨‍👧' => 'família: homem, homem e menina',
    '👩‍👩‍👦' => 'família: mulher, mulher e menino',
    '👩‍👩‍👧' => 'família: mulher, mulher e menina',
    '👨‍👦‍👦' => 'família: homem, menino e menino',
    '👨‍👧‍👦' => 'família: homem, menina e menino',
    '👨‍👧‍👧' => 'família: homem, menina e menina',
    '👩‍👦‍👦' => 'família: mulher, menino e menino',
    '👩‍👧‍👦' => 'família: mulher, menina e menino',
    '👩‍👧‍👧' => 'família: mulher, menina e menina',
    '🧑‍🤝‍🧑' => 'pessoas de mãos dadas',
    '🧑‍🧑‍🧒' => 'família: adulto, adulto, criança',
    '🧑‍🧒‍🧒' => 'família: adulto, criança, criança',
    '🧑🏻‍🦰' => 'pessoa: pele clara e cabelo vermelho',
    '🧑🏼‍🦰' => 'pessoa: pele morena clara e cabelo vermelho',
    '🧑🏽‍🦰' => 'pessoa: pele morena e cabelo vermelho',
    '🧑🏾‍🦰' => 'pessoa: pele morena escura e cabelo vermelho',
    '🧑🏿‍🦰' => 'pessoa: pele escura e cabelo vermelho',
    '🧑🏻‍🦱' => 'pessoa: pele clara e cabelo cacheado',
    '🧑🏼‍🦱' => 'pessoa: pele morena clara e cabelo cacheado',
    '🧑🏽‍🦱' => 'pessoa: pele morena e cabelo cacheado',
    '🧑🏾‍🦱' => 'pessoa: pele morena escura e cabelo cacheado',
    '🧑🏿‍🦱' => 'pessoa: pele escura e cabelo cacheado',
    '🧑🏻‍🦳' => 'pessoa: pele clara e cabelo branco',
    '🧑🏼‍🦳' => 'pessoa: pele morena clara e cabelo branco',
    '🧑🏽‍🦳' => 'pessoa: pele morena e cabelo branco',
    '🧑🏾‍🦳' => 'pessoa: pele morena escura e cabelo branco',
    '🧑🏿‍🦳' => 'pessoa: pele escura e cabelo branco',
    '🧑🏻‍🦲' => 'pessoa: pele clara e careca',
    '🧑🏼‍🦲' => 'pessoa: pele morena clara e careca',
    '🧑🏽‍🦲' => 'pessoa: pele morena e careca',
    '🧑🏾‍🦲' => 'pessoa: pele morena escura e careca',
    '🧑🏿‍🦲' => 'pessoa: pele escura e careca',
    '🧑🏻‍🩰' => 'bailarina: pele clara',
    '🧑🏼‍🩰' => 'bailarina: pele morena clara',
    '🧑🏽‍🩰' => 'bailarina: pele morena',
    '🧑🏾‍🩰' => 'bailarina: pele morena escura',
    '🧑🏿‍🩰' => 'bailarina: pele escura',
    '🧔🏻‍♂' => 'homem: pele clara e barbudo',
    '🧔🏼‍♂' => 'homem: pele morena clara e barbudo',
    '🧔🏽‍♂' => 'homem: pele morena e barbudo',
    '🧔🏾‍♂' => 'homem: pele morena escura e barbudo',
    '🧔🏿‍♂' => 'homem: pele escura e barbudo',
    '👱🏻‍♂' => 'homem: pele clara e cabelo loiro',
    '👱🏼‍♂' => 'homem: pele morena clara e cabelo loiro',
    '👱🏽‍♂' => 'homem: pele morena e cabelo loiro',
    '👱🏾‍♂' => 'homem: pele morena escura e cabelo loiro',
    '👱🏿‍♂' => 'homem: pele escura e cabelo loiro',
    '👨🏻‍🦰' => 'homem: pele clara e cabelo vermelho',
    '👨🏼‍🦰' => 'homem: pele morena clara e cabelo vermelho',
    '👨🏽‍🦰' => 'homem: pele morena e cabelo vermelho',
    '👨🏾‍🦰' => 'homem: pele morena escura e cabelo vermelho',
    '👨🏿‍🦰' => 'homem: pele escura e cabelo vermelho',
    '👨🏻‍🦱' => 'homem: pele clara e cabelo cacheado',
    '👨🏼‍🦱' => 'homem: pele morena clara e cabelo cacheado',
    '👨🏽‍🦱' => 'homem: pele morena e cabelo cacheado',
    '👨🏾‍🦱' => 'homem: pele morena escura e cabelo cacheado',
    '👨🏿‍🦱' => 'homem: pele escura e cabelo cacheado',
    '👨🏻‍🦳' => 'homem: pele clara e cabelo branco',
    '👨🏼‍🦳' => 'homem: pele morena clara e cabelo branco',
    '👨🏽‍🦳' => 'homem: pele morena e cabelo branco',
    '👨🏾‍🦳' => 'homem: pele morena escura e cabelo branco',
    '👨🏿‍🦳' => 'homem: pele escura e cabelo branco',
    '👨🏻‍🦲' => 'homem: pele clara e careca',
    '👨🏼‍🦲' => 'homem: pele morena clara e careca',
    '👨🏽‍🦲' => 'homem: pele morena e careca',
    '👨🏾‍🦲' => 'homem: pele morena escura e careca',
    '👨🏿‍🦲' => 'homem: pele escura e careca',
    '🧔🏻‍♀' => 'mulher: pele clara e barba',
    '🧔🏼‍♀' => 'mulher: pele morena clara e barba',
    '🧔🏽‍♀' => 'mulher: pele morena e barba',
    '🧔🏾‍♀' => 'mulher: pele morena escura e barba',
    '🧔🏿‍♀' => 'mulher: pele escura e barba',
    '👱🏻‍♀' => 'mulher: pele clara e cabelo loiro',
    '👱🏼‍♀' => 'mulher: pele morena clara e cabelo loiro',
    '👱🏽‍♀' => 'mulher: pele morena e cabelo loiro',
    '👱🏾‍♀' => 'mulher: pele morena escura e cabelo loiro',
    '👱🏿‍♀' => 'mulher: pele escura e cabelo loiro',
    '👩🏻‍🦰' => 'mulher: pele clara e cabelo vermelho',
    '👩🏼‍🦰' => 'mulher: pele morena clara e cabelo vermelho',
    '👩🏽‍🦰' => 'mulher: pele morena e cabelo vermelho',
    '👩🏾‍🦰' => 'mulher: pele morena escura e cabelo vermelho',
    '👩🏿‍🦰' => 'mulher: pele escura e cabelo vermelho',
    '👩🏻‍🦱' => 'mulher: pele clara e cabelo cacheado',
    '👩🏼‍🦱' => 'mulher: pele morena clara e cabelo cacheado',
    '👩🏽‍🦱' => 'mulher: pele morena e cabelo cacheado',
    '👩🏾‍🦱' => 'mulher: pele morena escura e cabelo cacheado',
    '👩🏿‍🦱' => 'mulher: pele escura e cabelo cacheado',
    '👩🏻‍🦳' => 'mulher: pele clara e cabelo branco',
    '👩🏼‍🦳' => 'mulher: pele morena clara e cabelo branco',
    '👩🏽‍🦳' => 'mulher: pele morena e cabelo branco',
    '👩🏾‍🦳' => 'mulher: pele morena escura e cabelo branco',
    '👩🏿‍🦳' => 'mulher: pele escura e cabelo branco',
    '👩🏻‍🦲' => 'mulher: pele clara e careca',
    '👩🏼‍🦲' => 'mulher: pele morena clara e careca',
    '👩🏽‍🦲' => 'mulher: pele morena e careca',
    '👩🏾‍🦲' => 'mulher: pele morena escura e careca',
    '👩🏿‍🦲' => 'mulher: pele escura e careca',
    '🙍🏻‍♂' => 'homem franzindo a sobrancelha: pele clara',
    '🙍🏼‍♂' => 'homem franzindo a sobrancelha: pele morena clara',
    '🙍🏽‍♂' => 'homem franzindo a sobrancelha: pele morena',
    '🙍🏾‍♂' => 'homem franzindo a sobrancelha: pele morena escura',
    '🙍🏿‍♂' => 'homem franzindo a sobrancelha: pele escura',
    '🙍🏻‍♀' => 'mulher franzindo a sobrancelha: pele clara',
    '🙍🏼‍♀' => 'mulher franzindo a sobrancelha: pele morena clara',
    '🙍🏽‍♀' => 'mulher franzindo a sobrancelha: pele morena',
    '🙍🏾‍♀' => 'mulher franzindo a sobrancelha: pele morena escura',
    '🙍🏿‍♀' => 'mulher franzindo a sobrancelha: pele escura',
    '🙎🏻‍♂' => 'homem fazendo bico: pele clara',
    '🙎🏼‍♂' => 'homem fazendo bico: pele morena clara',
    '🙎🏽‍♂' => 'homem fazendo bico: pele morena',
    '🙎🏾‍♂' => 'homem fazendo bico: pele morena escura',
    '🙎🏿‍♂' => 'homem fazendo bico: pele escura',
    '🙎🏻‍♀' => 'mulher fazendo bico: pele clara',
    '🙎🏼‍♀' => 'mulher fazendo bico: pele morena clara',
    '🙎🏽‍♀' => 'mulher fazendo bico: pele morena',
    '🙎🏾‍♀' => 'mulher fazendo bico: pele morena escura',
    '🙎🏿‍♀' => 'mulher fazendo bico: pele escura',
    '🙅🏻‍♂' => 'homem fazendo gesto de “não”: pele clara',
    '🙅🏼‍♂' => 'homem fazendo gesto de “não”: pele morena clara',
    '🙅🏽‍♂' => 'homem fazendo gesto de “não”: pele morena',
    '🙅🏾‍♂' => 'homem fazendo gesto de “não”: pele morena escura',
    '🙅🏿‍♂' => 'homem fazendo gesto de “não”: pele escura',
    '🙅🏻‍♀' => 'mulher fazendo gesto de “não”: pele clara',
    '🙅🏼‍♀' => 'mulher fazendo gesto de “não”: pele morena clara',
    '🙅🏽‍♀' => 'mulher fazendo gesto de “não”: pele morena',
    '🙅🏾‍♀' => 'mulher fazendo gesto de “não”: pele morena escura',
    '🙅🏿‍♀' => 'mulher fazendo gesto de “não”: pele escura',
    '🙆🏻‍♂' => 'homem fazendo gesto de “OK”: pele clara',
    '🙆🏼‍♂' => 'homem fazendo gesto de “OK”: pele morena clara',
    '🙆🏽‍♂' => 'homem fazendo gesto de “OK”: pele morena',
    '🙆🏾‍♂' => 'homem fazendo gesto de “OK”: pele morena escura',
    '🙆🏿‍♂' => 'homem fazendo gesto de “OK”: pele escura',
    '🙆🏻‍♀' => 'mulher fazendo gesto de “OK”: pele clara',
    '🙆🏼‍♀' => 'mulher fazendo gesto de “OK”: pele morena clara',
    '🙆🏽‍♀' => 'mulher fazendo gesto de “OK”: pele morena',
    '🙆🏾‍♀' => 'mulher fazendo gesto de “OK”: pele morena escura',
    '🙆🏿‍♀' => 'mulher fazendo gesto de “OK”: pele escura',
    '💁🏻‍♂' => 'homem com a palma virada para cima: pele clara',
    '💁🏼‍♂' => 'homem com a palma virada para cima: pele morena clara',
    '💁🏽‍♂' => 'homem com a palma virada para cima: pele morena',
    '💁🏾‍♂' => 'homem com a palma virada para cima: pele morena escura',
    '💁🏿‍♂' => 'homem com a palma virada para cima: pele escura',
    '💁🏻‍♀' => 'mulher com a palma virada para cima: pele clara',
    '💁🏼‍♀' => 'mulher com a palma virada para cima: pele morena clara',
    '💁🏽‍♀' => 'mulher com a palma virada para cima: pele morena',
    '💁🏾‍♀' => 'mulher com a palma virada para cima: pele morena escura',
    '💁🏿‍♀' => 'mulher com a palma virada para cima: pele escura',
    '🙋🏻‍♂' => 'homem levantando a mão: pele clara',
    '🙋🏼‍♂' => 'homem levantando a mão: pele morena clara',
    '🙋🏽‍♂' => 'homem levantando a mão: pele morena',
    '🙋🏾‍♂' => 'homem levantando a mão: pele morena escura',
    '🙋🏿‍♂' => 'homem levantando a mão: pele escura',
    '🙋🏻‍♀' => 'mulher levantando a mão: pele clara',
    '🙋🏼‍♀' => 'mulher levantando a mão: pele morena clara',
    '🙋🏽‍♀' => 'mulher levantando a mão: pele morena',
    '🙋🏾‍♀' => 'mulher levantando a mão: pele morena escura',
    '🙋🏿‍♀' => 'mulher levantando a mão: pele escura',
    '🧏🏻‍♂' => 'homem surdo: pele clara',
    '🧏🏼‍♂' => 'homem surdo: pele morena clara',
    '🧏🏽‍♂' => 'homem surdo: pele morena',
    '🧏🏾‍♂' => 'homem surdo: pele morena escura',
    '🧏🏿‍♂' => 'homem surdo: pele escura',
    '🧏🏻‍♀' => 'mulher surda: pele clara',
    '🧏🏼‍♀' => 'mulher surda: pele morena clara',
    '🧏🏽‍♀' => 'mulher surda: pele morena',
    '🧏🏾‍♀' => 'mulher surda: pele morena escura',
    '🧏🏿‍♀' => 'mulher surda: pele escura',
    '🙇🏻‍♂' => 'homem fazendo reverência: pele clara',
    '🙇🏼‍♂' => 'homem fazendo reverência: pele morena clara',
    '🙇🏽‍♂' => 'homem fazendo reverência: pele morena',
    '🙇🏾‍♂' => 'homem fazendo reverência: pele morena escura',
    '🙇🏿‍♂' => 'homem fazendo reverência: pele escura',
    '🙇🏻‍♀' => 'mulher fazendo reverência: pele clara',
    '🙇🏼‍♀' => 'mulher fazendo reverência: pele morena clara',
    '🙇🏽‍♀' => 'mulher fazendo reverência: pele morena',
    '🙇🏾‍♀' => 'mulher fazendo reverência: pele morena escura',
    '🙇🏿‍♀' => 'mulher fazendo reverência: pele escura',
    '🤦🏻‍♂' => 'homem decepcionado: pele clara',
    '🤦🏼‍♂' => 'homem decepcionado: pele morena clara',
    '🤦🏽‍♂' => 'homem decepcionado: pele morena',
    '🤦🏾‍♂' => 'homem decepcionado: pele morena escura',
    '🤦🏿‍♂' => 'homem decepcionado: pele escura',
    '🤦🏻‍♀' => 'mulher decepcionada: pele clara',
    '🤦🏼‍♀' => 'mulher decepcionada: pele morena clara',
    '🤦🏽‍♀' => 'mulher decepcionada: pele morena',
    '🤦🏾‍♀' => 'mulher decepcionada: pele morena escura',
    '🤦🏿‍♀' => 'mulher decepcionada: pele escura',
    '🤷🏻‍♂' => 'homem dando de ombros: pele clara',
    '🤷🏼‍♂' => 'homem dando de ombros: pele morena clara',
    '🤷🏽‍♂' => 'homem dando de ombros: pele morena',
    '🤷🏾‍♂' => 'homem dando de ombros: pele morena escura',
    '🤷🏿‍♂' => 'homem dando de ombros: pele escura',
    '🤷🏻‍♀' => 'mulher dando de ombros: pele clara',
    '🤷🏼‍♀' => 'mulher dando de ombros: pele morena clara',
    '🤷🏽‍♀' => 'mulher dando de ombros: pele morena',
    '🤷🏾‍♀' => 'mulher dando de ombros: pele morena escura',
    '🤷🏿‍♀' => 'mulher dando de ombros: pele escura',
    '🧑🏻‍⚕' => 'profissional de saúde: pele clara',
    '🧑🏼‍⚕' => 'profissional de saúde: pele morena clara',
    '🧑🏽‍⚕' => 'profissional de saúde: pele morena',
    '🧑🏾‍⚕' => 'profissional de saúde: pele morena escura',
    '🧑🏿‍⚕' => 'profissional de saúde: pele escura',
    '👨🏻‍⚕' => 'homem profissional da saúde: pele clara',
    '👨🏼‍⚕' => 'homem profissional da saúde: pele morena clara',
    '👨🏽‍⚕' => 'homem profissional da saúde: pele morena',
    '👨🏾‍⚕' => 'homem profissional da saúde: pele morena escura',
    '👨🏿‍⚕' => 'homem profissional da saúde: pele escura',
    '👩🏻‍⚕' => 'mulher profissional da saúde: pele clara',
    '👩🏼‍⚕' => 'mulher profissional da saúde: pele morena clara',
    '👩🏽‍⚕' => 'mulher profissional da saúde: pele morena',
    '👩🏾‍⚕' => 'mulher profissional da saúde: pele morena escura',
    '👩🏿‍⚕' => 'mulher profissional da saúde: pele escura',
    '🧑🏻‍🎓' => 'aluno: pele clara',
    '🧑🏼‍🎓' => 'aluno: pele morena clara',
    '🧑🏽‍🎓' => 'aluno: pele morena',
    '🧑🏾‍🎓' => 'aluno: pele morena escura',
    '🧑🏿‍🎓' => 'aluno: pele escura',
    '👨🏻‍🎓' => 'estudante: pele clara',
    '👨🏼‍🎓' => 'estudante: pele morena clara',
    '👨🏽‍🎓' => 'estudante: pele morena',
    '👨🏾‍🎓' => 'estudante: pele morena escura',
    '👨🏿‍🎓' => 'estudante: pele escura',
    '👩🏻‍🎓' => 'aluna: pele clara',
    '👩🏼‍🎓' => 'aluna: pele morena clara',
    '👩🏽‍🎓' => 'aluna: pele morena',
    '👩🏾‍🎓' => 'aluna: pele morena escura',
    '👩🏿‍🎓' => 'aluna: pele escura',
    '🧑🏻‍🏫' => 'professora na escola: pele clara',
    '🧑🏼‍🏫' => 'professora na escola: pele morena clara',
    '🧑🏽‍🏫' => 'professora na escola: pele morena',
    '🧑🏾‍🏫' => 'professora na escola: pele morena escura',
    '🧑🏿‍🏫' => 'professora na escola: pele escura',
    '👨🏻‍🏫' => 'professor: pele clara',
    '👨🏼‍🏫' => 'professor: pele morena clara',
    '👨🏽‍🏫' => 'professor: pele morena',
    '👨🏾‍🏫' => 'professor: pele morena escura',
    '👨🏿‍🏫' => 'professor: pele escura',
    '👩🏻‍🏫' => 'professora: pele clara',
    '👩🏼‍🏫' => 'professora: pele morena clara',
    '👩🏽‍🏫' => 'professora: pele morena',
    '👩🏾‍🏫' => 'professora: pele morena escura',
    '👩🏿‍🏫' => 'professora: pele escura',
    '🧑🏻‍⚖' => 'juiz no tribunal: pele clara',
    '🧑🏼‍⚖' => 'juiz no tribunal: pele morena clara',
    '🧑🏽‍⚖' => 'juiz no tribunal: pele morena',
    '🧑🏾‍⚖' => 'juiz no tribunal: pele morena escura',
    '🧑🏿‍⚖' => 'juiz no tribunal: pele escura',
    '👨🏻‍⚖' => 'juiz: pele clara',
    '👨🏼‍⚖' => 'juiz: pele morena clara',
    '👨🏽‍⚖' => 'juiz: pele morena',
    '👨🏾‍⚖' => 'juiz: pele morena escura',
    '👨🏿‍⚖' => 'juiz: pele escura',
    '👩🏻‍⚖' => 'juíza: pele clara',
    '👩🏼‍⚖' => 'juíza: pele morena clara',
    '👩🏽‍⚖' => 'juíza: pele morena',
    '👩🏾‍⚖' => 'juíza: pele morena escura',
    '👩🏿‍⚖' => 'juíza: pele escura',
    '🧑🏻‍🌾' => 'agricultor: pele clara',
    '🧑🏼‍🌾' => 'agricultor: pele morena clara',
    '🧑🏽‍🌾' => 'agricultor: pele morena',
    '🧑🏾‍🌾' => 'agricultor: pele morena escura',
    '🧑🏿‍🌾' => 'agricultor: pele escura',
    '👨🏻‍🌾' => 'fazendeiro: pele clara',
    '👨🏼‍🌾' => 'fazendeiro: pele morena clara',
    '👨🏽‍🌾' => 'fazendeiro: pele morena',
    '👨🏾‍🌾' => 'fazendeiro: pele morena escura',
    '👨🏿‍🌾' => 'fazendeiro: pele escura',
    '👩🏻‍🌾' => 'fazendeira: pele clara',
    '👩🏼‍🌾' => 'fazendeira: pele morena clara',
    '👩🏽‍🌾' => 'fazendeira: pele morena',
    '👩🏾‍🌾' => 'fazendeira: pele morena escura',
    '👩🏿‍🌾' => 'fazendeira: pele escura',
    '🧑🏻‍🍳' => 'chef de cozinha: pele clara',
    '🧑🏼‍🍳' => 'chef de cozinha: pele morena clara',
    '🧑🏽‍🍳' => 'chef de cozinha: pele morena',
    '🧑🏾‍🍳' => 'chef de cozinha: pele morena escura',
    '🧑🏿‍🍳' => 'chef de cozinha: pele escura',
    '👨🏻‍🍳' => 'cozinheiro: pele clara',
    '👨🏼‍🍳' => 'cozinheiro: pele morena clara',
    '👨🏽‍🍳' => 'cozinheiro: pele morena',
    '👨🏾‍🍳' => 'cozinheiro: pele morena escura',
    '👨🏿‍🍳' => 'cozinheiro: pele escura',
    '👩🏻‍🍳' => 'cozinheira: pele clara',
    '👩🏼‍🍳' => 'cozinheira: pele morena clara',
    '👩🏽‍🍳' => 'cozinheira: pele morena',
    '👩🏾‍🍳' => 'cozinheira: pele morena escura',
    '👩🏿‍🍳' => 'cozinheira: pele escura',
    '🧑🏻‍🔧' => 'mecânico trabalhando: pele clara',
    '🧑🏼‍🔧' => 'mecânico trabalhando: pele morena clara',
    '🧑🏽‍🔧' => 'mecânico trabalhando: pele morena',
    '🧑🏾‍🔧' => 'mecânico trabalhando: pele morena escura',
    '🧑🏿‍🔧' => 'mecânico trabalhando: pele escura',
    '👨🏻‍🔧' => 'mecânico: pele clara',
    '👨🏼‍🔧' => 'mecânico: pele morena clara',
    '👨🏽‍🔧' => 'mecânico: pele morena',
    '👨🏾‍🔧' => 'mecânico: pele morena escura',
    '👨🏿‍🔧' => 'mecânico: pele escura',
    '👩🏻‍🔧' => 'mecânica: pele clara',
    '👩🏼‍🔧' => 'mecânica: pele morena clara',
    '👩🏽‍🔧' => 'mecânica: pele morena',
    '👩🏾‍🔧' => 'mecânica: pele morena escura',
    '👩🏿‍🔧' => 'mecânica: pele escura',
    '🧑🏻‍🏭' => 'funcionário de fábrica: pele clara',
    '🧑🏼‍🏭' => 'funcionário de fábrica: pele morena clara',
    '🧑🏽‍🏭' => 'funcionário de fábrica: pele morena',
    '🧑🏾‍🏭' => 'funcionário de fábrica: pele morena escura',
    '🧑🏿‍🏭' => 'funcionário de fábrica: pele escura',
    '👨🏻‍🏭' => 'operário: pele clara',
    '👨🏼‍🏭' => 'operário: pele morena clara',
    '👨🏽‍🏭' => 'operário: pele morena',
    '👨🏾‍🏭' => 'operário: pele morena escura',
    '👨🏿‍🏭' => 'operário: pele escura',
    '👩🏻‍🏭' => 'operária: pele clara',
    '👩🏼‍🏭' => 'operária: pele morena clara',
    '👩🏽‍🏭' => 'operária: pele morena',
    '👩🏾‍🏭' => 'operária: pele morena escura',
    '👩🏿‍🏭' => 'operária: pele escura',
    '🧑🏻‍💼' => 'trabalhador de escritório: pele clara',
    '🧑🏼‍💼' => 'trabalhador de escritório: pele morena clara',
    '🧑🏽‍💼' => 'trabalhador de escritório: pele morena',
    '🧑🏾‍💼' => 'trabalhador de escritório: pele morena escura',
    '🧑🏿‍💼' => 'trabalhador de escritório: pele escura',
    '👨🏻‍💼' => 'funcionário de escritório: pele clara',
    '👨🏼‍💼' => 'funcionário de escritório: pele morena clara',
    '👨🏽‍💼' => 'funcionário de escritório: pele morena',
    '👨🏾‍💼' => 'funcionário de escritório: pele morena escura',
    '👨🏿‍💼' => 'funcionário de escritório: pele escura',
    '👩🏻‍💼' => 'funcionária de escritório: pele clara',
    '👩🏼‍💼' => 'funcionária de escritório: pele morena clara',
    '👩🏽‍💼' => 'funcionária de escritório: pele morena',
    '👩🏾‍💼' => 'funcionária de escritório: pele morena escura',
    '👩🏿‍💼' => 'funcionária de escritório: pele escura',
    '🧑🏻‍🔬' => 'cientista: pele clara',
    '🧑🏼‍🔬' => 'cientista: pele morena clara',
    '🧑🏽‍🔬' => 'cientista: pele morena',
    '🧑🏾‍🔬' => 'cientista: pele morena escura',
    '🧑🏿‍🔬' => 'cientista: pele escura',
    '👨🏻‍🔬' => 'cientista homem: pele clara',
    '👨🏼‍🔬' => 'cientista homem: pele morena clara',
    '👨🏽‍🔬' => 'cientista homem: pele morena',
    '👨🏾‍🔬' => 'cientista homem: pele morena escura',
    '👨🏿‍🔬' => 'cientista homem: pele escura',
    '👩🏻‍🔬' => 'cientista mulher: pele clara',
    '👩🏼‍🔬' => 'cientista mulher: pele morena clara',
    '👩🏽‍🔬' => 'cientista mulher: pele morena',
    '👩🏾‍🔬' => 'cientista mulher: pele morena escura',
    '👩🏿‍🔬' => 'cientista mulher: pele escura',
    '🧑🏻‍💻' => 'programador: pele clara',
    '🧑🏼‍💻' => 'programador: pele morena clara',
    '🧑🏽‍💻' => 'programador: pele morena',
    '🧑🏾‍💻' => 'programador: pele morena escura',
    '🧑🏿‍💻' => 'programador: pele escura',
    '👨🏻‍💻' => 'tecnólogo: pele clara',
    '👨🏼‍💻' => 'tecnólogo: pele morena clara',
    '👨🏽‍💻' => 'tecnólogo: pele morena',
    '👨🏾‍💻' => 'tecnólogo: pele morena escura',
    '👨🏿‍💻' => 'tecnólogo: pele escura',
    '👩🏻‍💻' => 'tecnóloga: pele clara',
    '👩🏼‍💻' => 'tecnóloga: pele morena clara',
    '👩🏽‍💻' => 'tecnóloga: pele morena',
    '👩🏾‍💻' => 'tecnóloga: pele morena escura',
    '👩🏿‍💻' => 'tecnóloga: pele escura',
    '🧑🏻‍🎤' => 'cantor: pele clara',
    '🧑🏼‍🎤' => 'cantor: pele morena clara',
    '🧑🏽‍🎤' => 'cantor: pele morena',
    '🧑🏾‍🎤' => 'cantor: pele morena escura',
    '🧑🏿‍🎤' => 'cantor: pele escura',
    '👨🏻‍🎤' => 'cantor homem: pele clara',
    '👨🏼‍🎤' => 'cantor homem: pele morena clara',
    '👨🏽‍🎤' => 'cantor homem: pele morena',
    '👨🏾‍🎤' => 'cantor homem: pele morena escura',
    '👨🏿‍🎤' => 'cantor homem: pele escura',
    '👩🏻‍🎤' => 'cantora: pele clara',
    '👩🏼‍🎤' => 'cantora: pele morena clara',
    '👩🏽‍🎤' => 'cantora: pele morena',
    '👩🏾‍🎤' => 'cantora: pele morena escura',
    '👩🏿‍🎤' => 'cantora: pele escura',
    '🧑🏻‍🎨' => 'artista: pele clara',
    '🧑🏼‍🎨' => 'artista: pele morena clara',
    '🧑🏽‍🎨' => 'artista: pele morena',
    '🧑🏾‍🎨' => 'artista: pele morena escura',
    '🧑🏿‍🎨' => 'artista: pele escura',
    '👨🏻‍🎨' => 'artista plástico: pele clara',
    '👨🏼‍🎨' => 'artista plástico: pele morena clara',
    '👨🏽‍🎨' => 'artista plástico: pele morena',
    '👨🏾‍🎨' => 'artista plástico: pele morena escura',
    '👨🏿‍🎨' => 'artista plástico: pele escura',
    '👩🏻‍🎨' => 'artista plástica: pele clara',
    '👩🏼‍🎨' => 'artista plástica: pele morena clara',
    '👩🏽‍🎨' => 'artista plástica: pele morena',
    '👩🏾‍🎨' => 'artista plástica: pele morena escura',
    '👩🏿‍🎨' => 'artista plástica: pele escura',
    '🧑🏻‍✈' => 'piloto: pele clara',
    '🧑🏼‍✈' => 'piloto: pele morena clara',
    '🧑🏽‍✈' => 'piloto: pele morena',
    '🧑🏾‍✈' => 'piloto: pele morena escura',
    '🧑🏿‍✈' => 'piloto: pele escura',
    '👨🏻‍✈' => 'piloto de avião homem: pele clara',
    '👨🏼‍✈' => 'piloto de avião homem: pele morena clara',
    '👨🏽‍✈' => 'piloto de avião homem: pele morena',
    '👨🏾‍✈' => 'piloto de avião homem: pele morena escura',
    '👨🏿‍✈' => 'piloto de avião homem: pele escura',
    '👩🏻‍✈' => 'piloto de avião mulher: pele clara',
    '👩🏼‍✈' => 'piloto de avião mulher: pele morena clara',
    '👩🏽‍✈' => 'piloto de avião mulher: pele morena',
    '👩🏾‍✈' => 'piloto de avião mulher: pele morena escura',
    '👩🏿‍✈' => 'piloto de avião mulher: pele escura',
    '🧑🏻‍🚀' => 'astronauta: pele clara',
    '🧑🏼‍🚀' => 'astronauta: pele morena clara',
    '🧑🏽‍🚀' => 'astronauta: pele morena',
    '🧑🏾‍🚀' => 'astronauta: pele morena escura',
    '🧑🏿‍🚀' => 'astronauta: pele escura',
    '👨🏻‍🚀' => 'astronauta homem: pele clara',
    '👨🏼‍🚀' => 'astronauta homem: pele morena clara',
    '👨🏽‍🚀' => 'astronauta homem: pele morena',
    '👨🏾‍🚀' => 'astronauta homem: pele morena escura',
    '👨🏿‍🚀' => 'astronauta homem: pele escura',
    '👩🏻‍🚀' => 'astronauta mulher: pele clara',
    '👩🏼‍🚀' => 'astronauta mulher: pele morena clara',
    '👩🏽‍🚀' => 'astronauta mulher: pele morena',
    '👩🏾‍🚀' => 'astronauta mulher: pele morena escura',
    '👩🏿‍🚀' => 'astronauta mulher: pele escura',
    '🧑🏻‍🚒' => 'bombeiro: pele clara',
    '🧑🏼‍🚒' => 'bombeiro: pele morena clara',
    '🧑🏽‍🚒' => 'bombeiro: pele morena',
    '🧑🏾‍🚒' => 'bombeiro: pele morena escura',
    '🧑🏿‍🚒' => 'bombeiro: pele escura',
    '👨🏻‍🚒' => 'bombeiro homem: pele clara',
    '👨🏼‍🚒' => 'bombeiro homem: pele morena clara',
    '👨🏽‍🚒' => 'bombeiro homem: pele morena',
    '👨🏾‍🚒' => 'bombeiro homem: pele morena escura',
    '👨🏿‍🚒' => 'bombeiro homem: pele escura',
    '👩🏻‍🚒' => 'bombeira: pele clara',
    '👩🏼‍🚒' => 'bombeira: pele morena clara',
    '👩🏽‍🚒' => 'bombeira: pele morena',
    '👩🏾‍🚒' => 'bombeira: pele morena escura',
    '👩🏿‍🚒' => 'bombeira: pele escura',
    '👮🏻‍♂' => 'policial homem: pele clara',
    '👮🏼‍♂' => 'policial homem: pele morena clara',
    '👮🏽‍♂' => 'policial homem: pele morena',
    '👮🏾‍♂' => 'policial homem: pele morena escura',
    '👮🏿‍♂' => 'policial homem: pele escura',
    '👮🏻‍♀' => 'policial mulher: pele clara',
    '👮🏼‍♀' => 'policial mulher: pele morena clara',
    '👮🏽‍♀' => 'policial mulher: pele morena',
    '👮🏾‍♀' => 'policial mulher: pele morena escura',
    '👮🏿‍♀' => 'policial mulher: pele escura',
    '🕵🏻‍♂' => 'detetive homem: pele clara',
    '🕵🏼‍♂' => 'detetive homem: pele morena clara',
    '🕵🏽‍♂' => 'detetive homem: pele morena',
    '🕵🏾‍♂' => 'detetive homem: pele morena escura',
    '🕵🏿‍♂' => 'detetive homem: pele escura',
    '🕵🏻‍♀' => 'detetive mulher: pele clara',
    '🕵🏼‍♀' => 'detetive mulher: pele morena clara',
    '🕵🏽‍♀' => 'detetive mulher: pele morena',
    '🕵🏾‍♀' => 'detetive mulher: pele morena escura',
    '🕵🏿‍♀' => 'detetive mulher: pele escura',
    '💂🏻‍♂' => 'guarda homem: pele clara',
    '💂🏼‍♂' => 'guarda homem: pele morena clara',
    '💂🏽‍♂' => 'guarda homem: pele morena',
    '💂🏾‍♂' => 'guarda homem: pele morena escura',
    '💂🏿‍♂' => 'guarda homem: pele escura',
    '💂🏻‍♀' => 'guarda mulher: pele clara',
    '💂🏼‍♀' => 'guarda mulher: pele morena clara',
    '💂🏽‍♀' => 'guarda mulher: pele morena',
    '💂🏾‍♀' => 'guarda mulher: pele morena escura',
    '💂🏿‍♀' => 'guarda mulher: pele escura',
    '👷🏻‍♂' => 'pedreiro: pele clara',
    '👷🏼‍♂' => 'pedreiro: pele morena clara',
    '👷🏽‍♂' => 'pedreiro: pele morena',
    '👷🏾‍♂' => 'pedreiro: pele morena escura',
    '👷🏿‍♂' => 'pedreiro: pele escura',
    '👷🏻‍♀' => 'pedreira: pele clara',
    '👷🏼‍♀' => 'pedreira: pele morena clara',
    '👷🏽‍♀' => 'pedreira: pele morena',
    '👷🏾‍♀' => 'pedreira: pele morena escura',
    '👷🏿‍♀' => 'pedreira: pele escura',
    '👳🏻‍♂' => 'homem com turbante: pele clara',
    '👳🏼‍♂' => 'homem com turbante: pele morena clara',
    '👳🏽‍♂' => 'homem com turbante: pele morena',
    '👳🏾‍♂' => 'homem com turbante: pele morena escura',
    '👳🏿‍♂' => 'homem com turbante: pele escura',
    '👳🏻‍♀' => 'mulher com turbante: pele clara',
    '👳🏼‍♀' => 'mulher com turbante: pele morena clara',
    '👳🏽‍♀' => 'mulher com turbante: pele morena',
    '👳🏾‍♀' => 'mulher com turbante: pele morena escura',
    '👳🏿‍♀' => 'mulher com turbante: pele escura',
    '🤵🏻‍♂' => 'homem de smoking: pele clara',
    '🤵🏼‍♂' => 'homem de smoking: pele morena clara',
    '🤵🏽‍♂' => 'homem de smoking: pele morena',
    '🤵🏾‍♂' => 'homem de smoking: pele morena escura',
    '🤵🏿‍♂' => 'homem de smoking: pele escura',
    '🤵🏻‍♀' => 'mulher de smoking: pele clara',
    '🤵🏼‍♀' => 'mulher de smoking: pele morena clara',
    '🤵🏽‍♀' => 'mulher de smoking: pele morena',
    '🤵🏾‍♀' => 'mulher de smoking: pele morena escura',
    '🤵🏿‍♀' => 'mulher de smoking: pele escura',
    '👰🏻‍♂' => 'noivo com véu: pele clara',
    '👰🏼‍♂' => 'noivo com véu: pele morena clara',
    '👰🏽‍♂' => 'noivo com véu: pele morena',
    '👰🏾‍♂' => 'noivo com véu: pele morena escura',
    '👰🏿‍♂' => 'noivo com véu: pele escura',
    '👰🏻‍♀' => 'noiva com véu: pele clara',
    '👰🏼‍♀' => 'noiva com véu: pele morena clara',
    '👰🏽‍♀' => 'noiva com véu: pele morena',
    '👰🏾‍♀' => 'noiva com véu: pele morena escura',
    '👰🏿‍♀' => 'noiva com véu: pele escura',
    '👩🏻‍🍼' => 'mulher alimentando bebê: pele clara',
    '👩🏼‍🍼' => 'mulher alimentando bebê: pele morena clara',
    '👩🏽‍🍼' => 'mulher alimentando bebê: pele morena',
    '👩🏾‍🍼' => 'mulher alimentando bebê: pele morena escura',
    '👩🏿‍🍼' => 'mulher alimentando bebê: pele escura',
    '👨🏻‍🍼' => 'homem alimentando bebê: pele clara',
    '👨🏼‍🍼' => 'homem alimentando bebê: pele morena clara',
    '👨🏽‍🍼' => 'homem alimentando bebê: pele morena',
    '👨🏾‍🍼' => 'homem alimentando bebê: pele morena escura',
    '👨🏿‍🍼' => 'homem alimentando bebê: pele escura',
    '🧑🏻‍🍼' => 'pessoa alimentando bebê: pele clara',
    '🧑🏼‍🍼' => 'pessoa alimentando bebê: pele morena clara',
    '🧑🏽‍🍼' => 'pessoa alimentando bebê: pele morena',
    '🧑🏾‍🍼' => 'pessoa alimentando bebê: pele morena escura',
    '🧑🏿‍🍼' => 'pessoa alimentando bebê: pele escura',
    '🧑🏻‍🎄' => 'noel: pele clara',
    '🧑🏼‍🎄' => 'noel: pele morena clara',
    '🧑🏽‍🎄' => 'noel: pele morena',
    '🧑🏾‍🎄' => 'noel: pele morena escura',
    '🧑🏿‍🎄' => 'noel: pele escura',
    '🦸🏻‍♂' => 'homem super-herói: pele clara',
    '🦸🏼‍♂' => 'homem super-herói: pele morena clara',
    '🦸🏽‍♂' => 'homem super-herói: pele morena',
    '🦸🏾‍♂' => 'homem super-herói: pele morena escura',
    '🦸🏿‍♂' => 'homem super-herói: pele escura',
    '🦸🏻‍♀' => 'super-heroína: pele clara',
    '🦸🏼‍♀' => 'super-heroína: pele morena clara',
    '🦸🏽‍♀' => 'super-heroína: pele morena',
    '🦸🏾‍♀' => 'super-heroína: pele morena escura',
    '🦸🏿‍♀' => 'super-heroína: pele escura',
    '🦹🏻‍♂' => 'homem supervilão: pele clara',
    '🦹🏼‍♂' => 'homem supervilão: pele morena clara',
    '🦹🏽‍♂' => 'homem supervilão: pele morena',
    '🦹🏾‍♂' => 'homem supervilão: pele morena escura',
    '🦹🏿‍♂' => 'homem supervilão: pele escura',
    '🦹🏻‍♀' => 'supervilã: pele clara',
    '🦹🏼‍♀' => 'supervilã: pele morena clara',
    '🦹🏽‍♀' => 'supervilã: pele morena',
    '🦹🏾‍♀' => 'supervilã: pele morena escura',
    '🦹🏿‍♀' => 'supervilã: pele escura',
    '🧙🏻‍♂' => 'homem mago: pele clara',
    '🧙🏼‍♂' => 'homem mago: pele morena clara',
    '🧙🏽‍♂' => 'homem mago: pele morena',
    '🧙🏾‍♂' => 'homem mago: pele morena escura',
    '🧙🏿‍♂' => 'homem mago: pele escura',
    '🧙🏻‍♀' => 'maga: pele clara',
    '🧙🏼‍♀' => 'maga: pele morena clara',
    '🧙🏽‍♀' => 'maga: pele morena',
    '🧙🏾‍♀' => 'maga: pele morena escura',
    '🧙🏿‍♀' => 'maga: pele escura',
    '🧚🏻‍♂' => 'homem fada: pele clara',
    '🧚🏼‍♂' => 'homem fada: pele morena clara',
    '🧚🏽‍♂' => 'homem fada: pele morena',
    '🧚🏾‍♂' => 'homem fada: pele morena escura',
    '🧚🏿‍♂' => 'homem fada: pele escura',
    '🧚🏻‍♀' => 'mulher fada: pele clara',
    '🧚🏼‍♀' => 'mulher fada: pele morena clara',
    '🧚🏽‍♀' => 'mulher fada: pele morena',
    '🧚🏾‍♀' => 'mulher fada: pele morena escura',
    '🧚🏿‍♀' => 'mulher fada: pele escura',
    '🧛🏻‍♂' => 'homem vampiro: pele clara',
    '🧛🏼‍♂' => 'homem vampiro: pele morena clara',
    '🧛🏽‍♂' => 'homem vampiro: pele morena',
    '🧛🏾‍♂' => 'homem vampiro: pele morena escura',
    '🧛🏿‍♂' => 'homem vampiro: pele escura',
    '🧛🏻‍♀' => 'mulher vampira: pele clara',
    '🧛🏼‍♀' => 'mulher vampira: pele morena clara',
    '🧛🏽‍♀' => 'mulher vampira: pele morena',
    '🧛🏾‍♀' => 'mulher vampira: pele morena escura',
    '🧛🏿‍♀' => 'mulher vampira: pele escura',
    '🧜🏻‍♂' => 'sereio: pele clara',
    '🧜🏼‍♂' => 'sereio: pele morena clara',
    '🧜🏽‍♂' => 'sereio: pele morena',
    '🧜🏾‍♂' => 'sereio: pele morena escura',
    '🧜🏿‍♂' => 'sereio: pele escura',
    '🧜🏻‍♀' => 'sereia: pele clara',
    '🧜🏼‍♀' => 'sereia: pele morena clara',
    '🧜🏽‍♀' => 'sereia: pele morena',
    '🧜🏾‍♀' => 'sereia: pele morena escura',
    '🧜🏿‍♀' => 'sereia: pele escura',
    '🧝🏻‍♂' => 'elfo homem: pele clara',
    '🧝🏼‍♂' => 'elfo homem: pele morena clara',
    '🧝🏽‍♂' => 'elfo homem: pele morena',
    '🧝🏾‍♂' => 'elfo homem: pele morena escura',
    '🧝🏿‍♂' => 'elfo homem: pele escura',
    '🧝🏻‍♀' => 'elfa: pele clara',
    '🧝🏼‍♀' => 'elfa: pele morena clara',
    '🧝🏽‍♀' => 'elfa: pele morena',
    '🧝🏾‍♀' => 'elfa: pele morena escura',
    '🧝🏿‍♀' => 'elfa: pele escura',
    '💆🏻‍♂' => 'homem recebendo massagem facial: pele clara',
    '💆🏼‍♂' => 'homem recebendo massagem facial: pele morena clara',
    '💆🏽‍♂' => 'homem recebendo massagem facial: pele morena',
    '💆🏾‍♂' => 'homem recebendo massagem facial: pele morena escura',
    '💆🏿‍♂' => 'homem recebendo massagem facial: pele escura',
    '💆🏻‍♀' => 'mulher recebendo massagem facial: pele clara',
    '💆🏼‍♀' => 'mulher recebendo massagem facial: pele morena clara',
    '💆🏽‍♀' => 'mulher recebendo massagem facial: pele morena',
    '💆🏾‍♀' => 'mulher recebendo massagem facial: pele morena escura',
    '💆🏿‍♀' => 'mulher recebendo massagem facial: pele escura',
    '💇🏻‍♂' => 'homem cortando o cabelo: pele clara',
    '💇🏼‍♂' => 'homem cortando o cabelo: pele morena clara',
    '💇🏽‍♂' => 'homem cortando o cabelo: pele morena',
    '💇🏾‍♂' => 'homem cortando o cabelo: pele morena escura',
    '💇🏿‍♂' => 'homem cortando o cabelo: pele escura',
    '💇🏻‍♀' => 'mulher cortando o cabelo: pele clara',
    '💇🏼‍♀' => 'mulher cortando o cabelo: pele morena clara',
    '💇🏽‍♀' => 'mulher cortando o cabelo: pele morena',
    '💇🏾‍♀' => 'mulher cortando o cabelo: pele morena escura',
    '💇🏿‍♀' => 'mulher cortando o cabelo: pele escura',
    '🚶🏻‍♂' => 'homem andando: pele clara',
    '🚶🏼‍♂' => 'homem andando: pele morena clara',
    '🚶🏽‍♂' => 'homem andando: pele morena',
    '🚶🏾‍♂' => 'homem andando: pele morena escura',
    '🚶🏿‍♂' => 'homem andando: pele escura',
    '🚶🏻‍♀' => 'mulher andando: pele clara',
    '🚶🏼‍♀' => 'mulher andando: pele morena clara',
    '🚶🏽‍♀' => 'mulher andando: pele morena',
    '🚶🏾‍♀' => 'mulher andando: pele morena escura',
    '🚶🏿‍♀' => 'mulher andando: pele escura',
    '🚶🏻‍➡' => 'pessoa andando: pele clara e de frente para a direita',
    '🚶🏼‍➡' => 'pessoa andando: pele morena clara e de frente para a direita',
    '🚶🏽‍➡' => 'pessoa andando: pele morena e de frente para a direita',
    '🚶🏾‍➡' => 'pessoa andando: pele morena escura e de frente para a direita',
    '🚶🏿‍➡' => 'pessoa andando: pele escura e de frente para a direita',
    '🧍🏻‍♂' => 'homem em pé: pele clara',
    '🧍🏼‍♂' => 'homem em pé: pele morena clara',
    '🧍🏽‍♂' => 'homem em pé: pele morena',
    '🧍🏾‍♂' => 'homem em pé: pele morena escura',
    '🧍🏿‍♂' => 'homem em pé: pele escura',
    '🧍🏻‍♀' => 'mulher em pé: pele clara',
    '🧍🏼‍♀' => 'mulher em pé: pele morena clara',
    '🧍🏽‍♀' => 'mulher em pé: pele morena',
    '🧍🏾‍♀' => 'mulher em pé: pele morena escura',
    '🧍🏿‍♀' => 'mulher em pé: pele escura',
    '🧎🏻‍♂' => 'homem ajoelhando: pele clara',
    '🧎🏼‍♂' => 'homem ajoelhando: pele morena clara',
    '🧎🏽‍♂' => 'homem ajoelhando: pele morena',
    '🧎🏾‍♂' => 'homem ajoelhando: pele morena escura',
    '🧎🏿‍♂' => 'homem ajoelhando: pele escura',
    '🧎🏻‍♀' => 'mulher ajoelhando: pele clara',
    '🧎🏼‍♀' => 'mulher ajoelhando: pele morena clara',
    '🧎🏽‍♀' => 'mulher ajoelhando: pele morena',
    '🧎🏾‍♀' => 'mulher ajoelhando: pele morena escura',
    '🧎🏿‍♀' => 'mulher ajoelhando: pele escura',
    '🧎🏻‍➡' => 'pessoa ajoelhando: pele clara e de frente para a direita',
    '🧎🏼‍➡' => 'pessoa ajoelhando: pele morena clara e de frente para a direita',
    '🧎🏽‍➡' => 'pessoa ajoelhando: pele morena e de frente para a direita',
    '🧎🏾‍➡' => 'pessoa ajoelhando: pele morena escura e de frente para a direita',
    '🧎🏿‍➡' => 'pessoa ajoelhando: pele escura e de frente para a direita',
    '🧑🏻‍🦯' => 'pessoa com bengala para cego: pele clara',
    '🧑🏼‍🦯' => 'pessoa com bengala para cego: pele morena clara',
    '🧑🏽‍🦯' => 'pessoa com bengala para cego: pele morena',
    '🧑🏾‍🦯' => 'pessoa com bengala para cego: pele morena escura',
    '🧑🏿‍🦯' => 'pessoa com bengala para cego: pele escura',
    '👨🏻‍🦯' => 'homem com bengala para cego: pele clara',
    '👨🏼‍🦯' => 'homem com bengala para cego: pele morena clara',
    '👨🏽‍🦯' => 'homem com bengala para cego: pele morena',
    '👨🏾‍🦯' => 'homem com bengala para cego: pele morena escura',
    '👨🏿‍🦯' => 'homem com bengala para cego: pele escura',
    '👩🏻‍🦯' => 'mulher com bengala para cego: pele clara',
    '👩🏼‍🦯' => 'mulher com bengala para cego: pele morena clara',
    '👩🏽‍🦯' => 'mulher com bengala para cego: pele morena',
    '👩🏾‍🦯' => 'mulher com bengala para cego: pele morena escura',
    '👩🏿‍🦯' => 'mulher com bengala para cego: pele escura',
    '🧑🏻‍🦼' => 'pessoa em cadeira de rodas motorizada: pele clara',
    '🧑🏼‍🦼' => 'pessoa em cadeira de rodas motorizada: pele morena clara',
    '🧑🏽‍🦼' => 'pessoa em cadeira de rodas motorizada: pele morena',
    '🧑🏾‍🦼' => 'pessoa em cadeira de rodas motorizada: pele morena escura',
    '🧑🏿‍🦼' => 'pessoa em cadeira de rodas motorizada: pele escura',
    '👨🏻‍🦼' => 'homem em cadeira de rodas motorizada: pele clara',
    '👨🏼‍🦼' => 'homem em cadeira de rodas motorizada: pele morena clara',
    '👨🏽‍🦼' => 'homem em cadeira de rodas motorizada: pele morena',
    '👨🏾‍🦼' => 'homem em cadeira de rodas motorizada: pele morena escura',
    '👨🏿‍🦼' => 'homem em cadeira de rodas motorizada: pele escura',
    '👩🏻‍🦼' => 'mulher em cadeira de rodas motorizada: pele clara',
    '👩🏼‍🦼' => 'mulher em cadeira de rodas motorizada: pele morena clara',
    '👩🏽‍🦼' => 'mulher em cadeira de rodas motorizada: pele morena',
    '👩🏾‍🦼' => 'mulher em cadeira de rodas motorizada: pele morena escura',
    '👩🏿‍🦼' => 'mulher em cadeira de rodas motorizada: pele escura',
    '🧑🏻‍🦽' => 'pessoa em cadeira de rodas manual: pele clara',
    '🧑🏼‍🦽' => 'pessoa em cadeira de rodas manual: pele morena clara',
    '🧑🏽‍🦽' => 'pessoa em cadeira de rodas manual: pele morena',
    '🧑🏾‍🦽' => 'pessoa em cadeira de rodas manual: pele morena escura',
    '🧑🏿‍🦽' => 'pessoa em cadeira de rodas manual: pele escura',
    '👨🏻‍🦽' => 'homem em cadeira de rodas manual: pele clara',
    '👨🏼‍🦽' => 'homem em cadeira de rodas manual: pele morena clara',
    '👨🏽‍🦽' => 'homem em cadeira de rodas manual: pele morena',
    '👨🏾‍🦽' => 'homem em cadeira de rodas manual: pele morena escura',
    '👨🏿‍🦽' => 'homem em cadeira de rodas manual: pele escura',
    '👩🏻‍🦽' => 'mulher em cadeira de rodas manual: pele clara',
    '👩🏼‍🦽' => 'mulher em cadeira de rodas manual: pele morena clara',
    '👩🏽‍🦽' => 'mulher em cadeira de rodas manual: pele morena',
    '👩🏾‍🦽' => 'mulher em cadeira de rodas manual: pele morena escura',
    '👩🏿‍🦽' => 'mulher em cadeira de rodas manual: pele escura',
    '🏃🏻‍♂' => 'homem correndo: pele clara',
    '🏃🏼‍♂' => 'homem correndo: pele morena clara',
    '🏃🏽‍♂' => 'homem correndo: pele morena',
    '🏃🏾‍♂' => 'homem correndo: pele morena escura',
    '🏃🏿‍♂' => 'homem correndo: pele escura',
    '🏃🏻‍♀' => 'mulher correndo: pele clara',
    '🏃🏼‍♀' => 'mulher correndo: pele morena clara',
    '🏃🏽‍♀' => 'mulher correndo: pele morena',
    '🏃🏾‍♀' => 'mulher correndo: pele morena escura',
    '🏃🏿‍♀' => 'mulher correndo: pele escura',
    '🏃🏻‍➡' => 'pessoa correndo: pele clara e de frente para a direita',
    '🏃🏼‍➡' => 'pessoa correndo: pele morena clara e de frente para a direita',
    '🏃🏽‍➡' => 'pessoa correndo: pele morena e de frente para a direita',
    '🏃🏾‍➡' => 'pessoa correndo: pele morena escura e de frente para a direita',
    '🏃🏿‍➡' => 'pessoa correndo: pele escura e de frente para a direita',
    '👯🏻‍♀' => 'mulheres com orelhas de coelho: pele clara',
    '👯🏼‍♀' => 'mulheres com orelhas de coelho: pele morena clara',
    '👯🏽‍♀' => 'mulheres com orelhas de coelho: pele morena',
    '👯🏾‍♀' => 'mulheres com orelhas de coelho: pele morena escura',
    '👯🏿‍♀' => 'mulheres com orelhas de coelho: pele escura',
    '👯🏻‍♂' => 'homens com orelhas de coelho: pele clara',
    '👯🏼‍♂' => 'homens com orelhas de coelho: pele morena clara',
    '👯🏽‍♂' => 'homens com orelhas de coelho: pele morena',
    '👯🏾‍♂' => 'homens com orelhas de coelho: pele morena escura',
    '👯🏿‍♂' => 'homens com orelhas de coelho: pele escura',
    '🧖🏻‍♂' => 'homem na sauna: pele clara',
    '🧖🏼‍♂' => 'homem na sauna: pele morena clara',
    '🧖🏽‍♂' => 'homem na sauna: pele morena',
    '🧖🏾‍♂' => 'homem na sauna: pele morena escura',
    '🧖🏿‍♂' => 'homem na sauna: pele escura',
    '🧖🏻‍♀' => 'mulher na sauna: pele clara',
    '🧖🏼‍♀' => 'mulher na sauna: pele morena clara',
    '🧖🏽‍♀' => 'mulher na sauna: pele morena',
    '🧖🏾‍♀' => 'mulher na sauna: pele morena escura',
    '🧖🏿‍♀' => 'mulher na sauna: pele escura',
    '🧗🏻‍♂' => 'homem escalando: pele clara',
    '🧗🏼‍♂' => 'homem escalando: pele morena clara',
    '🧗🏽‍♂' => 'homem escalando: pele morena',
    '🧗🏾‍♂' => 'homem escalando: pele morena escura',
    '🧗🏿‍♂' => 'homem escalando: pele escura',
    '🧗🏻‍♀' => 'mulher escalando: pele clara',
    '🧗🏼‍♀' => 'mulher escalando: pele morena clara',
    '🧗🏽‍♀' => 'mulher escalando: pele morena',
    '🧗🏾‍♀' => 'mulher escalando: pele morena escura',
    '🧗🏿‍♀' => 'mulher escalando: pele escura',
    '🏌🏻‍♂' => 'homem golfista: pele clara',
    '🏌🏼‍♂' => 'homem golfista: pele morena clara',
    '🏌🏽‍♂' => 'homem golfista: pele morena',
    '🏌🏾‍♂' => 'homem golfista: pele morena escura',
    '🏌🏿‍♂' => 'homem golfista: pele escura',
    '🏌🏻‍♀' => 'mulher golfista: pele clara',
    '🏌🏼‍♀' => 'mulher golfista: pele morena clara',
    '🏌🏽‍♀' => 'mulher golfista: pele morena',
    '🏌🏾‍♀' => 'mulher golfista: pele morena escura',
    '🏌🏿‍♀' => 'mulher golfista: pele escura',
    '🏄🏻‍♂' => 'homem surfista: pele clara',
    '🏄🏼‍♂' => 'homem surfista: pele morena clara',
    '🏄🏽‍♂' => 'homem surfista: pele morena',
    '🏄🏾‍♂' => 'homem surfista: pele morena escura',
    '🏄🏿‍♂' => 'homem surfista: pele escura',
    '🏄🏻‍♀' => 'mulher surfista: pele clara',
    '🏄🏼‍♀' => 'mulher surfista: pele morena clara',
    '🏄🏽‍♀' => 'mulher surfista: pele morena',
    '🏄🏾‍♀' => 'mulher surfista: pele morena escura',
    '🏄🏿‍♀' => 'mulher surfista: pele escura',
    '🚣🏻‍♂' => 'homem remando: pele clara',
    '🚣🏼‍♂' => 'homem remando: pele morena clara',
    '🚣🏽‍♂' => 'homem remando: pele morena',
    '🚣🏾‍♂' => 'homem remando: pele morena escura',
    '🚣🏿‍♂' => 'homem remando: pele escura',
    '🚣🏻‍♀' => 'mulher remando: pele clara',
    '🚣🏼‍♀' => 'mulher remando: pele morena clara',
    '🚣🏽‍♀' => 'mulher remando: pele morena',
    '🚣🏾‍♀' => 'mulher remando: pele morena escura',
    '🚣🏿‍♀' => 'mulher remando: pele escura',
    '🏊🏻‍♂' => 'homem nadando: pele clara',
    '🏊🏼‍♂' => 'homem nadando: pele morena clara',
    '🏊🏽‍♂' => 'homem nadando: pele morena',
    '🏊🏾‍♂' => 'homem nadando: pele morena escura',
    '🏊🏿‍♂' => 'homem nadando: pele escura',
    '🏊🏻‍♀' => 'mulher nadando: pele clara',
    '🏊🏼‍♀' => 'mulher nadando: pele morena clara',
    '🏊🏽‍♀' => 'mulher nadando: pele morena',
    '🏊🏾‍♀' => 'mulher nadando: pele morena escura',
    '🏊🏿‍♀' => 'mulher nadando: pele escura',
    '⛹🏻‍♂' => 'homem jogando basquete: pele clara',
    '⛹🏼‍♂' => 'homem jogando basquete: pele morena clara',
    '⛹🏽‍♂' => 'homem jogando basquete: pele morena',
    '⛹🏾‍♂' => 'homem jogando basquete: pele morena escura',
    '⛹🏿‍♂' => 'homem jogando basquete: pele escura',
    '⛹🏻‍♀' => 'mulher jogando basquete: pele clara',
    '⛹🏼‍♀' => 'mulher jogando basquete: pele morena clara',
    '⛹🏽‍♀' => 'mulher jogando basquete: pele morena',
    '⛹🏾‍♀' => 'mulher jogando basquete: pele morena escura',
    '⛹🏿‍♀' => 'mulher jogando basquete: pele escura',
    '🏋🏻‍♂' => 'homem levantando peso: pele clara',
    '🏋🏼‍♂' => 'homem levantando peso: pele morena clara',
    '🏋🏽‍♂' => 'homem levantando peso: pele morena',
    '🏋🏾‍♂' => 'homem levantando peso: pele morena escura',
    '🏋🏿‍♂' => 'homem levantando peso: pele escura',
    '🏋🏻‍♀' => 'mulher levantando peso: pele clara',
    '🏋🏼‍♀' => 'mulher levantando peso: pele morena clara',
    '🏋🏽‍♀' => 'mulher levantando peso: pele morena',
    '🏋🏾‍♀' => 'mulher levantando peso: pele morena escura',
    '🏋🏿‍♀' => 'mulher levantando peso: pele escura',
    '🚴🏻‍♂' => 'homem ciclista: pele clara',
    '🚴🏼‍♂' => 'homem ciclista: pele morena clara',
    '🚴🏽‍♂' => 'homem ciclista: pele morena',
    '🚴🏾‍♂' => 'homem ciclista: pele morena escura',
    '🚴🏿‍♂' => 'homem ciclista: pele escura',
    '🚴🏻‍♀' => 'mulher ciclista: pele clara',
    '🚴🏼‍♀' => 'mulher ciclista: pele morena clara',
    '🚴🏽‍♀' => 'mulher ciclista: pele morena',
    '🚴🏾‍♀' => 'mulher ciclista: pele morena escura',
    '🚴🏿‍♀' => 'mulher ciclista: pele escura',
    '🚵🏻‍♂' => 'homem fazendo mountain bike: pele clara',
    '🚵🏼‍♂' => 'homem fazendo mountain bike: pele morena clara',
    '🚵🏽‍♂' => 'homem fazendo mountain bike: pele morena',
    '🚵🏾‍♂' => 'homem fazendo mountain bike: pele morena escura',
    '🚵🏿‍♂' => 'homem fazendo mountain bike: pele escura',
    '🚵🏻‍♀' => 'mulher fazendo mountain bike: pele clara',
    '🚵🏼‍♀' => 'mulher fazendo mountain bike: pele morena clara',
    '🚵🏽‍♀' => 'mulher fazendo mountain bike: pele morena',
    '🚵🏾‍♀' => 'mulher fazendo mountain bike: pele morena escura',
    '🚵🏿‍♀' => 'mulher fazendo mountain bike: pele escura',
    '🤸🏻‍♂' => 'homem fazendo estrela: pele clara',
    '🤸🏼‍♂' => 'homem fazendo estrela: pele morena clara',
    '🤸🏽‍♂' => 'homem fazendo estrela: pele morena',
    '🤸🏾‍♂' => 'homem fazendo estrela: pele morena escura',
    '🤸🏿‍♂' => 'homem fazendo estrela: pele escura',
    '🤸🏻‍♀' => 'mulher fazendo estrela: pele clara',
    '🤸🏼‍♀' => 'mulher fazendo estrela: pele morena clara',
    '🤸🏽‍♀' => 'mulher fazendo estrela: pele morena',
    '🤸🏾‍♀' => 'mulher fazendo estrela: pele morena escura',
    '🤸🏿‍♀' => 'mulher fazendo estrela: pele escura',
    '🤼🏻‍♀' => 'mulheres lutando: pele clara',
    '🤼🏼‍♀' => 'mulheres lutando: pele morena clara',
    '🤼🏽‍♀' => 'mulheres lutando: pele morena',
    '🤼🏾‍♀' => 'mulheres lutando: pele morena escura',
    '🤼🏿‍♀' => 'mulheres lutando: pele escura',
    '🤼🏻‍♂' => 'homens lutando: pele clara',
    '🤼🏼‍♂' => 'homens lutando: pele morena clara',
    '🤼🏽‍♂' => 'homens lutando: pele morena',
    '🤼🏾‍♂' => 'homens lutando: pele morena escura',
    '🤼🏿‍♂' => 'homens lutando: pele escura',
    '🤽🏻‍♂' => 'homem jogando polo aquático: pele clara',
    '🤽🏼‍♂' => 'homem jogando polo aquático: pele morena clara',
    '🤽🏽‍♂' => 'homem jogando polo aquático: pele morena',
    '🤽🏾‍♂' => 'homem jogando polo aquático: pele morena escura',
    '🤽🏿‍♂' => 'homem jogando polo aquático: pele escura',
    '🤽🏻‍♀' => 'mulher jogando polo aquático: pele clara',
    '🤽🏼‍♀' => 'mulher jogando polo aquático: pele morena clara',
    '🤽🏽‍♀' => 'mulher jogando polo aquático: pele morena',
    '🤽🏾‍♀' => 'mulher jogando polo aquático: pele morena escura',
    '🤽🏿‍♀' => 'mulher jogando polo aquático: pele escura',
    '🤾🏻‍♂' => 'jogador de handebol: pele clara',
    '🤾🏼‍♂' => 'jogador de handebol: pele morena clara',
    '🤾🏽‍♂' => 'jogador de handebol: pele morena',
    '🤾🏾‍♂' => 'jogador de handebol: pele morena escura',
    '🤾🏿‍♂' => 'jogador de handebol: pele escura',
    '🤾🏻‍♀' => 'jogadora de handebol: pele clara',
    '🤾🏼‍♀' => 'jogadora de handebol: pele morena clara',
    '🤾🏽‍♀' => 'jogadora de handebol: pele morena',
    '🤾🏾‍♀' => 'jogadora de handebol: pele morena escura',
    '🤾🏿‍♀' => 'jogadora de handebol: pele escura',
    '🤹🏻‍♂' => 'homem malabarista: pele clara',
    '🤹🏼‍♂' => 'homem malabarista: pele morena clara',
    '🤹🏽‍♂' => 'homem malabarista: pele morena',
    '🤹🏾‍♂' => 'homem malabarista: pele morena escura',
    '🤹🏿‍♂' => 'homem malabarista: pele escura',
    '🤹🏻‍♀' => 'mulher malabarista: pele clara',
    '🤹🏼‍♀' => 'mulher malabarista: pele morena clara',
    '🤹🏽‍♀' => 'mulher malabarista: pele morena',
    '🤹🏾‍♀' => 'mulher malabarista: pele morena escura',
    '🤹🏿‍♀' => 'mulher malabarista: pele escura',
    '🧘🏻‍♂' => 'homem na posição de lótus: pele clara',
    '🧘🏼‍♂' => 'homem na posição de lótus: pele morena clara',
    '🧘🏽‍♂' => 'homem na posição de lótus: pele morena',
    '🧘🏾‍♂' => 'homem na posição de lótus: pele morena escura',
    '🧘🏿‍♂' => 'homem na posição de lótus: pele escura',
    '🧘🏻‍♀' => 'mulher na posição de lótus: pele clara',
    '🧘🏼‍♀' => 'mulher na posição de lótus: pele morena clara',
    '🧘🏽‍♀' => 'mulher na posição de lótus: pele morena',
    '🧘🏾‍♀' => 'mulher na posição de lótus: pele morena escura',
    '🧘🏿‍♀' => 'mulher na posição de lótus: pele escura',
    '🧑‍🦰' => 'pessoa: cabelo vermelho',
    '🧑‍🦱' => 'pessoa: cabelo cacheado',
    '🧑‍🦳' => 'pessoa: cabelo branco',
    '🧑‍🦲' => 'pessoa: careca',
    '👨‍🦰' => 'homem: cabelo vermelho',
    '👨‍🦱' => 'homem: cabelo cacheado',
    '👨‍🦳' => 'homem: cabelo branco',
    '👨‍🦲' => 'homem: careca',
    '👩‍🦰' => 'mulher: cabelo vermelho',
    '👩‍🦱' => 'mulher: cabelo cacheado',
    '👩‍🦳' => 'mulher: cabelo branco',
    '👩‍🦲' => 'mulher: careca',
    '🚶‍➡' => 'pessoa andando: de frente para a direita',
    '🧎‍➡' => 'pessoa ajoelhando: de frente para a direita',
    '🏃‍➡' => 'pessoa correndo: de frente para a direita',
    '👨‍👦' => 'família: homem e menino',
    '👨‍👧' => 'família: homem e menina',
    '👩‍👦' => 'família: mulher e menino',
    '👩‍👧' => 'família: mulher e menina',
    '😶‍🌫' => 'rosto nas nuvens',
    '😮‍💨' => 'rosto exalando',
    '🙂‍↕' => 'cabeça balançando na vertical',
    '😵‍💫' => 'rosto com olhos em espiral',
    '❤‍🔥' => 'coração em chamas',
    '❤‍🩹' => 'coração remendado',
    '👁‍🗨' => 'olho no balão de diálogo',
    '🧔‍♂' => 'homem: barbudo',
    '👱‍♂' => 'homem: cabelo loiro',
    '🧔‍♀' => 'mulher: barba',
    '👱‍♀' => 'mulher: cabelo loiro',
    '🙍‍♂' => 'homem franzindo a sobrancelha',
    '🙍‍♀' => 'mulher franzindo a sobrancelha',
    '🙎‍♂' => 'homem fazendo bico',
    '🙎‍♀' => 'mulher fazendo bico',
    '🙅‍♂' => 'homem fazendo gesto de “não”',
    '🙅‍♀' => 'mulher fazendo gesto de “não”',
    '🙆‍♂' => 'homem fazendo gesto de “OK”',
    '🙆‍♀' => 'mulher fazendo gesto de “OK”',
    '💁‍♂' => 'homem com a palma virada para cima',
    '💁‍♀' => 'mulher com a palma virada para cima',
    '🙋‍♂' => 'homem levantando a mão',
    '🙋‍♀' => 'mulher levantando a mão',
    '🧏‍♂' => 'homem surdo',
    '🧏‍♀' => 'mulher surda',
    '🙇‍♂' => 'homem fazendo reverência',
    '🙇‍♀' => 'mulher fazendo reverência',
    '🤦‍♂' => 'homem decepcionado',
    '🤦‍♀' => 'mulher decepcionada',
    '🤷‍♂' => 'homem dando de ombros',
    '🤷‍♀' => 'mulher dando de ombros',
    '🧑‍⚕' => 'profissional de saúde',
    '👨‍⚕' => 'homem profissional da saúde',
    '👩‍⚕' => 'mulher profissional da saúde',
    '🧑‍🎓' => 'aluno',
    '👨‍🎓' => 'estudante',
    '👩‍🎓' => 'aluna',
    '🧑‍🏫' => 'professora na escola',
    '👨‍🏫' => 'professor',
    '👩‍🏫' => 'professora',
    '🧑‍⚖' => 'juiz no tribunal',
    '👨‍⚖' => 'juiz',
    '👩‍⚖' => 'juíza',
    '🧑‍🌾' => 'agricultor',
    '👨‍🌾' => 'fazendeiro',
    '👩‍🌾' => 'fazendeira',
    '🧑‍🍳' => 'chef de cozinha',
    '👨‍🍳' => 'cozinheiro',
    '👩‍🍳' => 'cozinheira',
    '🧑‍🔧' => 'mecânico trabalhando',
    '👨‍🔧' => 'mecânico',
    '👩‍🔧' => 'mecânica',
    '🧑‍🏭' => 'funcionário de fábrica',
    '👨‍🏭' => 'operário',
    '👩‍🏭' => 'operária',
    '🧑‍💼' => 'trabalhador de escritório',
    '👨‍💼' => 'funcionário de escritório',
    '👩‍💼' => 'funcionária de escritório',
    '🧑‍🔬' => 'cientista',
    '👨‍🔬' => 'cientista homem',
    '👩‍🔬' => 'cientista mulher',
    '🧑‍💻' => 'programador',
    '👨‍💻' => 'tecnólogo',
    '👩‍💻' => 'tecnóloga',
    '🧑‍🎤' => 'cantor',
    '👨‍🎤' => 'cantor homem',
    '👩‍🎤' => 'cantora',
    '🧑‍🎨' => 'artista',
    '👨‍🎨' => 'artista plástico',
    '👩‍🎨' => 'artista plástica',
    '🧑‍✈' => 'piloto',
    '👨‍✈' => 'piloto de avião homem',
    '👩‍✈' => 'piloto de avião mulher',
    '🧑‍🚀' => 'astronauta',
    '👨‍🚀' => 'astronauta homem',
    '👩‍🚀' => 'astronauta mulher',
    '🧑‍🚒' => 'bombeiro',
    '👨‍🚒' => 'bombeiro homem',
    '👩‍🚒' => 'bombeira',
    '👮‍♂' => 'policial homem',
    '👮‍♀' => 'policial mulher',
    '🕵‍♂' => 'detetive homem',
    '🕵‍♀' => 'detetive mulher',
    '💂‍♂' => 'guarda homem',
    '💂‍♀' => 'guarda mulher',
    '👷‍♂' => 'pedreiro',
    '👷‍♀' => 'pedreira',
    '👳‍♂' => 'homem com turbante',
    '👳‍♀' => 'mulher com turbante',
    '🤵‍♂' => 'homem de smoking',
    '🤵‍♀' => 'mulher de smoking',
    '👰‍♂' => 'noivo com véu',
    '👰‍♀' => 'noiva com véu',
    '👩‍🍼' => 'mulher alimentando bebê',
    '👨‍🍼' => 'homem alimentando bebê',
    '🧑‍🍼' => 'pessoa alimentando bebê',
    '🧑‍🎄' => 'noel',
    '🦸‍♂' => 'homem super-herói',
    '🦸‍♀' => 'super-heroína',
    '🦹‍♂' => 'homem supervilão',
    '🦹‍♀' => 'supervilã',
    '🧙‍♂' => 'homem mago',
    '🧙‍♀' => 'maga',
    '🧚‍♂' => 'homem fada',
    '🧚‍♀' => 'mulher fada',
    '🧛‍♂' => 'homem vampiro',
    '🧛‍♀' => 'mulher vampira',
    '🧜‍♂' => 'sereio',
    '🧜‍♀' => 'sereia',
    '🧝‍♂' => 'elfo homem',
    '🧝‍♀' => 'elfa',
    '🧞‍♂' => 'homem gênio',
    '🧞‍♀' => 'mulher gênio',
    '🧟‍♂' => 'homem zumbi',
    '🧟‍♀' => 'mulher zumbi',
    '💆‍♂' => 'homem recebendo massagem facial',
    '💆‍♀' => 'mulher recebendo massagem facial',
    '💇‍♂' => 'homem cortando o cabelo',
    '💇‍♀' => 'mulher cortando o cabelo',
    '🚶‍♂' => 'homem andando',
    '🚶‍♀' => 'mulher andando',
    '🧍‍♂' => 'homem em pé',
    '🧍‍♀' => 'mulher em pé',
    '🧎‍♂' => 'homem ajoelhando',
    '🧎‍♀' => 'mulher ajoelhando',
    '🧑‍🦯' => 'pessoa com bengala para cego',
    '👨‍🦯' => 'homem com bengala para cego',
    '👩‍🦯' => 'mulher com bengala para cego',
    '🧑‍🦼' => 'pessoa em cadeira de rodas motorizada',
    '👨‍🦼' => 'homem em cadeira de rodas motorizada',
    '👩‍🦼' => 'mulher em cadeira de rodas motorizada',
    '🧑‍🦽' => 'pessoa em cadeira de rodas manual',
    '👨‍🦽' => 'homem em cadeira de rodas manual',
    '👩‍🦽' => 'mulher em cadeira de rodas manual',
    '🏃‍♂' => 'homem correndo',
    '🏃‍♀' => 'mulher correndo',
    '🧑‍🩰' => 'bailarina',
    '👯‍♂' => 'homens com orelhas de coelho',
    '👯‍♀' => 'mulheres com orelhas de coelho',
    '🧖‍♂' => 'homem na sauna',
    '🧖‍♀' => 'mulher na sauna',
    '🧗‍♂' => 'homem escalando',
    '🧗‍♀' => 'mulher escalando',
    '🏌‍♂' => 'homem golfista',
    '🏌‍♀' => 'mulher golfista',
    '🏄‍♂' => 'homem surfista',
    '🏄‍♀' => 'mulher surfista',
    '🚣‍♂' => 'homem remando',
    '🚣‍♀' => 'mulher remando',
    '🏊‍♂' => 'homem nadando',
    '🏊‍♀' => 'mulher nadando',
    '⛹‍♂' => 'homem jogando basquete',
    '⛹‍♀' => 'mulher jogando basquete',
    '🏋‍♂' => 'homem levantando peso',
    '🏋‍♀' => 'mulher levantando peso',
    '🚴‍♂' => 'homem ciclista',
    '🚴‍♀' => 'mulher ciclista',
    '🚵‍♂' => 'homem fazendo mountain bike',
    '🚵‍♀' => 'mulher fazendo mountain bike',
    '🤸‍♂' => 'homem fazendo estrela',
    '🤸‍♀' => 'mulher fazendo estrela',
    '🤼‍♂' => 'homens lutando',
    '🤼‍♀' => 'mulheres lutando',
    '🤽‍♂' => 'homem jogando polo aquático',
    '🤽‍♀' => 'mulher jogando polo aquático',
    '🤾‍♂' => 'jogador de handebol',
    '🤾‍♀' => 'jogadora de handebol',
    '🤹‍♂' => 'homem malabarista',
    '🤹‍♀' => 'mulher malabarista',
    '🧘‍♂' => 'homem na posição de lótus',
    '🧘‍♀' => 'mulher na posição de lótus',
    '🧑‍🧒' => 'família: adulto, criança',
    '🐕‍🦺' => 'cão de serviço',
    '🐈‍⬛' => 'gato preto',
    '🐻‍❄' => 'urso polar',
    '🐦‍⬛' => 'pássaro preto',
    '🐦‍🔥' => 'fênix',
    '🍋‍🟩' => 'lima',
    '🍄‍🟫' => 'cogumelo marrom',
    '⛓‍💥' => 'corrente quebrada',
    '🏳‍🌈' => 'bandeira do arco-íris',
    '🏳‍⚧' => 'bandeira transgênero',
    '🏴‍☠' => 'bandeira de pirata',
    '👋🏻' => 'mão acenando: pele clara',
    '👋🏼' => 'mão acenando: pele morena clara',
    '👋🏽' => 'mão acenando: pele morena',
    '👋🏾' => 'mão acenando: pele morena escura',
    '👋🏿' => 'mão acenando: pele escura',
    '🤚🏻' => 'dorso da mão levantado: pele clara',
    '🤚🏼' => 'dorso da mão levantado: pele morena clara',
    '🤚🏽' => 'dorso da mão levantado: pele morena',
    '🤚🏾' => 'dorso da mão levantado: pele morena escura',
    '🤚🏿' => 'dorso da mão levantado: pele escura',
    '🖐🏻' => 'mão aberta com os dedos separados: pele clara',
    '🖐🏼' => 'mão aberta com os dedos separados: pele morena clara',
    '🖐🏽' => 'mão aberta com os dedos separados: pele morena',
    '🖐🏾' => 'mão aberta com os dedos separados: pele morena escura',
    '🖐🏿' => 'mão aberta com os dedos separados: pele escura',
    '✋🏻' => 'mão levantada: pele clara',
    '✋🏼' => 'mão levantada: pele morena clara',
    '✋🏽' => 'mão levantada: pele morena',
    '✋🏾' => 'mão levantada: pele morena escura',
    '✋🏿' => 'mão levantada: pele escura',
    '🖖🏻' => 'saudação vulcana: pele clara',
    '🖖🏼' => 'saudação vulcana: pele morena clara',
    '🖖🏽' => 'saudação vulcana: pele morena',
    '🖖🏾' => 'saudação vulcana: pele morena escura',
    '🖖🏿' => 'saudação vulcana: pele escura',
    '🫱🏻' => 'mão para a direita: pele clara',
    '🫱🏼' => 'mão para a direita: pele morena clara',
    '🫱🏽' => 'mão para a direita: pele morena',
    '🫱🏾' => 'mão para a direita: pele morena escura',
    '🫱🏿' => 'mão para a direita: pele escura',
    '🫲🏻' => 'mão para a esquerda: pele clara',
    '🫲🏼' => 'mão para a esquerda: pele morena clara',
    '🫲🏽' => 'mão para a esquerda: pele morena',
    '🫲🏾' => 'mão para a esquerda: pele morena escura',
    '🫲🏿' => 'mão para a esquerda: pele escura',
    '🫳🏻' => 'mão com a palma para baixo: pele clara',
    '🫳🏼' => 'mão com a palma para baixo: pele morena clara',
    '🫳🏽' => 'mão com a palma para baixo: pele morena',
    '🫳🏾' => 'mão com a palma para baixo: pele morena escura',
    '🫳🏿' => 'mão com a palma para baixo: pele escura',
    '🫴🏻' => 'mão com a palma para cima: pele clara',
    '🫴🏼' => 'mão com a palma para cima: pele morena clara',
    '🫴🏽' => 'mão com a palma para cima: pele morena',
    '🫴🏾' => 'mão com a palma para cima: pele morena escura',
    '🫴🏿' => 'mão com a palma para cima: pele escura',
    '🫷🏻' => 'mão empurrando para a esquerda: pele clara',
    '🫷🏼' => 'mão empurrando para a esquerda: pele morena clara',
    '🫷🏽' => 'mão empurrando para a esquerda: pele morena',
    '🫷🏾' => 'mão empurrando para a esquerda: pele morena escura',
    '🫷🏿' => 'mão empurrando para a esquerda: pele escura',
    '🫸🏻' => 'mão empurrando para a direita: pele clara',
    '🫸🏼' => 'mão empurrando para a direita: pele morena clara',
    '🫸🏽' => 'mão empurrando para a direita: pele morena',
    '🫸🏾' => 'mão empurrando para a direita: pele morena escura',
    '🫸🏿' => 'mão empurrando para a direita: pele escura',
    '👌🏻' => 'sinal de ok: pele clara',
    '👌🏼' => 'sinal de ok: pele morena clara',
    '👌🏽' => 'sinal de ok: pele morena',
    '👌🏾' => 'sinal de ok: pele morena escura',
    '👌🏿' => 'sinal de ok: pele escura',
    '🤌🏻' => 'dedos comprimidos: pele clara',
    '🤌🏼' => 'dedos comprimidos: pele morena clara',
    '🤌🏽' => 'dedos comprimidos: pele morena',
    '🤌🏾' => 'dedos comprimidos: pele morena escura',
    '🤌🏿' => 'dedos comprimidos: pele escura',
    '🤏🏻' => 'mão beliscando: pele clara',
    '🤏🏼' => 'mão beliscando: pele morena clara',
    '🤏🏽' => 'mão beliscando: pele morena',
    '🤏🏾' => 'mão beliscando: pele morena escura',
    '🤏🏿' => 'mão beliscando: pele escura',
    '✌🏻' => 'mão em V de vitória: pele clara',
    '✌🏼' => 'mão em V de vitória: pele morena clara',
    '✌🏽' => 'mão em V de vitória: pele morena',
    '✌🏾' => 'mão em V de vitória: pele morena escura',
    '✌🏿' => 'mão em V de vitória: pele escura',
    '🤞🏻' => 'dedos cruzados: pele clara',
    '🤞🏼' => 'dedos cruzados: pele morena clara',
    '🤞🏽' => 'dedos cruzados: pele morena',
    '🤞🏾' => 'dedos cruzados: pele morena escura',
    '🤞🏿' => 'dedos cruzados: pele escura',
    '🫰🏻' => 'mão com dedo indicador e polegar cruzados: pele clara',
    '🫰🏼' => 'mão com dedo indicador e polegar cruzados: pele morena clara',
    '🫰🏽' => 'mão com dedo indicador e polegar cruzados: pele morena',
    '🫰🏾' => 'mão com dedo indicador e polegar cruzados: pele morena escura',
    '🫰🏿' => 'mão com dedo indicador e polegar cruzados: pele escura',
    '🤟🏻' => 'gesto de "te amo": pele clara',
    '🤟🏼' => 'gesto de "te amo": pele morena clara',
    '🤟🏽' => 'gesto de "te amo": pele morena',
    '🤟🏾' => 'gesto de "te amo": pele morena escura',
    '🤟🏿' => 'gesto de "te amo": pele escura',
    '🤘🏻' => 'saudação do rock: pele clara',
    '🤘🏼' => 'saudação do rock: pele morena clara',
    '🤘🏽' => 'saudação do rock: pele morena',
    '🤘🏾' => 'saudação do rock: pele morena escura',
    '🤘🏿' => 'saudação do rock: pele escura',
    '🤙🏻' => 'sinal "me liga": pele clara',
    '🤙🏼' => 'sinal "me liga": pele morena clara',
    '🤙🏽' => 'sinal "me liga": pele morena',
    '🤙🏾' => 'sinal "me liga": pele morena escura',
    '🤙🏿' => 'sinal "me liga": pele escura',
    '👈🏻' => 'dorso da mão com indicador apontando para a esquerda: pele clara',
    '👈🏼' => 'dorso da mão com indicador apontando para a esquerda: pele morena clara',
    '👈🏽' => 'dorso da mão com indicador apontando para a esquerda: pele morena',
    '👈🏾' => 'dorso da mão com indicador apontando para a esquerda: pele morena escura',
    '👈🏿' => 'dorso da mão com indicador apontando para a esquerda: pele escura',
    '👉🏻' => 'dorso da mão com indicador apontando para a direita: pele clara',
    '👉🏼' => 'dorso da mão com indicador apontando para a direita: pele morena clara',
    '👉🏽' => 'dorso da mão com indicador apontando para a direita: pele morena',
    '👉🏾' => 'dorso da mão com indicador apontando para a direita: pele morena escura',
    '👉🏿' => 'dorso da mão com indicador apontando para a direita: pele escura',
    '👆🏻' => 'dorso da mão com indicador apontando para cima: pele clara',
    '👆🏼' => 'dorso da mão com indicador apontando para cima: pele morena clara',
    '👆🏽' => 'dorso da mão com indicador apontando para cima: pele morena',
    '👆🏾' => 'dorso da mão com indicador apontando para cima: pele morena escura',
    '👆🏿' => 'dorso da mão com indicador apontando para cima: pele escura',
    '🖕🏻' => 'dedo do meio: pele clara',
    '🖕🏼' => 'dedo do meio: pele morena clara',
    '🖕🏽' => 'dedo do meio: pele morena',
    '🖕🏾' => 'dedo do meio: pele morena escura',
    '🖕🏿' => 'dedo do meio: pele escura',
    '👇🏻' => 'dorso da mão com indicador apontando para baixo: pele clara',
    '👇🏼' => 'dorso da mão com indicador apontando para baixo: pele morena clara',
    '👇🏽' => 'dorso da mão com indicador apontando para baixo: pele morena',
    '👇🏾' => 'dorso da mão com indicador apontando para baixo: pele morena escura',
    '👇🏿' => 'dorso da mão com indicador apontando para baixo: pele escura',
    '☝🏻' => 'indicador apontando para cima: pele clara',
    '☝🏼' => 'indicador apontando para cima: pele morena clara',
    '☝🏽' => 'indicador apontando para cima: pele morena',
    '☝🏾' => 'indicador apontando para cima: pele morena escura',
    '☝🏿' => 'indicador apontando para cima: pele escura',
    '🫵🏻' => 'indicador apontando para o visualizador: pele clara',
    '🫵🏼' => 'indicador apontando para o visualizador: pele morena clara',
    '🫵🏽' => 'indicador apontando para o visualizador: pele morena',
    '🫵🏾' => 'indicador apontando para o visualizador: pele morena escura',
    '🫵🏿' => 'indicador apontando para o visualizador: pele escura',
    '👍🏻' => 'polegar para cima: pele clara',
    '👍🏼' => 'polegar para cima: pele morena clara',
    '👍🏽' => 'polegar para cima: pele morena',
    '👍🏾' => 'polegar para cima: pele morena escura',
    '👍🏿' => 'polegar para cima: pele escura',
    '👎🏻' => 'polegar para baixo: pele clara',
    '👎🏼' => 'polegar para baixo: pele morena clara',
    '👎🏽' => 'polegar para baixo: pele morena',
    '👎🏾' => 'polegar para baixo: pele morena escura',
    '👎🏿' => 'polegar para baixo: pele escura',
    '✊🏻' => 'punho levantado: pele clara',
    '✊🏼' => 'punho levantado: pele morena clara',
    '✊🏽' => 'punho levantado: pele morena',
    '✊🏾' => 'punho levantado: pele morena escura',
    '✊🏿' => 'punho levantado: pele escura',
    '👊🏻' => 'soco: pele clara',
    '👊🏼' => 'soco: pele morena clara',
    '👊🏽' => 'soco: pele morena',
    '👊🏾' => 'soco: pele morena escura',
    '👊🏿' => 'soco: pele escura',
    '🤛🏻' => 'punho esquerdo: pele clara',
    '🤛🏼' => 'punho esquerdo: pele morena clara',
    '🤛🏽' => 'punho esquerdo: pele morena',
    '🤛🏾' => 'punho esquerdo: pele morena escura',
    '🤛🏿' => 'punho esquerdo: pele escura',
    '🤜🏻' => 'punho direito: pele clara',
    '🤜🏼' => 'punho direito: pele morena clara',
    '🤜🏽' => 'punho direito: pele morena',
    '🤜🏾' => 'punho direito: pele morena escura',
    '🤜🏿' => 'punho direito: pele escura',
    '👏🏻' => 'mãos aplaudindo: pele clara',
    '👏🏼' => 'mãos aplaudindo: pele morena clara',
    '👏🏽' => 'mãos aplaudindo: pele morena',
    '👏🏾' => 'mãos aplaudindo: pele morena escura',
    '👏🏿' => 'mãos aplaudindo: pele escura',
    '🙌🏻' => 'mãos para cima: pele clara',
    '🙌🏼' => 'mãos para cima: pele morena clara',
    '🙌🏽' => 'mãos para cima: pele morena',
    '🙌🏾' => 'mãos para cima: pele morena escura',
    '🙌🏿' => 'mãos para cima: pele escura',
    '🫶🏻' => 'mãos de coração: pele clara',
    '🫶🏼' => 'mãos de coração: pele morena clara',
    '🫶🏽' => 'mãos de coração: pele morena',
    '🫶🏾' => 'mãos de coração: pele morena escura',
    '🫶🏿' => 'mãos de coração: pele escura',
    '👐🏻' => 'mãos abertas: pele clara',
    '👐🏼' => 'mãos abertas: pele morena clara',
    '👐🏽' => 'mãos abertas: pele morena',
    '👐🏾' => 'mãos abertas: pele morena escura',
    '👐🏿' => 'mãos abertas: pele escura',
    '🤲🏻' => 'palmas unidas para cima: pele clara',
    '🤲🏼' => 'palmas unidas para cima: pele morena clara',
    '🤲🏽' => 'palmas unidas para cima: pele morena',
    '🤲🏾' => 'palmas unidas para cima: pele morena escura',
    '🤲🏿' => 'palmas unidas para cima: pele escura',
    '🤝🏻' => 'aperto de mãos: pele clara',
    '🤝🏼' => 'aperto de mãos: pele morena clara',
    '🤝🏽' => 'aperto de mãos: pele morena',
    '🤝🏾' => 'aperto de mãos: pele morena escura',
    '🤝🏿' => 'aperto de mãos: pele escura',
    '🙏🏻' => 'mãos juntas: pele clara',
    '🙏🏼' => 'mãos juntas: pele morena clara',
    '🙏🏽' => 'mãos juntas: pele morena',
    '🙏🏾' => 'mãos juntas: pele morena escura',
    '🙏🏿' => 'mãos juntas: pele escura',
    '✍🏻' => 'escrevendo à mão: pele clara',
    '✍🏼' => 'escrevendo à mão: pele morena clara',
    '✍🏽' => 'escrevendo à mão: pele morena',
    '✍🏾' => 'escrevendo à mão: pele morena escura',
    '✍🏿' => 'escrevendo à mão: pele escura',
    '💅🏻' => 'esmalte de unha: pele clara',
    '💅🏼' => 'esmalte de unha: pele morena clara',
    '💅🏽' => 'esmalte de unha: pele morena',
    '💅🏾' => 'esmalte de unha: pele morena escura',
    '💅🏿' => 'esmalte de unha: pele escura',
    '🤳🏻' => 'selfie: pele clara',
    '🤳🏼' => 'selfie: pele morena clara',
    '🤳🏽' => 'selfie: pele morena',
    '🤳🏾' => 'selfie: pele morena escura',
    '🤳🏿' => 'selfie: pele escura',
    '💪🏻' => 'bíceps: pele clara',
    '💪🏼' => 'bíceps: pele morena clara',
    '💪🏽' => 'bíceps: pele morena',
    '💪🏾' => 'bíceps: pele morena escura',
    '💪🏿' => 'bíceps: pele escura',
    '🦵🏻' => 'perna: pele clara',
    '🦵🏼' => 'perna: pele morena clara',
    '🦵🏽' => 'perna: pele morena',
    '🦵🏾' => 'perna: pele morena escura',
    '🦵🏿' => 'perna: pele escura',
    '🦶🏻' => 'pé: pele clara',
    '🦶🏼' => 'pé: pele morena clara',
    '🦶🏽' => 'pé: pele morena',
    '🦶🏾' => 'pé: pele morena escura',
    '🦶🏿' => 'pé: pele escura',
    '👂🏻' => 'orelha: pele clara',
    '👂🏼' => 'orelha: pele morena clara',
    '👂🏽' => 'orelha: pele morena',
    '👂🏾' => 'orelha: pele morena escura',
    '👂🏿' => 'orelha: pele escura',
    '🦻🏻' => 'ouvido com aparelho auditivo: pele clara',
    '🦻🏼' => 'ouvido com aparelho auditivo: pele morena clara',
    '🦻🏽' => 'ouvido com aparelho auditivo: pele morena',
    '🦻🏾' => 'ouvido com aparelho auditivo: pele morena escura',
    '🦻🏿' => 'ouvido com aparelho auditivo: pele escura',
    '👃🏻' => 'nariz: pele clara',
    '👃🏼' => 'nariz: pele morena clara',
    '👃🏽' => 'nariz: pele morena',
    '👃🏾' => 'nariz: pele morena escura',
    '👃🏿' => 'nariz: pele escura',
    '👶🏻' => 'bebê: pele clara',
    '👶🏼' => 'bebê: pele morena clara',
    '👶🏽' => 'bebê: pele morena',
    '👶🏾' => 'bebê: pele morena escura',
    '👶🏿' => 'bebê: pele escura',
    '🧒🏻' => 'criança: pele clara',
    '🧒🏼' => 'criança: pele morena clara',
    '🧒🏽' => 'criança: pele morena',
    '🧒🏾' => 'criança: pele morena escura',
    '🧒🏿' => 'criança: pele escura',
    '👦🏻' => 'menino: pele clara',
    '👦🏼' => 'menino: pele morena clara',
    '👦🏽' => 'menino: pele morena',
    '👦🏾' => 'menino: pele morena escura',
    '👦🏿' => 'menino: pele escura',
    '👧🏻' => 'menina: pele clara',
    '👧🏼' => 'menina: pele morena clara',
    '👧🏽' => 'menina: pele morena',
    '👧🏾' => 'menina: pele morena escura',
    '👧🏿' => 'menina: pele escura',
    '🧑🏻' => 'pessoa: pele clara',
    '🧑🏼' => 'pessoa: pele morena clara',
    '🧑🏽' => 'pessoa: pele morena',
    '🧑🏾' => 'pessoa: pele morena escura',
    '🧑🏿' => 'pessoa: pele escura',
    '👱🏻' => 'pessoa: pele clara e cabelo louro',
    '👱🏼' => 'pessoa: pele morena clara e cabelo louro',
    '👱🏽' => 'pessoa: pele morena e cabelo louro',
    '👱🏾' => 'pessoa: pele morena escura e cabelo louro',
    '👱🏿' => 'pessoa: pele escura e cabelo louro',
    '👨🏻' => 'homem: pele clara',
    '👨🏼' => 'homem: pele morena clara',
    '👨🏽' => 'homem: pele morena',
    '👨🏾' => 'homem: pele morena escura',
    '👨🏿' => 'homem: pele escura',
    '🧔🏻' => 'homem: pele clara e barba',
    '🧔🏼' => 'homem: pele morena clara e barba',
    '🧔🏽' => 'homem: pele morena e barba',
    '🧔🏾' => 'homem: pele morena escura e barba',
    '🧔🏿' => 'homem: pele escura e barba',
    '👩🏻' => 'mulher: pele clara',
    '👩🏼' => 'mulher: pele morena clara',
    '👩🏽' => 'mulher: pele morena',
    '👩🏾' => 'mulher: pele morena escura',
    '👩🏿' => 'mulher: pele escura',
    '🧓🏻' => 'idoso: pele clara',
    '🧓🏼' => 'idoso: pele morena clara',
    '🧓🏽' => 'idoso: pele morena',
    '🧓🏾' => 'idoso: pele morena escura',
    '🧓🏿' => 'idoso: pele escura',
    '👴🏻' => 'homem idoso: pele clara',
    '👴🏼' => 'homem idoso: pele morena clara',
    '👴🏽' => 'homem idoso: pele morena',
    '👴🏾' => 'homem idoso: pele morena escura',
    '👴🏿' => 'homem idoso: pele escura',
    '👵🏻' => 'idosa: pele clara',
    '👵🏼' => 'idosa: pele morena clara',
    '👵🏽' => 'idosa: pele morena',
    '👵🏾' => 'idosa: pele morena escura',
    '👵🏿' => 'idosa: pele escura',
    '🙍🏻' => 'franzindo a sobrancelha: pele clara',
    '🙍🏼' => 'franzindo a sobrancelha: pele morena clara',
    '🙍🏽' => 'franzindo a sobrancelha: pele morena',
    '🙍🏾' => 'franzindo a sobrancelha: pele morena escura',
    '🙍🏿' => 'franzindo a sobrancelha: pele escura',
    '🙎🏻' => 'pessoa fazendo bico: pele clara',
    '🙎🏼' => 'pessoa fazendo bico: pele morena clara',
    '🙎🏽' => 'pessoa fazendo bico: pele morena',
    '🙎🏾' => 'pessoa fazendo bico: pele morena escura',
    '🙎🏿' => 'pessoa fazendo bico: pele escura',
    '🙅🏻' => 'pessoa fazendo gesto de “não”: pele clara',
    '🙅🏼' => 'pessoa fazendo gesto de “não”: pele morena clara',
    '🙅🏽' => 'pessoa fazendo gesto de “não”: pele morena',
    '🙅🏾' => 'pessoa fazendo gesto de “não”: pele morena escura',
    '🙅🏿' => 'pessoa fazendo gesto de “não”: pele escura',
    '🙆🏻' => 'pessoa fazendo gesto de “OK”: pele clara',
    '🙆🏼' => 'pessoa fazendo gesto de “OK”: pele morena clara',
    '🙆🏽' => 'pessoa fazendo gesto de “OK”: pele morena',
    '🙆🏾' => 'pessoa fazendo gesto de “OK”: pele morena escura',
    '🙆🏿' => 'pessoa fazendo gesto de “OK”: pele escura',
    '💁🏻' => 'pessoa com a palma virada para cima: pele clara',
    '💁🏼' => 'pessoa com a palma virada para cima: pele morena clara',
    '💁🏽' => 'pessoa com a palma virada para cima: pele morena',
    '💁🏾' => 'pessoa com a palma virada para cima: pele morena escura',
    '💁🏿' => 'pessoa com a palma virada para cima: pele escura',
    '🙋🏻' => 'pessoa levantando a mão: pele clara',
    '🙋🏼' => 'pessoa levantando a mão: pele morena clara',
    '🙋🏽' => 'pessoa levantando a mão: pele morena',
    '🙋🏾' => 'pessoa levantando a mão: pele morena escura',
    '🙋🏿' => 'pessoa levantando a mão: pele escura',
    '🧏🏻' => 'pessoa surda: pele clara',
    '🧏🏼' => 'pessoa surda: pele morena clara',
    '🧏🏽' => 'pessoa surda: pele morena',
    '🧏🏾' => 'pessoa surda: pele morena escura',
    '🧏🏿' => 'pessoa surda: pele escura',
    '🙇🏻' => 'pessoa fazendo reverência: pele clara',
    '🙇🏼' => 'pessoa fazendo reverência: pele morena clara',
    '🙇🏽' => 'pessoa fazendo reverência: pele morena',
    '🙇🏾' => 'pessoa fazendo reverência: pele morena escura',
    '🙇🏿' => 'pessoa fazendo reverência: pele escura',
    '🤦🏻' => 'pessoa decepcionada: pele clara',
    '🤦🏼' => 'pessoa decepcionada: pele morena clara',
    '🤦🏽' => 'pessoa decepcionada: pele morena',
    '🤦🏾' => 'pessoa decepcionada: pele morena escura',
    '🤦🏿' => 'pessoa decepcionada: pele escura',
    '🤷🏻' => 'pessoa dando de ombros: pele clara',
    '🤷🏼' => 'pessoa dando de ombros: pele morena clara',
    '🤷🏽' => 'pessoa dando de ombros: pele morena',
    '🤷🏾' => 'pessoa dando de ombros: pele morena escura',
    '🤷🏿' => 'pessoa dando de ombros: pele escura',
    '👮🏻' => 'policial: pele clara',
    '👮🏼' => 'policial: pele morena clara',
    '👮🏽' => 'policial: pele morena',
    '👮🏾' => 'policial: pele morena escura',
    '👮🏿' => 'policial: pele escura',
    '🕵🏻' => 'detetive: pele clara',
    '🕵🏼' => 'detetive: pele morena clara',
    '🕵🏽' => 'detetive: pele morena',
    '🕵🏾' => 'detetive: pele morena escura',
    '🕵🏿' => 'detetive: pele escura',
    '💂🏻' => 'guarda: pele clara',
    '💂🏼' => 'guarda: pele morena clara',
    '💂🏽' => 'guarda: pele morena',
    '💂🏾' => 'guarda: pele morena escura',
    '💂🏿' => 'guarda: pele escura',
    '🥷🏻' => 'ninja: pele clara',
    '🥷🏼' => 'ninja: pele morena clara',
    '🥷🏽' => 'ninja: pele morena',
    '🥷🏾' => 'ninja: pele morena escura',
    '🥷🏿' => 'ninja: pele escura',
    '👷🏻' => 'trabalhador de construção civil: pele clara',
    '👷🏼' => 'trabalhador de construção civil: pele morena clara',
    '👷🏽' => 'trabalhador de construção civil: pele morena',
    '👷🏾' => 'trabalhador de construção civil: pele morena escura',
    '👷🏿' => 'trabalhador de construção civil: pele escura',
    '🫅🏻' => 'pessoa com coroa: pele clara',
    '🫅🏼' => 'pessoa com coroa: pele morena clara',
    '🫅🏽' => 'pessoa com coroa: pele morena',
    '🫅🏾' => 'pessoa com coroa: pele morena escura',
    '🫅🏿' => 'pessoa com coroa: pele escura',
    '🤴🏻' => 'príncipe: pele clara',
    '🤴🏼' => 'príncipe: pele morena clara',
    '🤴🏽' => 'príncipe: pele morena',
    '🤴🏾' => 'príncipe: pele morena escura',
    '🤴🏿' => 'príncipe: pele escura',
    '👸🏻' => 'princesa: pele clara',
    '👸🏼' => 'princesa: pele morena clara',
    '👸🏽' => 'princesa: pele morena',
    '👸🏾' => 'princesa: pele morena escura',
    '👸🏿' => 'princesa: pele escura',
    '👳🏻' => 'pessoa com turbante: pele clara',
    '👳🏼' => 'pessoa com turbante: pele morena clara',
    '👳🏽' => 'pessoa com turbante: pele morena',
    '👳🏾' => 'pessoa com turbante: pele morena escura',
    '👳🏿' => 'pessoa com turbante: pele escura',
    '👲🏻' => 'homem de boné: pele clara',
    '👲🏼' => 'homem de boné: pele morena clara',
    '👲🏽' => 'homem de boné: pele morena',
    '👲🏾' => 'homem de boné: pele morena escura',
    '👲🏿' => 'homem de boné: pele escura',
    '🧕🏻' => 'mulher com véu: pele clara',
    '🧕🏼' => 'mulher com véu: pele morena clara',
    '🧕🏽' => 'mulher com véu: pele morena',
    '🧕🏾' => 'mulher com véu: pele morena escura',
    '🧕🏿' => 'mulher com véu: pele escura',
    '🤵🏻' => 'pessoa de smoking: pele clara',
    '🤵🏼' => 'pessoa de smoking: pele morena clara',
    '🤵🏽' => 'pessoa de smoking: pele morena',
    '🤵🏾' => 'pessoa de smoking: pele morena escura',
    '🤵🏿' => 'pessoa de smoking: pele escura',
    '👰🏻' => 'pessoa com véu: pele clara',
    '👰🏼' => 'pessoa com véu: pele morena clara',
    '👰🏽' => 'pessoa com véu: pele morena',
    '👰🏾' => 'pessoa com véu: pele morena escura',
    '👰🏿' => 'pessoa com véu: pele escura',
    '🤰🏻' => 'grávida: pele clara',
    '🤰🏼' => 'grávida: pele morena clara',
    '🤰🏽' => 'grávida: pele morena',
    '🤰🏾' => 'grávida: pele morena escura',
    '🤰🏿' => 'grávida: pele escura',
    '🫃🏻' => 'homem grávido: pele clara',
    '🫃🏼' => 'homem grávido: pele morena clara',
    '🫃🏽' => 'homem grávido: pele morena',
    '🫃🏾' => 'homem grávido: pele morena escura',
    '🫃🏿' => 'homem grávido: pele escura',
    '🫄🏻' => 'pessoa grávida: pele clara',
    '🫄🏼' => 'pessoa grávida: pele morena clara',
    '🫄🏽' => 'pessoa grávida: pele morena',
    '🫄🏾' => 'pessoa grávida: pele morena escura',
    '🫄🏿' => 'pessoa grávida: pele escura',
    '🤱🏻' => 'amamentando: pele clara',
    '🤱🏼' => 'amamentando: pele morena clara',
    '🤱🏽' => 'amamentando: pele morena',
    '🤱🏾' => 'amamentando: pele morena escura',
    '🤱🏿' => 'amamentando: pele escura',
    '👼🏻' => 'bebê anjo: pele clara',
    '👼🏼' => 'bebê anjo: pele morena clara',
    '👼🏽' => 'bebê anjo: pele morena',
    '👼🏾' => 'bebê anjo: pele morena escura',
    '👼🏿' => 'bebê anjo: pele escura',
    '🎅🏻' => 'Papai Noel: pele clara',
    '🎅🏼' => 'Papai Noel: pele morena clara',
    '🎅🏽' => 'Papai Noel: pele morena',
    '🎅🏾' => 'Papai Noel: pele morena escura',
    '🎅🏿' => 'Papai Noel: pele escura',
    '🤶🏻' => 'Mamãe Noel: pele clara',
    '🤶🏼' => 'Mamãe Noel: pele morena clara',
    '🤶🏽' => 'Mamãe Noel: pele morena',
    '🤶🏾' => 'Mamãe Noel: pele morena escura',
    '🤶🏿' => 'Mamãe Noel: pele escura',
    '🦸🏻' => 'super-herói: pele clara',
    '🦸🏼' => 'super-herói: pele morena clara',
    '🦸🏽' => 'super-herói: pele morena',
    '🦸🏾' => 'super-herói: pele morena escura',
    '🦸🏿' => 'super-herói: pele escura',
    '🦹🏻' => 'supervilão: pele clara',
    '🦹🏼' => 'supervilão: pele morena clara',
    '🦹🏽' => 'supervilão: pele morena',
    '🦹🏾' => 'supervilão: pele morena escura',
    '🦹🏿' => 'supervilão: pele escura',
    '🧙🏻' => 'mago: pele clara',
    '🧙🏼' => 'mago: pele morena clara',
    '🧙🏽' => 'mago: pele morena',
    '🧙🏾' => 'mago: pele morena escura',
    '🧙🏿' => 'mago: pele escura',
    '🧚🏻' => 'fada: pele clara',
    '🧚🏼' => 'fada: pele morena clara',
    '🧚🏽' => 'fada: pele morena',
    '🧚🏾' => 'fada: pele morena escura',
    '🧚🏿' => 'fada: pele escura',
    '🧛🏻' => 'vampiro: pele clara',
    '🧛🏼' => 'vampiro: pele morena clara',
    '🧛🏽' => 'vampiro: pele morena',
    '🧛🏾' => 'vampiro: pele morena escura',
    '🧛🏿' => 'vampiro: pele escura',
    '🧜🏻' => 'pessoa sereia: pele clara',
    '🧜🏼' => 'pessoa sereia: pele morena clara',
    '🧜🏽' => 'pessoa sereia: pele morena',
    '🧜🏾' => 'pessoa sereia: pele morena escura',
    '🧜🏿' => 'pessoa sereia: pele escura',
    '🧝🏻' => 'elfo: pele clara',
    '🧝🏼' => 'elfo: pele morena clara',
    '🧝🏽' => 'elfo: pele morena',
    '🧝🏾' => 'elfo: pele morena escura',
    '🧝🏿' => 'elfo: pele escura',
    '💆🏻' => 'pessoa recebendo massagem facial: pele clara',
    '💆🏼' => 'pessoa recebendo massagem facial: pele morena clara',
    '💆🏽' => 'pessoa recebendo massagem facial: pele morena',
    '💆🏾' => 'pessoa recebendo massagem facial: pele morena escura',
    '💆🏿' => 'pessoa recebendo massagem facial: pele escura',
    '💇🏻' => 'pessoa cortando o cabelo: pele clara',
    '💇🏼' => 'pessoa cortando o cabelo: pele morena clara',
    '💇🏽' => 'pessoa cortando o cabelo: pele morena',
    '💇🏾' => 'pessoa cortando o cabelo: pele morena escura',
    '💇🏿' => 'pessoa cortando o cabelo: pele escura',
    '🚶🏻' => 'pessoa andando: pele clara',
    '🚶🏼' => 'pessoa andando: pele morena clara',
    '🚶🏽' => 'pessoa andando: pele morena',
    '🚶🏾' => 'pessoa andando: pele morena escura',
    '🚶🏿' => 'pessoa andando: pele escura',
    '🧍🏻' => 'pessoa em pé: pele clara',
    '🧍🏼' => 'pessoa em pé: pele morena clara',
    '🧍🏽' => 'pessoa em pé: pele morena',
    '🧍🏾' => 'pessoa em pé: pele morena escura',
    '🧍🏿' => 'pessoa em pé: pele escura',
    '🧎🏻' => 'pessoa ajoelhando: pele clara',
    '🧎🏼' => 'pessoa ajoelhando: pele morena clara',
    '🧎🏽' => 'pessoa ajoelhando: pele morena',
    '🧎🏾' => 'pessoa ajoelhando: pele morena escura',
    '🧎🏿' => 'pessoa ajoelhando: pele escura',
    '🏃🏻' => 'pessoa correndo: pele clara',
    '🏃🏼' => 'pessoa correndo: pele morena clara',
    '🏃🏽' => 'pessoa correndo: pele morena',
    '🏃🏾' => 'pessoa correndo: pele morena escura',
    '🏃🏿' => 'pessoa correndo: pele escura',
    '💃🏻' => 'mulher dançando: pele clara',
    '💃🏼' => 'mulher dançando: pele morena clara',
    '💃🏽' => 'mulher dançando: pele morena',
    '💃🏾' => 'mulher dançando: pele morena escura',
    '💃🏿' => 'mulher dançando: pele escura',
    '🕺🏻' => 'homem dançando: pele clara',
    '🕺🏼' => 'homem dançando: pele morena clara',
    '🕺🏽' => 'homem dançando: pele morena',
    '🕺🏾' => 'homem dançando: pele morena escura',
    '🕺🏿' => 'homem dançando: pele escura',
    '🕴🏻' => 'homem de terno levitando: pele clara',
    '🕴🏼' => 'homem de terno levitando: pele morena clara',
    '🕴🏽' => 'homem de terno levitando: pele morena',
    '🕴🏾' => 'homem de terno levitando: pele morena escura',
    '🕴🏿' => 'homem de terno levitando: pele escura',
    '👯🏻' => 'pessoas com orelhas de coelho: pele clara',
    '👯🏼' => 'pessoas com orelhas de coelho: pele morena clara',
    '👯🏽' => 'pessoas com orelhas de coelho: pele morena',
    '👯🏾' => 'pessoas com orelhas de coelho: pele morena escura',
    '👯🏿' => 'pessoas com orelhas de coelho: pele escura',
    '🧖🏻' => 'pessoa na sauna: pele clara',
    '🧖🏼' => 'pessoa na sauna: pele morena clara',
    '🧖🏽' => 'pessoa na sauna: pele morena',
    '🧖🏾' => 'pessoa na sauna: pele morena escura',
    '🧖🏿' => 'pessoa na sauna: pele escura',
    '🧗🏻' => 'pessoa escalando: pele clara',
    '🧗🏼' => 'pessoa escalando: pele morena clara',
    '🧗🏽' => 'pessoa escalando: pele morena',
    '🧗🏾' => 'pessoa escalando: pele morena escura',
    '🧗🏿' => 'pessoa escalando: pele escura',
    '🏇🏻' => 'corrida de cavalos: pele clara',
    '🏇🏼' => 'corrida de cavalos: pele morena clara',
    '🏇🏽' => 'corrida de cavalos: pele morena',
    '🏇🏾' => 'corrida de cavalos: pele morena escura',
    '🏇🏿' => 'corrida de cavalos: pele escura',
    '🏂🏻' => 'praticante de snowboard: pele clara',
    '🏂🏼' => 'praticante de snowboard: pele morena clara',
    '🏂🏽' => 'praticante de snowboard: pele morena',
    '🏂🏾' => 'praticante de snowboard: pele morena escura',
    '🏂🏿' => 'praticante de snowboard: pele escura',
    '🏌🏻' => 'golfista: pele clara',
    '🏌🏼' => 'golfista: pele morena clara',
    '🏌🏽' => 'golfista: pele morena',
    '🏌🏾' => 'golfista: pele morena escura',
    '🏌🏿' => 'golfista: pele escura',
    '🏄🏻' => 'surfista: pele clara',
    '🏄🏼' => 'surfista: pele morena clara',
    '🏄🏽' => 'surfista: pele morena',
    '🏄🏾' => 'surfista: pele morena escura',
    '🏄🏿' => 'surfista: pele escura',
    '🚣🏻' => 'pessoa remando: pele clara',
    '🚣🏼' => 'pessoa remando: pele morena clara',
    '🚣🏽' => 'pessoa remando: pele morena',
    '🚣🏾' => 'pessoa remando: pele morena escura',
    '🚣🏿' => 'pessoa remando: pele escura',
    '🏊🏻' => 'pessoa nadando: pele clara',
    '🏊🏼' => 'pessoa nadando: pele morena clara',
    '🏊🏽' => 'pessoa nadando: pele morena',
    '🏊🏾' => 'pessoa nadando: pele morena escura',
    '🏊🏿' => 'pessoa nadando: pele escura',
    '⛹🏻' => 'pessoa jogando basquete: pele clara',
    '⛹🏼' => 'pessoa jogando basquete: pele morena clara',
    '⛹🏽' => 'pessoa jogando basquete: pele morena',
    '⛹🏾' => 'pessoa jogando basquete: pele morena escura',
    '⛹🏿' => 'pessoa jogando basquete: pele escura',
    '🏋🏻' => 'pessoa levantando peso: pele clara',
    '🏋🏼' => 'pessoa levantando peso: pele morena clara',
    '🏋🏽' => 'pessoa levantando peso: pele morena',
    '🏋🏾' => 'pessoa levantando peso: pele morena escura',
    '🏋🏿' => 'pessoa levantando peso: pele escura',
    '🚴🏻' => 'ciclista: pele clara',
    '🚴🏼' => 'ciclista: pele morena clara',
    '🚴🏽' => 'ciclista: pele morena',
    '🚴🏾' => 'ciclista: pele morena escura',
    '🚴🏿' => 'ciclista: pele escura',
    '🚵🏻' => 'pessoa fazendo mountain bike: pele clara',
    '🚵🏼' => 'pessoa fazendo mountain bike: pele morena clara',
    '🚵🏽' => 'pessoa fazendo mountain bike: pele morena',
    '🚵🏾' => 'pessoa fazendo mountain bike: pele morena escura',
    '🚵🏿' => 'pessoa fazendo mountain bike: pele escura',
    '🤸🏻' => 'pessoa fazendo estrela: pele clara',
    '🤸🏼' => 'pessoa fazendo estrela: pele morena clara',
    '🤸🏽' => 'pessoa fazendo estrela: pele morena',
    '🤸🏾' => 'pessoa fazendo estrela: pele morena escura',
    '🤸🏿' => 'pessoa fazendo estrela: pele escura',
    '🤼🏻' => 'pessoas lutando: pele clara',
    '🤼🏼' => 'pessoas lutando: pele morena clara',
    '🤼🏽' => 'pessoas lutando: pele morena',
    '🤼🏾' => 'pessoas lutando: pele morena escura',
    '🤼🏿' => 'pessoas lutando: pele escura',
    '🤽🏻' => 'pessoa jogando polo aquático: pele clara',
    '🤽🏼' => 'pessoa jogando polo aquático: pele morena clara',
    '🤽🏽' => 'pessoa jogando polo aquático: pele morena',
    '🤽🏾' => 'pessoa jogando polo aquático: pele morena escura',
    '🤽🏿' => 'pessoa jogando polo aquático: pele escura',
    '🤾🏻' => 'handebol: pele clara',
    '🤾🏼' => 'handebol: pele morena clara',
    '🤾🏽' => 'handebol: pele morena',
    '🤾🏾' => 'handebol: pele morena escura',
    '🤾🏿' => 'handebol: pele escura',
    '🤹🏻' => 'malabarista: pele clara',
    '🤹🏼' => 'malabarista: pele morena clara',
    '🤹🏽' => 'malabarista: pele morena',
    '🤹🏾' => 'malabarista: pele morena escura',
    '🤹🏿' => 'malabarista: pele escura',
    '🧘🏻' => 'pessoa na posição de lótus: pele clara',
    '🧘🏼' => 'pessoa na posição de lótus: pele morena clara',
    '🧘🏽' => 'pessoa na posição de lótus: pele morena',
    '🧘🏾' => 'pessoa na posição de lótus: pele morena escura',
    '🧘🏿' => 'pessoa na posição de lótus: pele escura',
    '🛀🏻' => 'pessoa tomando banho: pele clara',
    '🛀🏼' => 'pessoa tomando banho: pele morena clara',
    '🛀🏽' => 'pessoa tomando banho: pele morena',
    '🛀🏾' => 'pessoa tomando banho: pele morena escura',
    '🛀🏿' => 'pessoa tomando banho: pele escura',
    '🛌🏻' => 'pessoa deitada na cama: pele clara',
    '🛌🏼' => 'pessoa deitada na cama: pele morena clara',
    '🛌🏽' => 'pessoa deitada na cama: pele morena',
    '🛌🏾' => 'pessoa deitada na cama: pele morena escura',
    '🛌🏿' => 'pessoa deitada na cama: pele escura',
    '👭🏻' => 'duas mulheres de mãos dadas: pele clara',
    '👭🏼' => 'duas mulheres de mãos dadas: pele morena clara',
    '👭🏽' => 'duas mulheres de mãos dadas: pele morena',
    '👭🏾' => 'duas mulheres de mãos dadas: pele morena escura',
    '👭🏿' => 'duas mulheres de mãos dadas: pele escura',
    '👫🏻' => 'homem e mulher de mãos dadas: pele clara',
    '👫🏼' => 'homem e mulher de mãos dadas: pele morena clara',
    '👫🏽' => 'homem e mulher de mãos dadas: pele morena',
    '👫🏾' => 'homem e mulher de mãos dadas: pele morena escura',
    '👫🏿' => 'homem e mulher de mãos dadas: pele escura',
    '👬🏻' => 'dois homens de mãos dadas: pele clara',
    '👬🏼' => 'dois homens de mãos dadas: pele morena clara',
    '👬🏽' => 'dois homens de mãos dadas: pele morena',
    '👬🏾' => 'dois homens de mãos dadas: pele morena escura',
    '👬🏿' => 'dois homens de mãos dadas: pele escura',
    '💏🏻' => 'beijo: pele clara',
    '💏🏼' => 'beijo: pele morena clara',
    '💏🏽' => 'beijo: pele morena',
    '💏🏾' => 'beijo: pele morena escura',
    '💏🏿' => 'beijo: pele escura',
    '💑🏻' => 'casal apaixonado: pele clara',
    '💑🏼' => 'casal apaixonado: pele morena clara',
    '💑🏽' => 'casal apaixonado: pele morena',
    '💑🏾' => 'casal apaixonado: pele morena escura',
    '💑🏿' => 'casal apaixonado: pele escura',
    '🇦🇨' => 'bandeira: Ilha de Ascensão',
    '🇦🇩' => 'bandeira: Andorra',
    '🇦🇪' => 'bandeira: Emirados Árabes Unidos',
    '🇦🇫' => 'bandeira: Afeganistão',
    '🇦🇬' => 'bandeira: Antígua e Barbuda',
    '🇦🇮' => 'bandeira: Anguila',
    '🇦🇱' => 'bandeira: Albânia',
    '🇦🇲' => 'bandeira: Armênia',
    '🇦🇴' => 'bandeira: Angola',
    '🇦🇶' => 'bandeira: Antártida',
    '🇦🇷' => 'bandeira: Argentina',
    '🇦🇸' => 'bandeira: Samoa Americana',
    '🇦🇹' => 'bandeira: Áustria',
    '🇦🇺' => 'bandeira: Austrália',
    '🇦🇼' => 'bandeira: Aruba',
    '🇦🇽' => 'bandeira: Ilhas Aland',
    '🇦🇿' => 'bandeira: Azerbaijão',
    '🇧🇦' => 'bandeira: Bósnia e Herzegovina',
    '🇧🇧' => 'bandeira: Barbados',
    '🇧🇩' => 'bandeira: Bangladesh',
    '🇧🇪' => 'bandeira: Bélgica',
    '🇧🇫' => 'bandeira: Burquina Faso',
    '🇧🇬' => 'bandeira: Bulgária',
    '🇧🇭' => 'bandeira: Barein',
    '🇧🇮' => 'bandeira: Burundi',
    '🇧🇯' => 'bandeira: Benin',
    '🇧🇱' => 'bandeira: São Bartolomeu',
    '🇧🇲' => 'bandeira: Bermudas',
    '🇧🇳' => 'bandeira: Brunei',
    '🇧🇴' => 'bandeira: Bolívia',
    '🇧🇶' => 'bandeira: Países Baixos Caribenhos',
    '🇧🇷' => 'bandeira: Brasil',
    '🇧🇸' => 'bandeira: Bahamas',
    '🇧🇹' => 'bandeira: Butão',
    '🇧🇻' => 'bandeira: Ilha Bouvet',
    '🇧🇼' => 'bandeira: Botsuana',
    '🇧🇾' => 'bandeira: Bielorrússia',
    '🇧🇿' => 'bandeira: Belize',
    '🇨🇦' => 'bandeira: Canadá',
    '🇨🇨' => 'bandeira: Ilhas Cocos (Keeling)',
    '🇨🇩' => 'bandeira: Congo - Kinshasa',
    '🇨🇫' => 'bandeira: República Centro-Africana',
    '🇨🇬' => 'bandeira: República do Congo',
    '🇨🇭' => 'bandeira: Suíça',
    '🇨🇮' => 'bandeira: Costa do Marfim',
    '🇨🇰' => 'bandeira: Ilhas Cook',
    '🇨🇱' => 'bandeira: Chile',
    '🇨🇲' => 'bandeira: Camarões',
    '🇨🇳' => 'bandeira: China',
    '🇨🇴' => 'bandeira: Colômbia',
    '🇨🇵' => 'bandeira: Ilha de Clipperton',
    '🇨🇶' => 'bandeira: Sark',
    '🇨🇷' => 'bandeira: Costa Rica',
    '🇨🇺' => 'bandeira: Cuba',
    '🇨🇻' => 'bandeira: Cabo Verde',
    '🇨🇼' => 'bandeira: Curaçao',
    '🇨🇽' => 'bandeira: Ilha Christmas',
    '🇨🇾' => 'bandeira: Chipre',
    '🇨🇿' => 'bandeira: Tchéquia',
    '🇩🇪' => 'bandeira: Alemanha',
    '🇩🇬' => 'bandeira: Diego Garcia',
    '🇩🇯' => 'bandeira: Djibuti',
    '🇩🇰' => 'bandeira: Dinamarca',
    '🇩🇲' => 'bandeira: Dominica',
    '🇩🇴' => 'bandeira: República Dominicana',
    '🇩🇿' => 'bandeira: Argélia',
    '🇪🇦' => 'bandeira: Ceuta e Melilla',
    '🇪🇨' => 'bandeira: Equador',
    '🇪🇪' => 'bandeira: Estônia',
    '🇪🇬' => 'bandeira: Egito',
    '🇪🇭' => 'bandeira: Saara Ocidental',
    '🇪🇷' => 'bandeira: Eritreia',
    '🇪🇸' => 'bandeira: Espanha',
    '🇪🇹' => 'bandeira: Etiópia',
    '🇪🇺' => 'bandeira: União Europeia',
    '🇫🇮' => 'bandeira: Finlândia',
    '🇫🇯' => 'bandeira: Fiji',
    '🇫🇰' => 'bandeira: Ilhas Malvinas',
    '🇫🇲' => 'bandeira: Micronésia',
    '🇫🇴' => 'bandeira: Ilhas Faroé',
    '🇫🇷' => 'bandeira: França',
    '🇬🇦' => 'bandeira: Gabão',
    '🇬🇧' => 'bandeira: Reino Unido',
    '🇬🇩' => 'bandeira: Granada',
    '🇬🇪' => 'bandeira: Geórgia',
    '🇬🇫' => 'bandeira: Guiana Francesa',
    '🇬🇬' => 'bandeira: Guernsey',
    '🇬🇭' => 'bandeira: Gana',
    '🇬🇮' => 'bandeira: Gibraltar',
    '🇬🇱' => 'bandeira: Groenlândia',
    '🇬🇲' => 'bandeira: Gâmbia',
    '🇬🇳' => 'bandeira: Guiné',
    '🇬🇵' => 'bandeira: Guadalupe',
    '🇬🇶' => 'bandeira: Guiné Equatorial',
    '🇬🇷' => 'bandeira: Grécia',
    '🇬🇸' => 'bandeira: Ilhas Geórgia do Sul e Sandwich do Sul',
    '🇬🇹' => 'bandeira: Guatemala',
    '🇬🇺' => 'bandeira: Guam',
    '🇬🇼' => 'bandeira: Guiné-Bissau',
    '🇬🇾' => 'bandeira: Guiana',
    '🇭🇰' => 'bandeira: Hong Kong, RAE da China',
    '🇭🇲' => 'bandeira: Ilhas Heard e McDonald',
    '🇭🇳' => 'bandeira: Honduras',
    '🇭🇷' => 'bandeira: Croácia',
    '🇭🇹' => 'bandeira: Haiti',
    '🇭🇺' => 'bandeira: Hungria',
    '🇮🇨' => 'bandeira: Ilhas Canárias',
    '🇮🇩' => 'bandeira: Indonésia',
    '🇮🇪' => 'bandeira: Irlanda',
    '🇮🇱' => 'bandeira: Israel',
    '🇮🇲' => 'bandeira: Ilha de Man',
    '🇮🇳' => 'bandeira: Índia',
    '🇮🇴' => 'bandeira: Território Britânico do Oceano Índico',
    '🇮🇶' => 'bandeira: Iraque',
    '🇮🇷' => 'bandeira: Irã',
    '🇮🇸' => 'bandeira: Islândia',
    '🇮🇹' => 'bandeira: Itália',
    '🇯🇪' => 'bandeira: Jersey',
    '🇯🇲' => 'bandeira: Jamaica',
    '🇯🇴' => 'bandeira: Jordânia',
    '🇯🇵' => 'bandeira: Japão',
    '🇰🇪' => 'bandeira: Quênia',
    '🇰🇬' => 'bandeira: Quirguistão',
    '🇰🇭' => 'bandeira: Camboja',
    '🇰🇮' => 'bandeira: Quiribati',
    '🇰🇲' => 'bandeira: Comores',
    '🇰🇳' => 'bandeira: São Cristóvão e Névis',
    '🇰🇵' => 'bandeira: Coreia do Norte',
    '🇰🇷' => 'bandeira: Coreia do Sul',
    '🇰🇼' => 'bandeira: Kuwait',
    '🇰🇾' => 'bandeira: Ilhas Cayman',
    '🇰🇿' => 'bandeira: Cazaquistão',
    '🇱🇦' => 'bandeira: Laos',
    '🇱🇧' => 'bandeira: Líbano',
    '🇱🇨' => 'bandeira: Santa Lúcia',
    '🇱🇮' => 'bandeira: Liechtenstein',
    '🇱🇰' => 'bandeira: Sri Lanka',
    '🇱🇷' => 'bandeira: Libéria',
    '🇱🇸' => 'bandeira: Lesoto',
    '🇱🇹' => 'bandeira: Lituânia',
    '🇱🇺' => 'bandeira: Luxemburgo',
    '🇱🇻' => 'bandeira: Letônia',
    '🇱🇾' => 'bandeira: Líbia',
    '🇲🇦' => 'bandeira: Marrocos',
    '🇲🇨' => 'bandeira: Mônaco',
    '🇲🇩' => 'bandeira: Moldávia',
    '🇲🇪' => 'bandeira: Montenegro',
    '🇲🇫' => 'bandeira: São Martinho',
    '🇲🇬' => 'bandeira: Madagascar',
    '🇲🇭' => 'bandeira: Ilhas Marshall',
    '🇲🇰' => 'bandeira: Macedônia do Norte',
    '🇲🇱' => 'bandeira: Mali',
    '🇲🇲' => 'bandeira: Mianmar (Birmânia)',
    '🇲🇳' => 'bandeira: Mongólia',
    '🇲🇴' => 'bandeira: Macau, RAE da China',
    '🇲🇵' => 'bandeira: Ilhas Marianas do Norte',
    '🇲🇶' => 'bandeira: Martinica',
    '🇲🇷' => 'bandeira: Mauritânia',
    '🇲🇸' => 'bandeira: Montserrat',
    '🇲🇹' => 'bandeira: Malta',
    '🇲🇺' => 'bandeira: Maurício',
    '🇲🇻' => 'bandeira: Maldivas',
    '🇲🇼' => 'bandeira: Malaui',
    '🇲🇽' => 'bandeira: México',
    '🇲🇾' => 'bandeira: Malásia',
    '🇲🇿' => 'bandeira: Moçambique',
    '🇳🇦' => 'bandeira: Namíbia',
    '🇳🇨' => 'bandeira: Nova Caledônia',
    '🇳🇪' => 'bandeira: Níger',
    '🇳🇫' => 'bandeira: Ilha Norfolk',
    '🇳🇬' => 'bandeira: Nigéria',
    '🇳🇮' => 'bandeira: Nicarágua',
    '🇳🇱' => 'bandeira: Países Baixos',
    '🇳🇴' => 'bandeira: Noruega',
    '🇳🇵' => 'bandeira: Nepal',
    '🇳🇷' => 'bandeira: Nauru',
    '🇳🇺' => 'bandeira: Niue',
    '🇳🇿' => 'bandeira: Nova Zelândia',
    '🇴🇲' => 'bandeira: Omã',
    '🇵🇦' => 'bandeira: Panamá',
    '🇵🇪' => 'bandeira: Peru',
    '🇵🇫' => 'bandeira: Polinésia Francesa',
    '🇵🇬' => 'bandeira: Papua-Nova Guiné',
    '🇵🇭' => 'bandeira: Filipinas',
    '🇵🇰' => 'bandeira: Paquistão',
    '🇵🇱' => 'bandeira: Polônia',
    '🇵🇲' => 'bandeira: São Pedro e Miquelão',
    '🇵🇳' => 'bandeira: Ilhas Pitcairn',
    '🇵🇷' => 'bandeira: Porto Rico',
    '🇵🇸' => 'bandeira: Territórios palestinos',
    '🇵🇹' => 'bandeira: Portugal',
    '🇵🇼' => 'bandeira: Palau',
    '🇵🇾' => 'bandeira: Paraguai',
    '🇶🇦' => 'bandeira: Catar',
    '🇷🇪' => 'bandeira: Reunião',
    '🇷🇴' => 'bandeira: Romênia',
    '🇷🇸' => 'bandeira: Sérvia',
    '🇷🇺' => 'bandeira: Rússia',
    '🇷🇼' => 'bandeira: Ruanda',
    '🇸🇦' => 'bandeira: Arábia Saudita',
    '🇸🇧' => 'bandeira: Ilhas Salomão',
    '🇸🇨' => 'bandeira: Seicheles',
    '🇸🇩' => 'bandeira: Sudão',
    '🇸🇪' => 'bandeira: Suécia',
    '🇸🇬' => 'bandeira: Singapura',
    '🇸🇭' => 'bandeira: Santa Helena',
    '🇸🇮' => 'bandeira: Eslovênia',
    '🇸🇯' => 'bandeira: Svalbard e Jan Mayen',
    '🇸🇰' => 'bandeira: Eslováquia',
    '🇸🇱' => 'bandeira: Serra Leoa',
    '🇸🇲' => 'bandeira: San Marino',
    '🇸🇳' => 'bandeira: Senegal',
    '🇸🇴' => 'bandeira: Somália',
    '🇸🇷' => 'bandeira: Suriname',
    '🇸🇸' => 'bandeira: Sudão do Sul',
    '🇸🇹' => 'bandeira: São Tomé e Príncipe',
    '🇸🇻' => 'bandeira: El Salvador',
    '🇸🇽' => 'bandeira: Sint Maarten',
    '🇸🇾' => 'bandeira: Síria',
    '🇸🇿' => 'bandeira: Essuatíni',
    '🇹🇦' => 'bandeira: Tristão da Cunha',
    '🇹🇨' => 'bandeira: Ilhas Turcas e Caicos',
    '🇹🇩' => 'bandeira: Chade',
    '🇹🇫' => 'bandeira: Territórios Franceses do Sul',
    '🇹🇬' => 'bandeira: Togo',
    '🇹🇭' => 'bandeira: Tailândia',
    '🇹🇯' => 'bandeira: Tadjiquistão',
    '🇹🇰' => 'bandeira: Tokelau',
    '🇹🇱' => 'bandeira: Timor-Leste',
    '🇹🇲' => 'bandeira: Turcomenistão',
    '🇹🇳' => 'bandeira: Tunísia',
    '🇹🇴' => 'bandeira: Tonga',
    '🇹🇷' => 'bandeira: Turquia',
    '🇹🇹' => 'bandeira: Trinidad e Tobago',
    '🇹🇻' => 'bandeira: Tuvalu',
    '🇹🇼' => 'bandeira: Taiwan',
    '🇹🇿' => 'bandeira: Tanzânia',
    '🇺🇦' => 'bandeira: Ucrânia',
    '🇺🇬' => 'bandeira: Uganda',
    '🇺🇲' => 'bandeira: Ilhas Menores Distantes dos EUA',
    '🇺🇳' => 'bandeira: Nações Unidas',
    '🇺🇸' => 'bandeira: Estados Unidos',
    '🇺🇾' => 'bandeira: Uruguai',
    '🇺🇿' => 'bandeira: Uzbequistão',
    '🇻🇦' => 'bandeira: Cidade do Vaticano',
    '🇻🇨' => 'bandeira: São Vicente e Granadinas',
    '🇻🇪' => 'bandeira: Venezuela',
    '🇻🇬' => 'bandeira: Ilhas Virgens Britânicas',
    '🇻🇮' => 'bandeira: Ilhas Virgens Americanas',
    '🇻🇳' => 'bandeira: Vietnã',
    '🇻🇺' => 'bandeira: Vanuatu',
    '🇼🇫' => 'bandeira: Wallis e Futuna',
    '🇼🇸' => 'bandeira: Samoa',
    '🇽🇰' => 'bandeira: Kosovo',
    '🇾🇪' => 'bandeira: Iêmen',
    '🇾🇹' => 'bandeira: Mayotte',
    '🇿🇦' => 'bandeira: África do Sul',
    '🇿🇲' => 'bandeira: Zâmbia',
    '🇿🇼' => 'bandeira: Zimbábue',
    '🔟' => 'tecla: 10',
    '🏻' => 'pele clara',
    '🏼' => 'pele morena clara',
    '🏽' => 'pele morena',
    '🏾' => 'pele morena escura',
    '🏿' => 'pele escura',
    '😀' => 'rosto risonho',
    '😃' => 'rosto risonho com olhos bem abertos',
    '😄' => 'rosto risonho com olhos sorridentes',
    '😁' => 'rosto contente com olhos sorridentes',
    '😆' => 'rosto risonho com olhos semicerrados',
    '😅' => 'rosto risonho com gota de suor',
    '🤣' => 'rolando no chão de rir',
    '😂' => 'rosto chorando de rir',
    '🙂' => 'rosto levemente sorridente',
    '🙃' => 'rosto de cabeça para baixo',
    '🫠' => 'rosto derretendo',
    '😉' => 'rosto com olho piscando',
    '😊' => 'rosto sorridente com olhos sorridentes',
    '😇' => 'rosto sorridente com auréola',
    '🥰' => 'rosto sorridente com 3 corações',
    '😍' => 'rosto sorridente com olhos de coração',
    '🤩' => 'rosto com olhar maravilhado',
    '😘' => 'rosto mandando um beijo',
    '😗' => 'rosto beijando',
    '☺' => 'rosto sorridente',
    '😚' => 'rosto beijando com olhos fechados',
    '😙' => 'rosto beijando com olhos sorridentes',
    '🥲' => 'rosto sorridente com lágrima',
    '😋' => 'rosto saboreando comida',
    '😛' => 'rosto mostrando a língua',
    '😜' => 'rosto piscando e com língua para fora',
    '🤪' => 'rosto bizarro',
    '😝' => 'rosto com olhos semicerrados e língua para fora',
    '🤑' => 'rosto com cifrões',
    '🤗' => 'rosto abraçando',
    '🤭' => 'rosto com a mão sobre a boca',
    '🫢' => 'rosto com olhos abertos e mão sobre a boca',
    '🫣' => 'rosto com olho espiando',
    '🤫' => 'rosto fazendo sinal de silêncio',
    '🤔' => 'rosto pensativo',
    '🫡' => 'rosto saudando',
    '🤐' => 'rosto com boca de zíper',
    '🤨' => 'rosto com sobrancelha levantada',
    '😐' => 'rosto neutro',
    '😑' => 'rosto inexpressivo',
    '😶' => 'rosto sem boca',
    '🫥' => 'rosto com linha pontilhada',
    '😏' => 'rosto com sorriso maroto',
    '😒' => 'rosto aborrecido',
    '🙄' => 'rosto com olhos revirados',
    '😬' => 'rosto expressando desagrado',
    '🤥' => 'rosto de mentiroso',
    '🫨' => 'rosto tremendo',
    '😌' => 'rosto aliviado',
    '😔' => 'rosto deprimido',
    '😪' => 'rosto sonolento',
    '🤤' => 'rosto babando',
    '😴' => 'rosto dormindo',
    '🫩' => 'rosto com olheiras',
    '😷' => 'rosto com máscara médica',
    '🤒' => 'rosto com termômetro',
    '🤕' => 'rosto com atadura na cabeça',
    '🤢' => 'rosto nauseado',
    '🤮' => 'rosto vomitando',
    '🤧' => 'rosto espirrando',
    '🥵' => 'rosto fervendo de calor',
    '🥶' => 'rosto gelado',
    '🥴' => 'rosto embriagado',
    '😵' => 'rosto atordoado',
    '🤯' => 'cabeça explodindo',
    '🤠' => 'rosto com chapéu de caubói',
    '🥳' => 'rosto festivo',
    '🥸' => 'rosto disfarçado',
    '😎' => 'rosto sorridente com óculos escuros',
    '🤓' => 'rosto de nerd',
    '🧐' => 'rosto com monóculo',
    '😕' => 'rosto confuso',
    '🫤' => 'rosto com boca diagonal',
    '😟' => 'rosto preocupado',
    '🙁' => 'rosto meio triste',
    '☹' => 'rosto descontente',
    '😮' => 'rosto com boca aberta',
    '😯' => 'rosto surpreso',
    '😲' => 'rosto espantado',
    '😳' => 'rosto ruborizado',
    '🫪' => 'rosto distorcido',
    '🥺' => 'rosto implorando',
    '🥹' => 'rosto segurando as lágrimas',
    '😦' => 'rosto franzido com boca aberta',
    '😧' => 'rosto angustiado',
    '😨' => 'rosto amedrontado',
    '😰' => 'rosto ansioso com gota de suor',
    '😥' => 'rosto triste, mas aliviado',
    '😢' => 'rosto chorando',
    '😭' => 'rosto chorando aos berros',
    '😱' => 'rosto gritando de medo',
    '😖' => 'rosto perplexo',
    '😣' => 'rosto perseverante',
    '😞' => 'rosto desapontado',
    '😓' => 'rosto cabisbaixo com gota de suor',
    '😩' => 'rosto desolado',
    '😫' => 'rosto cansado',
    '🥱' => 'rosto bocejando',
    '😤' => 'rosto soltando vapor pelo nariz',
    '😡' => 'rosto furioso',
    '😠' => 'rosto zangado',
    '🤬' => 'rosto com símbolos na boca',
    '😈' => 'rosto sorridente com chifres',
    '👿' => 'rosto zangado com chifres',
    '💀' => 'caveira',
    '☠' => 'caveira e ossos cruzados',
    '💩' => 'cocô',
    '🤡' => 'rosto de palhaço',
    '👹' => 'ogro',
    '👺' => 'duende japonês',
    '👻' => 'fantasma',
    '👽' => 'alienígena',
    '👾' => 'monstro alienígena',
    '🤖' => 'rosto de robô',
    '😺' => 'rosto de gato sorrindo',
    '😸' => 'rosto de gato sorrindo com olhos sorridentes',
    '😹' => 'rosto de gato com lágrimas de alegria',
    '😻' => 'rosto de gato sorridente com olhos de coração',
    '😼' => 'rosto de gato com sorriso irônico',
    '😽' => 'rosto de gato mandando um beijo',
    '🙀' => 'rosto de gato desolado',
    '😿' => 'rosto de gato chorando',
    '😾' => 'rosto de gato mal-humorado',
    '🙈' => 'macaco que não vê nada',
    '🙉' => 'macaco que não ouve nada',
    '🙊' => 'macaco que não fala nada',
    '💌' => 'carta de amor',
    '💘' => 'coração com flecha',
    '💝' => 'coração com fita',
    '💖' => 'coração brilhante',
    '💗' => 'coração crescendo',
    '💓' => 'coração pulsante',
    '💞' => 'corações girando',
    '💕' => 'dois corações',
    '💟' => 'coração decorativo',
    '❣' => 'exclamação de coração',
    '💔' => 'coração partido',
    '❤' => 'coração vermelho',
    '🩷' => 'coração rosa',
    '🧡' => 'coração laranja',
    '💛' => 'coração amarelo',
    '💚' => 'coração verde',
    '💙' => 'coração azul',
    '🩵' => 'coração azul-claro',
    '💜' => 'coração roxo',
    '🤎' => 'coração marrom',
    '🖤' => 'coração preto',
    '🩶' => 'coração cinza',
    '🤍' => 'coração branco',
    '💋' => 'marca de beijo',
    '💯' => 'cem pontos',
    '💢' => 'símbolo de raiva',
    '🫯' => 'nuvem de briga',
    '💥' => 'colisão',
    '💫' => 'zonzo',
    '💦' => 'pingos de suor',
    '💨' => 'rapidez',
    '🕳' => 'buraco',
    '💬' => 'balão de diálogo',
    '🗨' => 'balão de diálogo à esquerda',
    '🗯' => 'balão de raiva à direita',
    '💭' => 'balão de pensamento',
    '💤' => 'zzz',
    '👋' => 'mão acenando',
    '🤚' => 'dorso da mão levantado',
    '🖐' => 'mão aberta com os dedos separados',
    '✋' => 'mão levantada',
    '🖖' => 'saudação vulcana',
    '🫱' => 'mão para a direita',
    '🫲' => 'mão para a esquerda',
    '🫳' => 'mão com a palma para baixo',
    '🫴' => 'mão com a palma para cima',
    '🫷' => 'mão empurrando para a esquerda',
    '🫸' => 'mão empurrando para a direita',
    '👌' => 'sinal de ok',
    '🤌' => 'dedos comprimidos',
    '🤏' => 'mão beliscando',
    '✌' => 'mão em V de vitória',
    '🤞' => 'dedos cruzados',
    '🫰' => 'mão com dedo indicador e polegar cruzados',
    '🤟' => 'gesto de "te amo"',
    '🤘' => 'saudação do rock',
    '🤙' => 'sinal "me liga"',
    '👈' => 'dorso da mão com indicador apontando para a esquerda',
    '👉' => 'dorso da mão com indicador apontando para a direita',
    '👆' => 'dorso da mão com indicador apontando para cima',
    '🖕' => 'dedo do meio',
    '👇' => 'dorso da mão com indicador apontando para baixo',
    '☝' => 'indicador apontando para cima',
    '🫵' => 'indicador apontando para o visualizador',
    '👍' => 'polegar para cima',
    '👎' => 'polegar para baixo',
    '✊' => 'punho levantado',
    '👊' => 'soco',
    '🤛' => 'punho esquerdo',
    '🤜' => 'punho direito',
    '👏' => 'mãos aplaudindo',
    '🙌' => 'mãos para cima',
    '🫶' => 'mãos de coração',
    '👐' => 'mãos abertas',
    '🤲' => 'palmas unidas para cima',
    '🤝' => 'aperto de mãos',
    '🙏' => 'mãos juntas',
    '✍' => 'escrevendo à mão',
    '💅' => 'esmalte de unha',
    '🤳' => 'selfie',
    '💪' => 'bíceps',
    '🦾' => 'braço mecânico',
    '🦿' => 'perna mecânica',
    '🦵' => 'perna',
    '🦶' => 'pé',
    '👂' => 'orelha',
    '🦻' => 'ouvido com aparelho auditivo',
    '👃' => 'nariz',
    '🧠' => 'cérebro',
    '🫀' => 'coração humano',
    '🫁' => 'pulmões',
    '🦷' => 'dente',
    '🦴' => 'osso',
    '👀' => 'olhos',
    '👁' => 'olho',
    '👅' => 'língua',
    '👄' => 'boca',
    '🫦' => 'mordendo o lábio',
    '👶' => 'bebê',
    '🧒' => 'criança',
    '👦' => 'menino',
    '👧' => 'menina',
    '🧑' => 'pessoa',
    '👱' => 'pessoa: cabelo louro',
    '👨' => 'homem',
    '🧔' => 'homem: barba',
    '👩' => 'mulher',
    '🧓' => 'idoso',
    '👴' => 'homem idoso',
    '👵' => 'idosa',
    '🙍' => 'franzindo a sobrancelha',
    '🙎' => 'pessoa fazendo bico',
    '🙅' => 'pessoa fazendo gesto de “não”',
    '🙆' => 'pessoa fazendo gesto de “OK”',
    '💁' => 'pessoa com a palma virada para cima',
    '🙋' => 'pessoa levantando a mão',
    '🧏' => 'pessoa surda',
    '🙇' => 'pessoa fazendo reverência',
    '🤦' => 'pessoa decepcionada',
    '🤷' => 'pessoa dando de ombros',
    '👮' => 'policial',
    '🕵' => 'detetive',
    '💂' => 'guarda',
    '🥷' => 'ninja',
    '👷' => 'trabalhador de construção civil',
    '🫅' => 'pessoa com coroa',
    '🤴' => 'príncipe',
    '👸' => 'princesa',
    '👳' => 'pessoa com turbante',
    '👲' => 'homem de boné',
    '🧕' => 'mulher com véu',
    '🤵' => 'pessoa de smoking',
    '👰' => 'pessoa com véu',
    '🤰' => 'grávida',
    '🫃' => 'homem grávido',
    '🫄' => 'pessoa grávida',
    '🤱' => 'amamentando',
    '👼' => 'bebê anjo',
    '🎅' => 'Papai Noel',
    '🤶' => 'Mamãe Noel',
    '🦸' => 'super-herói',
    '🦹' => 'supervilão',
    '🧙' => 'mago',
    '🧚' => 'fada',
    '🧛' => 'vampiro',
    '🧜' => 'pessoa sereia',
    '🧝' => 'elfo',
    '🧞' => 'gênio',
    '🧟' => 'zumbi',
    '🧌' => 'troll',
    '🫈' => 'criatura peluda',
    '💆' => 'pessoa recebendo massagem facial',
    '💇' => 'pessoa cortando o cabelo',
    '🚶' => 'pessoa andando',
    '🧍' => 'pessoa em pé',
    '🧎' => 'pessoa ajoelhando',
    '🏃' => 'pessoa correndo',
    '💃' => 'mulher dançando',
    '🕺' => 'homem dançando',
    '🕴' => 'homem de terno levitando',
    '👯' => 'pessoas com orelhas de coelho',
    '🧖' => 'pessoa na sauna',
    '🧗' => 'pessoa escalando',
    '🤺' => 'esgrimista',
    '🏇' => 'corrida de cavalos',
    '⛷' => 'esquiador',
    '🏂' => 'praticante de snowboard',
    '🏌' => 'golfista',
    '🏄' => 'surfista',
    '🚣' => 'pessoa remando',
    '🏊' => 'pessoa nadando',
    '⛹' => 'pessoa jogando basquete',
    '🏋' => 'pessoa levantando peso',
    '🚴' => 'ciclista',
    '🚵' => 'pessoa fazendo mountain bike',
    '🤸' => 'pessoa fazendo estrela',
    '🤼' => 'pessoas lutando',
    '🤽' => 'pessoa jogando polo aquático',
    '🤾' => 'handebol',
    '🤹' => 'malabarista',
    '🧘' => 'pessoa na posição de lótus',
    '🛀' => 'pessoa tomando banho',
    '🛌' => 'pessoa deitada na cama',
    '👭' => 'duas mulheres de mãos dadas',
    '👫' => 'homem e mulher de mãos dadas',
    '👬' => 'dois homens de mãos dadas',
    '💏' => 'beijo',
    '💑' => 'casal apaixonado',
    '🗣' => 'silhueta falando',
    '👤' => 'silhueta de busto',
    '👥' => 'silhueta de bustos',
    '🫂' => 'pessoas se abraçando',
    '👪' => 'família',
    '👣' => 'pegadas',
    '🫆' => 'impressão digital',
    '🦰' => 'cabelo vermelho',
    '🦱' => 'cabelo cacheado',
    '🦳' => 'cabelo branco',
    '🦲' => 'careca',
    '🐵' => 'rosto de macaco',
    '🐒' => 'macaco',
    '🦍' => 'gorila',
    '🦧' => 'orangotango',
    '🐶' => 'rosto de cachorro',
    '🐕' => 'cachorro',
    '🦮' => 'cão-guia',
    '🐩' => 'poodle',
    '🐺' => 'rosto de lobo',
    '🦊' => 'rosto de raposa',
    '🦝' => 'guaxinim',
    '🐱' => 'rosto de gato',
    '🐈' => 'gato',
    '🦁' => 'rosto de leão',
    '🐯' => 'rosto de tigre',
    '🐅' => 'tigre',
    '🐆' => 'leopardo',
    '🐴' => 'rosto de cavalo',
    '🫎' => 'alce',
    '🫏' => 'burro',
    '🐎' => 'cavalo',
    '🦄' => 'rosto de unicórnio',
    '🦓' => 'zebra',
    '🦌' => 'cervo',
    '🦬' => 'bisão',
    '🐮' => 'rosto de vaca',
    '🐂' => 'boi',
    '🐃' => 'búfalo-asiático',
    '🐄' => 'vaca',
    '🐷' => 'rosto de porco',
    '🐖' => 'porco',
    '🐗' => 'javali',
    '🐽' => 'nariz de porco',
    '🐏' => 'carneiro',
    '🐑' => 'ovelha',
    '🐐' => 'cabra',
    '🐪' => 'camelo',
    '🐫' => 'camelo com duas corcovas',
    '🦙' => 'lhama',
    '🦒' => 'girafa',
    '🐘' => 'elefante',
    '🦣' => 'mamute',
    '🦏' => 'rinoceronte',
    '🦛' => 'hipopótamo',
    '🐭' => 'rosto de camundongo',
    '🐁' => 'camundongo',
    '🐀' => 'rato',
    '🐹' => 'rosto de hamster',
    '🐰' => 'rosto de coelho',
    '🐇' => 'coelho',
    '🐿' => 'esquilo',
    '🦫' => 'castor',
    '🦔' => 'porco-espinho',
    '🦇' => 'morcego',
    '🐻' => 'rosto de urso',
    '🐨' => 'coala',
    '🐼' => 'rosto de panda',
    '🦥' => 'preguiça',
    '🦦' => 'lontra',
    '🦨' => 'gambá',
    '🦘' => 'canguru',
    '🦡' => 'texugo',
    '🐾' => 'patas',
    '🦃' => 'peru',
    '🐔' => 'galinha',
    '🐓' => 'galo',
    '🐣' => 'pintinho chocando',
    '🐤' => 'pintinho de perfil',
    '🐥' => 'pintinho de frente',
    '🐦' => 'pássaro',
    '🐧' => 'pinguim',
    '🕊' => 'pomba branca',
    '🦅' => 'águia',
    '🦆' => 'pato',
    '🦢' => 'cisne',
    '🦉' => 'coruja',
    '🦤' => 'dodô',
    '🪶' => 'pena',
    '🦩' => 'flamingo',
    '🦚' => 'pavão',
    '🦜' => 'papagaio',
    '🪽' => 'asa',
    '🪿' => 'ganso',
    '🐸' => 'sapo',
    '🐊' => 'crocodilo',
    '🐢' => 'tartaruga',
    '🦎' => 'lagartixa',
    '🐍' => 'cobra',
    '🐲' => 'rosto de dragão',
    '🐉' => 'dragão',
    '🦕' => 'saurópode',
    '🦖' => 'tiranossauro rex',
    '🐳' => 'baleia esguichando água',
    '🐋' => 'baleia',
    '🐬' => 'golfinho',
    '🫍' => 'orca',
    '🦭' => 'foca',
    '🐟' => 'peixe',
    '🐠' => 'peixe tropical',
    '🐡' => 'baiacu',
    '🦈' => 'tubarão',
    '🐙' => 'polvo',
    '🐚' => 'caramujo',
    '🪸' => 'coral',
    '🪼' => 'água-viva',
    '🦀' => 'caranguejo',
    '🦞' => 'lagosta',
    '🦐' => 'camarão',
    '🦑' => 'lula',
    '🦪' => 'ostra',
    '🐌' => 'caracol',
    '🦋' => 'borboleta',
    '🐛' => 'inseto',
    '🐜' => 'formiga',
    '🐝' => 'abelha',
    '🪲' => 'besouro',
    '🐞' => 'joaninha',
    '🦗' => 'grilo',
    '🪳' => 'barata',
    '🕷' => 'aranha',
    '🕸' => 'teia de aranha',
    '🦂' => 'escorpião',
    '🦟' => 'mosquito',
    '🪰' => 'mosca',
    '🪱' => 'minhoca',
    '🦠' => 'micróbio',
    '💐' => 'buquê',
    '🌸' => 'flor de cerejeira',
    '💮' => 'flor branca',
    '🪷' => 'lótus',
    '🏵' => 'roseta',
    '🌹' => 'rosa',
    '🥀' => 'flor murcha',
    '🌺' => 'hibisco',
    '🌻' => 'girassol',
    '🌼' => 'flor',
    '🌷' => 'tulipa',
    '🪻' => 'jacinto',
    '🌱' => 'muda de planta',
    '🪴' => 'vaso com planta',
    '🌲' => 'conífera',
    '🌳' => 'árvore caidiça',
    '🌴' => 'palmeira',
    '🌵' => 'cacto',
    '🌾' => 'planta de arroz',
    '🌿' => 'erva',
    '☘' => 'trevo',
    '🍀' => 'trevo de quatro folhas',
    '🍁' => 'folha de bordo',
    '🍂' => 'folhas caídas',
    '🍃' => 'folha ao vento',
    '🪹' => 'ninho vazio',
    '🪺' => 'ninho com ovos',
    '🍄' => 'cogumelo',
    '🪾' => 'árvore seca',
    '🍇' => 'uvas',
    '🍈' => 'melão',
    '🍉' => 'melancia',
    '🍊' => 'tangerina',
    '🍋' => 'limão',
    '🍌' => 'banana',
    '🍍' => 'abacaxi',
    '🥭' => 'manga',
    '🍎' => 'maçã vermelha',
    '🍏' => 'maçã verde',
    '🍐' => 'pera',
    '🍑' => 'pêssego',
    '🍒' => 'cereja',
    '🍓' => 'morango',
    '🫐' => 'mirtilos',
    '🥝' => 'kiwi',
    '🍅' => 'tomate',
    '🫒' => 'azeitona',
    '🥥' => 'coco',
    '🥑' => 'abacate',
    '🍆' => 'berinjela',
    '🥔' => 'batata',
    '🥕' => 'cenoura',
    '🌽' => 'milho',
    '🌶' => 'pimenta',
    '🫑' => 'pimentão',
    '🥒' => 'pepino',
    '🥬' => 'verdura',
    '🥦' => 'brócolis',
    '🧄' => 'alho',
    '🧅' => 'cebola',
    '🥜' => 'amendoim',
    '🫘' => 'feijões',
    '🌰' => 'castanha',
    '🫚' => 'gengibre',
    '🫛' => 'vagem',
    '🫜' => 'tubérculo',
    '🍞' => 'pão',
    '🥐' => 'croissant',
    '🥖' => 'baguete',
    '🫓' => 'pão sírio',
    '🥨' => 'pretzel',
    '🥯' => 'bagel',
    '🥞' => 'panquecas',
    '🧇' => 'waffle',
    '🧀' => 'queijo',
    '🍖' => 'carne',
    '🍗' => 'coxa de frango',
    '🥩' => 'corte de carne',
    '🥓' => 'bacon',
    '🍔' => 'hambúrguer',
    '🍟' => 'batata frita',
    '🍕' => 'pizza',
    '🌭' => 'cachorro-quente',
    '🥪' => 'sanduíche',
    '🌮' => 'taco',
    '🌯' => 'burrito',
    '🫔' => 'tamale',
    '🥙' => 'pão recheado',
    '🧆' => 'falafel',
    '🥚' => 'ovo',
    '🍳' => 'ovo frito',
    '🥘' => 'caçarola com comida',
    '🍲' => 'panela',
    '🫕' => 'fondue',
    '🥣' => 'tigela com colher',
    '🥗' => 'salada verde',
    '🍿' => 'pipoca',
    '🧈' => 'manteiga',
    '🧂' => 'sal',
    '🥫' => 'comida enlatada',
    '🍱' => 'bentô',
    '🍘' => 'biscoito de arroz',
    '🍙' => 'arroz japonês',
    '🍚' => 'arroz cozido',
    '🍛' => 'arroz com curry',
    '🍜' => 'lámen',
    '🍝' => 'espaguete',
    '🍠' => 'batata assada',
    '🍢' => 'oden',
    '🍣' => 'sushi',
    '🍤' => 'camarão frito',
    '🍥' => 'bolinho de peixe',
    '🥮' => 'bolo lunar',
    '🍡' => 'dango',
    '🥟' => 'bolinho asiático',
    '🥠' => 'biscoito da sorte',
    '🥡' => 'caixa para viagem',
    '🍦' => 'sorvete italiano',
    '🍧' => 'raspadinha de gelo',
    '🍨' => 'sorvete',
    '🍩' => 'donut',
    '🍪' => 'biscoito',
    '🎂' => 'bolo de aniversário',
    '🍰' => 'pão de ló de morango',
    '🧁' => 'cupcake',
    '🥧' => 'torta',
    '🍫' => 'chocolate',
    '🍬' => 'bala',
    '🍭' => 'pirulito',
    '🍮' => 'pudim',
    '🍯' => 'pote de mel',
    '🍼' => 'mamadeira',
    '🥛' => 'copo de leite',
    '☕' => 'café',
    '🫖' => 'bule',
    '🍵' => 'xícara de chá sem alça',
    '🍶' => 'saquê',
    '🍾' => 'garrafa de champanhe',
    '🍷' => 'vinho',
    '🍸' => 'coquetel',
    '🍹' => 'bebida tropical',
    '🍺' => 'cerveja',
    '🍻' => 'canecas de cerveja',
    '🥂' => 'taças brindando',
    '🥃' => 'copo',
    '🫗' => 'derramando líquido',
    '🥤' => 'copo com canudo',
    '🧋' => 'chá perolado',
    '🧃' => 'suco de caixa',
    '🧉' => 'mate',
    '🧊' => 'cubo de gelo',
    '🥢' => 'hashi',
    '🍽' => 'prato com talheres',
    '🍴' => 'garfo e faca',
    '🥄' => 'colher',
    '🔪' => 'faca de cozinha',
    '🫙' => 'jarro',
    '🏺' => 'ânfora',
    '🌍' => 'globo mostrando Europa e África',
    '🌎' => 'globo mostrando as Américas',
    '🌏' => 'globo mostrando Ásia e Oceania',
    '🌐' => 'globo com meridianos',
    '🗺' => 'mapa-múndi',
    '🗾' => 'mapa do Japão',
    '🧭' => 'bússola',
    '🏔' => 'montanha com neve',
    '⛰' => 'montanha',
    '🛘' => 'deslizamento',
    '🌋' => 'vulcão',
    '🗻' => 'Monte Fuji',
    '🏕' => 'acampamento',
    '🏖' => 'praia e guarda-sol',
    '🏜' => 'deserto',
    '🏝' => 'ilha deserta',
    '🏞' => 'parque nacional',
    '🏟' => 'estádio',
    '🏛' => 'prédio grego',
    '🏗' => 'construção',
    '🧱' => 'tijolo',
    '🪨' => 'pedra',
    '🪵' => 'madeira',
    '🛖' => 'cabana',
    '🏘' => 'casas',
    '🏚' => 'casa abandonada',
    '🏠' => 'casa',
    '🏡' => 'casa com jardim',
    '🏢' => 'edifício comercial',
    '🏣' => 'correio japonês',
    '🏤' => 'correio',
    '🏥' => 'hospital',
    '🏦' => 'banco',
    '🏨' => 'hotel',
    '🏩' => 'motel',
    '🏪' => 'loja de conveniência',
    '🏫' => 'escola',
    '🏬' => 'loja de departamentos',
    '🏭' => 'fábrica',
    '🏯' => 'castelo japonês',
    '🏰' => 'castelo',
    '💒' => 'capela de casamento',
    '🗼' => 'Torre de Tóquio',
    '🗽' => 'Estátua da Liberdade',
    '⛪' => 'igreja',
    '🕌' => 'mesquita',
    '🛕' => 'templo hindu',
    '🕍' => 'sinagoga',
    '⛩' => 'santuário japonês',
    '🕋' => 'caaba islã',
    '⛲' => 'fonte',
    '⛺' => 'barraca',
    '🌁' => 'enevoado',
    '🌃' => 'noite estrelada',
    '🏙' => 'cidade',
    '🌄' => 'aurora sobre montanhas',
    '🌅' => 'aurora sobre água',
    '🌆' => 'cidade ao anoitecer',
    '🌇' => 'pôr do sol',
    '🌉' => 'ponte à noite',
    '♨' => 'chamas',
    '🎠' => 'carrossel',
    '🛝' => 'escorregador',
    '🎡' => 'roda gigante',
    '🎢' => 'montanha russa',
    '💈' => 'barbearia',
    '🎪' => 'circo',
    '🚂' => 'locomotiva',
    '🚃' => 'vagão de trem',
    '🚄' => 'trem de alta velocidade',
    '🚅' => 'trem de alta velocidade japonês',
    '🚆' => 'trem',
    '🚇' => 'metrô',
    '🚈' => 'trem urbano',
    '🚉' => 'estação',
    '🚊' => 'bonde elétrico',
    '🚝' => 'monotrilho',
    '🚞' => 'estrada de ferro na montanha',
    '🚋' => 'bonde',
    '🚌' => 'ônibus',
    '🚍' => 'ônibus se aproximando',
    '🚎' => 'trólebus',
    '🚐' => 'van',
    '🚑' => 'ambulância',
    '🚒' => 'carro do corpo de bombeiros',
    '🚓' => 'viatura policial',
    '🚔' => 'viatura policial se aproximando',
    '🚕' => 'táxi',
    '🚖' => 'táxi se aproximando',
    '🚗' => 'carro',
    '🚘' => 'carro se aproximando',
    '🚙' => 'SUV',
    '🛻' => 'caminhonete',
    '🚚' => 'caminhão de entrega',
    '🚛' => 'caminhão',
    '🚜' => 'trator',
    '🏎' => 'carro de corrida',
    '🏍' => 'motocicleta',
    '🛵' => 'scooter',
    '🦽' => 'cadeira de rodas manual',
    '🦼' => 'cadeira de rodas motorizada',
    '🛺' => 'automóvel riquixá',
    '🚲' => 'bicicleta',
    '🛴' => 'patinete',
    '🛹' => 'skate',
    '🛼' => 'patins de rodas',
    '🚏' => 'ponto de ônibus',
    '🛣' => 'estrada',
    '🛤' => 'trilhos',
    '🛢' => 'barril de óleo',
    '⛽' => 'posto de gasolina',
    '🛞' => 'roda',
    '🚨' => 'sirene',
    '🚥' => 'semáforo horizontal',
    '🚦' => 'semáforo vertical',
    '🛑' => 'sinal de pare',
    '🚧' => 'em construção',
    '⚓' => 'âncora',
    '🛟' => 'boia',
    '⛵' => 'barco a vela',
    '🛶' => 'canoa',
    '🚤' => 'lancha',
    '🛳' => 'cruzeiro',
    '⛴' => 'balsa',
    '🛥' => 'barco',
    '🚢' => 'navio',
    '✈' => 'avião',
    '🛩' => 'avião pequeno',
    '🛫' => 'avião decolando',
    '🛬' => 'avião aterrissando',
    '🪂' => 'paraquedas',
    '💺' => 'assento',
    '🚁' => 'helicóptero',
    '🚟' => 'estrada de ferro suspensa',
    '🚠' => 'teleférico de montanha',
    '🚡' => 'teleférico',
    '🛰' => 'satélite',
    '🚀' => 'foguete',
    '🛸' => 'disco voador',
    '🛎' => 'sineta',
    '🧳' => 'mala',
    '⌛' => 'ampulheta',
    '⏳' => 'ampulheta contando o tempo',
    '⌚' => 'relógio de pulso',
    '⏰' => 'despertador',
    '⏱' => 'cronômetro',
    '⏲' => 'relógio temporizador',
    '🕰' => 'relógio de mesa',
    '🕛' => '12 horas',
    '🕧' => 'doze e meia',
    '🕐' => '1 hora',
    '🕜' => 'uma e meia',
    '🕑' => '2 horas',
    '🕝' => 'duas e meia',
    '🕒' => '3 horas',
    '🕞' => 'três e meia',
    '🕓' => '4 horas',
    '🕟' => 'quatro e meia',
    '🕔' => '5 horas',
    '🕠' => 'cinco e meia',
    '🕕' => '6 horas',
    '🕡' => 'seis e meia',
    '🕖' => '7 horas',
    '🕢' => 'sete e meia',
    '🕗' => '8 horas',
    '🕣' => 'oito e meia',
    '🕘' => '9 horas',
    '🕤' => 'nove e meia',
    '🕙' => '10 horas',
    '🕥' => 'dez e meia',
    '🕚' => '11 horas',
    '🕦' => 'onze e meia',
    '🌑' => 'lua nova',
    '🌒' => 'lua crescente côncava',
    '🌓' => 'quarto crescente',
    '🌔' => 'lua crescente convexa',
    '🌕' => 'lua cheia',
    '🌖' => 'lua minguante convexa',
    '🌗' => 'quarto minguante',
    '🌘' => 'lua minguante côncava',
    '🌙' => 'lua crescente',
    '🌚' => 'rosto da lua nova',
    '🌛' => 'rosto da lua de quarto crescente',
    '🌜' => 'rosto da lua de quarto minguante',
    '🌡' => 'termômetro',
    '☀' => 'sol',
    '🌝' => 'rosto da lua cheia',
    '🌞' => 'rosto do sol',
    '🪐' => 'planeta com anéis',
    '⭐' => 'estrela branca média',
    '🌟' => 'estrela brilhante',
    '🌠' => 'estrela cadente',
    '🌌' => 'via láctea',
    '☁' => 'nuvem',
    '⛅' => 'sol por trás das nuvens',
    '⛈' => 'chuva com trovão',
    '🌤' => 'sol com nuvens',
    '🌥' => 'nublado',
    '🌦' => 'sol com chuva',
    '🌧' => 'nuvem com chuva',
    '🌨' => 'nuvem com neve',
    '🌩' => 'nuvem com trovão',
    '🌪' => 'tornado',
    '🌫' => 'nevoeiro',
    '🌬' => 'rosto de vento',
    '🌀' => 'ciclone',
    '🌈' => 'arco-íris',
    '🌂' => 'guarda-chuva fechado',
    '☂' => 'guarda-chuva',
    '☔' => 'sombrinha na chuva',
    '⛱' => 'guarda-sol',
    '⚡' => 'alta tensão',
    '❄' => 'floco de neve',
    '☃' => 'boneco de neve',
    '⛄' => 'boneco de neve sem neve',
    '☄' => 'cometa',
    '🔥' => 'fogo',
    '💧' => 'gota',
    '🌊' => 'onda',
    '🎃' => 'abóbora de halloween',
    '🎄' => 'árvore de natal',
    '🎆' => 'fogos de artifício',
    '🎇' => 'vela estrela',
    '🧨' => 'bombinha',
    '✨' => 'brilhos',
    '🎈' => 'balão',
    '🎉' => 'cone de festa',
    '🎊' => 'confete',
    '🎋' => 'árvore de tanabata',
    '🎍' => 'decoração de pinhos',
    '🎎' => 'bonecas japonesas',
    '🎏' => 'bandeira de carpas',
    '🎐' => 'carrilhão de vento',
    '🎑' => 'contemplação da lua',
    '🧧' => 'envelope vermelho',
    '🎀' => 'laço de fita',
    '🎁' => 'presente',
    '🎗' => 'fita de lembrete',
    '🎟' => 'ingresso de cinema',
    '🎫' => 'ingresso',
    '🎖' => 'medalha militar',
    '🏆' => 'troféu',
    '🏅' => 'medalha esportiva',
    '🥇' => 'medalha de ouro',
    '🥈' => 'medalha de prata',
    '🥉' => 'medalha de bronze',
    '⚽' => 'bola de futebol',
    '⚾' => 'bola de beisebol',
    '🥎' => 'softbol',
    '🏀' => 'bola de basquete',
    '🏐' => 'bola de vôlei',
    '🏈' => 'bola de futebol americano',
    '🏉' => 'bola de rugby',
    '🎾' => 'tênis',
    '🥏' => 'frisbee',
    '🎳' => 'boliche',
    '🏏' => 'críquete',
    '🏑' => 'hóquei de campo',
    '🏒' => 'hóquei no gelo',
    '🥍' => 'lacrosse',
    '🏓' => 'pingue-pongue',
    '🏸' => 'badminton',
    '🥊' => 'luva de boxe',
    '🥋' => 'quimono de artes marciais',
    '🥅' => 'gol',
    '⛳' => 'bandeira no buraco',
    '⛸' => 'patins de gelo',
    '🎣' => 'pesca',
    '🤿' => 'máscara de mergulho',
    '🎽' => 'camiseta de corrida',
    '🎿' => 'esqui',
    '🛷' => 'trenó',
    '🥌' => 'pedra de curling',
    '🎯' => 'no alvo',
    '🪀' => 'ioiô',
    '🪁' => 'pipa',
    '🔫' => 'pistola d’água',
    '🎱' => 'bilhar',
    '🔮' => 'bola de cristal',
    '🪄' => 'varinha mágica',
    '🎮' => 'videogame',
    '🕹' => 'joystick',
    '🎰' => 'caça-níquel',
    '🎲' => 'jogo de dado',
    '🧩' => 'quebra-cabeça',
    '🧸' => 'ursinho de pelúcia',
    '🪅' => 'pinhata',
    '🪩' => 'globo de espelhos',
    '🪆' => 'boneca russa',
    '♠' => 'naipe de espadas',
    '♥' => 'naipe de copas',
    '♦' => 'naipe de ouros',
    '♣' => 'naipe de paus',
    '♟' => 'peão de xadrez',
    '🃏' => 'curinga',
    '🀄' => 'dragão vermelho de mahjong',
    '🎴' => 'carta de flores',
    '🎭' => 'máscara',
    '🖼' => 'quadro emoldurado',
    '🎨' => 'paleta de tintas',
    '🧵' => 'carretel',
    '🪡' => 'agulha de costura',
    '🧶' => 'novelo',
    '🪢' => 'nó',
    '👓' => 'óculos',
    '🕶' => 'óculos escuros',
    '🥽' => 'óculos de proteção',
    '🥼' => 'jaleco',
    '🦺' => 'colete salva-vidas',
    '👔' => 'gravata',
    '👕' => 'camiseta',
    '👖' => 'jeans',
    '🧣' => 'cachecol',
    '🧤' => 'luvas',
    '🧥' => 'casaco',
    '🧦' => 'meias',
    '👗' => 'vestido',
    '👘' => 'quimono',
    '🥻' => 'sari',
    '🩱' => 'maiô',
    '🩲' => 'cueca',
    '🩳' => 'shorts',
    '👙' => 'biquíni',
    '👚' => 'roupas femininas',
    '🪭' => 'leque dobrável',
    '👛' => 'bolsinha',
    '👜' => 'bolsa de mão',
    '👝' => 'bolsa pequena',
    '🛍' => 'sacolas de compras',
    '🎒' => 'mochila',
    '🩴' => 'chinelo',
    '👞' => 'sapato masculino',
    '👟' => 'tênis de corrida',
    '🥾' => 'bota de trekking',
    '🥿' => 'sapatilha',
    '👠' => 'sapato de salto alto',
    '👡' => 'sandália feminina',
    '🩰' => 'sapatilha de balé',
    '👢' => 'bota feminina',
    '🪮' => 'pente de cabelo',
    '👑' => 'coroa',
    '👒' => 'chapéu feminino',
    '🎩' => 'cartola',
    '🎓' => 'chapéu de formatura',
    '🧢' => 'boné',
    '🪖' => 'capacete militar',
    '⛑' => 'capacacete de socorrista',
    '📿' => 'rosário de oração',
    '💄' => 'batom',
    '💍' => 'anel',
    '💎' => 'pedra preciosa',
    '🔇' => 'alto-falante silenciado',
    '🔈' => 'alto-falante com volume baixo',
    '🔉' => 'alto-falante com volume médio',
    '🔊' => 'alto-falante com volume alto',
    '📢' => 'buzina',
    '📣' => 'megafone',
    '📯' => 'corneta postal',
    '🔔' => 'sino',
    '🔕' => 'sino silenciado',
    '🎼' => 'partitura musical',
    '🎵' => 'nota musical',
    '🎶' => 'notas musicais',
    '🎙' => 'microfone de estúdio',
    '🎚' => 'controle de volume',
    '🎛' => 'botões giratórios',
    '🎤' => 'microfone',
    '🎧' => 'fones de ouvido',
    '📻' => 'rádio',
    '🎷' => 'saxofone',
    '🎺' => 'trompete',
    '🪊' => 'trombone',
    '🪗' => 'acordeão',
    '🎸' => 'guitarra',
    '🎹' => 'teclado musical',
    '🎻' => 'violino',
    '🪕' => 'banjo',
    '🥁' => 'tambor',
    '🪘' => 'tambor comprido',
    '🪇' => 'maracás',
    '🪈' => 'flauta',
    '🪉' => 'harpa',
    '📱' => 'telefone celular',
    '📲' => 'telefone celular com seta',
    '☎' => 'telefone no gancho',
    '📞' => 'telefone',
    '📟' => 'pager',
    '📠' => 'fax',
    '🔋' => 'pilha',
    '🪫' => 'pouca bateria',
    '🔌' => 'tomada elétrica',
    '💻' => 'laptop',
    '🖥' => 'computador de mesa',
    '🖨' => 'impressora',
    '⌨' => 'teclado',
    '🖱' => 'mouse',
    '🖲' => 'trackball',
    '💽' => 'minidisc',
    '💾' => 'disquete',
    '💿' => 'cd',
    '📀' => 'DVD',
    '🧮' => 'ábaco',
    '🎥' => 'câmera de cinema',
    '🎞' => 'rolo de filmes',
    '📽' => 'projetor de filmes',
    '🎬' => 'claquete',
    '📺' => 'televisão',
    '📷' => 'câmera',
    '📸' => 'câmera com flash',
    '📹' => 'câmera de vídeo',
    '📼' => 'videocassete',
    '🔍' => 'lupa para a esquerda',
    '🔎' => 'lupa para a direita',
    '🕯' => 'vela',
    '💡' => 'lâmpada',
    '🔦' => 'lanterna',
    '🏮' => 'lanterna vermelha de papel',
    '🪔' => 'lâmpada de óleo',
    '📔' => 'caderno decorado',
    '📕' => 'livro fechado',
    '📖' => 'livro aberto',
    '📗' => 'livro verde',
    '📘' => 'livro azul',
    '📙' => 'livro laranja',
    '📚' => 'livros',
    '📓' => 'caderno',
    '📒' => 'livro contábil',
    '📃' => 'página dobrada',
    '📜' => 'pergaminho',
    '📄' => 'página voltada para cima',
    '📰' => 'jornal',
    '🗞' => 'jornal enrolado',
    '📑' => 'marcadores de página',
    '🔖' => 'marcador de página',
    '🏷' => 'etiqueta',
    '🪙' => 'moeda',
    '💰' => 'saco de dinheiro',
    '🪎' => 'baú de tesouro',
    '💴' => 'nota de iene',
    '💵' => 'nota de dólar',
    '💶' => 'nota de euro',
    '💷' => 'nota de libra',
    '💸' => 'dinheiro voando',
    '💳' => 'cartão de crédito',
    '🧾' => 'recibo',
    '💹' => 'gráfico subindo com iene',
    '✉' => 'envelope',
    '📧' => 'e-mail',
    '📨' => 'envelope chegando',
    '📩' => 'envelope com seta',
    '📤' => 'bandeja de saída',
    '📥' => 'bandeja de entrada',
    '📦' => 'pacote',
    '📫' => 'caixa de correio fechada com bandeira levantada',
    '📪' => 'caixa de correio fechada com bandeira abaixada',
    '📬' => 'caixa de correio aberta com bandeira levantada',
    '📭' => 'caixa de correio aberta com bandeira abaixada',
    '📮' => 'caixa de correio',
    '🗳' => 'urna eleitoral com cédula',
    '✏' => 'lápis',
    '✒' => 'ponta de caneta tinteiro',
    '🖋' => 'caneta tinteiro',
    '🖊' => 'caneta',
    '🖌' => 'pincel',
    '🖍' => 'giz de cera',
    '📝' => 'memorando',
    '💼' => 'maleta',
    '📁' => 'pasta de arquivos',
    '📂' => 'pasta de arquivos aberta',
    '🗂' => 'divisores de pastas',
    '📅' => 'calendário',
    '📆' => 'calendário com folhas destacáveis',
    '🗒' => 'bloco espiral',
    '🗓' => 'calendário espiral',
    '📇' => 'índice de cartões',
    '📈' => 'gráfico subindo',
    '📉' => 'gráfico caindo',
    '📊' => 'gráfico de barras',
    '📋' => 'prancheta',
    '📌' => 'tacha',
    '📍' => 'tacha redonda',
    '📎' => 'clipe de papel',
    '🖇' => 'clipes de papel conectados',
    '📏' => 'régua reta',
    '📐' => 'régua triangular',
    '✂' => 'tesoura',
    '🗃' => 'caixa de arquivos',
    '🗄' => 'gavetas de escritório',
    '🗑' => 'lixeira',
    '🔒' => 'cadeado',
    '🔓' => 'cadeado aberto',
    '🔏' => 'cadeado com caneta',
    '🔐' => 'cadeado fechado com chave',
    '🔑' => 'chave',
    '🗝' => 'chave antiga',
    '🔨' => 'martelo',
    '🪓' => 'machado',
    '⛏' => 'picareta',
    '⚒' => 'martelo e picareta',
    '🛠' => 'martelo e chave-inglesa',
    '🗡' => 'adaga',
    '⚔' => 'espadas cruzadas',
    '💣' => 'bomba',
    '🪃' => 'bumerangue',
    '🏹' => 'arco e flecha',
    '🛡' => 'escudo',
    '🪚' => 'serrote',
    '🔧' => 'chave inglesa',
    '🪛' => 'chave de fenda',
    '🔩' => 'porca e parafuso',
    '⚙' => 'engrenagem',
    '🗜' => 'braçadeira',
    '⚖' => 'balança',
    '🦯' => 'bengala para cegos',
    '🔗' => 'link',
    '⛓' => 'correntes',
    '🪝' => 'gancho',
    '🧰' => 'caixa de ferramentas',
    '🧲' => 'ímã',
    '🪜' => 'escada',
    '🪏' => 'pá',
    '⚗' => 'alambique',
    '🧪' => 'tubo de ensaio',
    '🧫' => 'placa de Petri',
    '🧬' => 'dna',
    '🔬' => 'microscópio',
    '🔭' => 'telescópio',
    '📡' => 'antena parabólica',
    '💉' => 'seringa',
    '🩸' => 'gota de sangue',
    '💊' => 'comprimido',
    '🩹' => 'atadura adesiva',
    '🩼' => 'muleta',
    '🩺' => 'estetoscópio',
    '🩻' => 'raio x',
    '🚪' => 'porta',
    '🛗' => 'elevador',
    '🪞' => 'espelho',
    '🪟' => 'janela',
    '🛏' => 'cama',
    '🛋' => 'sofá e luminária',
    '🪑' => 'cadeira',
    '🚽' => 'vaso sanitário',
    '🪠' => 'desentupidor',
    '🚿' => 'chuveiro',
    '🛁' => 'banheira',
    '🪤' => 'ratoeira',
    '🪒' => 'lâmina',
    '🧴' => 'frasco de loção',
    '🧷' => 'alfinete de segurança',
    '🧹' => 'vassoura',
    '🧺' => 'cesta',
    '🧻' => 'rolo de papel',
    '🪣' => 'balde',
    '🧼' => 'sabonete',
    '🫧' => 'bolhas',
    '🪥' => 'escova de dentes',
    '🧽' => 'esponja',
    '🧯' => 'extintor de incêndio',
    '🛒' => 'carrinho de compras',
    '🚬' => 'cigarro',
    '⚰' => 'caixão',
    '🪦' => 'lápide',
    '⚱' => 'urna funerária',
    '🧿' => 'olho grego',
    '🪬' => 'hamsá',
    '🗿' => 'moai',
    '🪧' => 'placa',
    '🪪' => 'cartão de identificação',
    '🏧' => 'símbolo de caixa automático',
    '🚮' => 'símbolo de lixeira',
    '🚰' => 'água potável',
    '♿' => 'símbolo de cadeira de rodas',
    '🚹' => 'banheiro masculino',
    '🚺' => 'banheiro feminino',
    '🚻' => 'banheiro',
    '🚼' => 'símbolo de bebê',
    '🚾' => 'WC',
    '🛂' => 'controle de passaportes',
    '🛃' => 'alfândega',
    '🛄' => 'restituição de bagagem',
    '🛅' => 'depósito de bagagem',
    '⚠' => 'aviso',
    '🚸' => 'crianças atravessando',
    '⛔' => 'entrada proibida',
    '🚫' => 'proibido',
    '🚳' => 'proibido andar de bicicleta',
    '🚭' => 'proibido fumar',
    '🚯' => 'proibido jogar lixo no chão',
    '🚱' => 'água não potável',
    '🚷' => 'proibida a passagem de pedestres',
    '📵' => 'proibido o uso de telefone celular',
    '🔞' => 'proibido para menores de 18 anos',
    '☢' => 'radioativo',
    '☣' => 'risco biológico',
    '⬆' => 'seta para cima',
    '↗' => 'seta para cima e para a direita',
    '➡' => 'seta para a direita',
    '↘' => 'seta para baixo e para a direita',
    '⬇' => 'seta para baixo',
    '↙' => 'seta para baixo e para a esquerda',
    '⬅' => 'seta para a esquerda',
    '↖' => 'seta para cima e para a esquerda',
    '↕' => 'seta para cima e para baixo',
    '↔' => 'seta para esquerda e direita',
    '↩' => 'seta curva da direita para a esquerda',
    '↪' => 'seta curva da esquerda para a direita',
    '⤴' => 'seta para a direita curvada para cima',
    '⤵' => 'seta para a direita curvada para baixo',
    '🔃' => 'setas verticais no sentido horário',
    '🔄' => 'botão de setas em sentido anti-horário',
    '🔙' => 'seta "BACK"',
    '🔚' => 'seta "END"',
    '🔛' => 'seta "ON!"',
    '🔜' => 'seta "SOON"',
    '🔝' => 'seta "TOP"',
    '🛐' => 'local de culto',
    '⚛' => 'símbolo de átomo',
    '🕉' => 'om',
    '✡' => 'estrela de Davi',
    '☸' => 'roda do Dharma',
    '☯' => 'yin yang',
    '✝' => 'cruz latina',
    '☦' => 'cruz ortodoxa',
    '☪' => 'estrela e lua crescente',
    '☮' => 'símbolo da paz',
    '🕎' => 'menorá',
    '🔯' => 'estrela de seis pontas',
    '🪯' => 'khanda',
    '♈' => 'signo de Áries',
    '♉' => 'signo de Touro',
    '♊' => 'signo de Gêmeos',
    '♋' => 'signo de Câncer',
    '♌' => 'signo de Leão',
    '♍' => 'signo de Virgem',
    '♎' => 'signo de Libra',
    '♏' => 'signo de Escorpião',
    '♐' => 'signo de Sagitário',
    '♑' => 'signo de Capricórnio',
    '♒' => 'signo de Aquário',
    '♓' => 'signo de Peixes',
    '⛎' => 'signo de Ofiúco',
    '🔀' => 'botão de músicas aleatórias',
    '🔁' => 'botão de repetir',
    '🔂' => 'botão de repetir uma única faixa',
    '▶' => 'botão reproduzir',
    '⏩' => 'botão avançar',
    '⏭' => 'botão de próxima faixa',
    '⏯' => 'botão de reproduzir ou pausar',
    '◀' => 'botão de voltar',
    '⏪' => 'botão de retroceder',
    '⏮' => 'botão de faixa anterior',
    '🔼' => 'botão apontando para cima',
    '⏫' => 'botão de avanço para cima',
    '🔽' => 'botão apontando para baixo',
    '⏬' => 'botão de avanço para baixo',
    '⏸' => 'botão pausar',
    '⏹' => 'botão parar',
    '⏺' => 'botão gravar',
    '⏏' => 'botão ejetar',
    '🎦' => 'cinema',
    '🔅' => 'botão de diminuir brilho',
    '🔆' => 'botão de aumentar brilho',
    '📶' => 'barras de sinal',
    '🛜' => 'sem fio',
    '📳' => 'modo vibratório',
    '📴' => 'telefone celular desligado',
    '♀' => 'símbolo de feminino',
    '♂' => 'símbolo de masculino',
    '⚧' => 'símbolo transgênero',
    '✖' => 'sinal de multiplicação',
    '➕' => 'símbolo de adição',
    '➖' => 'símbolo de subtração',
    '➗' => 'símbolo de divisão',
    '🟰' => 'sinal de igual',
    '♾' => 'infinito',
    '‼' => 'dupla exclamação',
    '⁉' => 'exclamação com interrogação',
    '❓' => 'ponto de interrogação vermelho',
    '❔' => 'ponto de interrogação branco',
    '❕' => 'ponto de exclamação branco',
    '❗' => 'ponto de exclamação vermelho',
    '〰' => 'travessão ondulado',
    '💱' => 'câmbio de moeda',
    '💲' => 'cifrão',
    '⚕' => 'símbolo da medicina',
    '♻' => 'símbolo de reciclagem',
    '⚜' => 'flor-de-lis',
    '🔱' => 'emblema de tridente',
    '📛' => 'crachá',
    '🔰' => 'símbolo japonês de principiante',
    '⭕' => 'círculo grande oco',
    '✅' => 'marca de seleção branca',
    '☑' => 'caixa de seleção marcada com tique',
    '✔' => 'marca de seleção',
    '❌' => 'xis',
    '❎' => 'botão de xis',
    '➰' => 'laço encaracolado',
    '➿' => 'loop encaracolado duas vezes',
    '〽' => 'sinal japonês indicando início de música',
    '✳' => 'asterisco de oito pontas',
    '✴' => 'estrela de oito pontas',
    '❇' => 'faísca',
    '™' => 'símbolo de marca registrada',
    '🫟' => 'respingo',
    '🔠' => 'letras latinas maiúsculas',
    '🔡' => 'letras latinas minúsculas',
    '🔢' => 'números',
    '🔣' => 'símbolos',
    '🔤' => 'letras latinas',
    '🅰' => 'botão A (tipo sanguíneo)',
    '🆎' => 'botão AB (tipo sanguíneo)',
    '🅱' => 'botão B (tipo sanguíneo)',
    '🆑' => 'botão CL',
    '🆒' => 'botão "COOL"',
    '🆓' => 'botão "FREE"',
    'ℹ' => 'informações',
    '🆔' => 'botão ID',
    'Ⓜ' => 'círculo com a letra M',
    '🆕' => 'botão "NEW"',
    '🆖' => 'botão NG',
    '🅾' => 'botão O (tipo sanguíneo)',
    '🆗' => 'botão OK',
    '🅿' => 'botão P',
    '🆘' => 'botão SOS',
    '🆙' => 'botão "UP!"',
    '🆚' => 'botão VS',
    '🈁' => 'botão japonês de “aqui”',
    '🈂' => 'botão japonês de “taxa de serviço”',
    '🈷' => 'botão japonês de “quantidade mensal”',
    '🈶' => 'botão japonês de “não gratuito”',
    '🈯' => 'botão japonês de “reservado”',
    '🉐' => 'botão japonês de “barganha”',
    '🈹' => 'botão japonês de “desconto”',
    '🈚' => 'botão japonês de “gratuito”',
    '🈲' => 'botão japonês de “proibido”',
    '🉑' => 'botão japonês de “aceitável”',
    '🈸' => 'botão japonês de “aplicação”',
    '🈴' => 'botão japonês de “nota mínima”',
    '🈳' => 'botão japonês de “vago”',
    '㊗' => 'botão japonês de “parabéns”',
    '㊙' => 'botão japonês de “segredo”',
    '🈺' => 'botão japonês de “aberto para negócios”',
    '🈵' => 'botão japonês de “sem vagas”',
    '🔴' => 'círculo vermelho',
    '🟠' => 'círculo laranja',
    '🟡' => 'círculo amarelo',
    '🟢' => 'círculo verde',
    '🔵' => 'círculo azul',
    '🟣' => 'círculo roxo',
    '🟤' => 'círculo marrom',
    '⚫' => 'círculo preto',
    '⚪' => 'círculo branco',
    '🟥' => 'quadrado vermelho',
    '🟧' => 'quadrado laranja',
    '🟨' => 'quadrado amarelo',
    '🟩' => 'quadrado verde',
    '🟦' => 'quadrado azul',
    '🟪' => 'quadrado roxo',
    '🟫' => 'quadrado marrom',
    '⬛' => 'quadrado preto grande',
    '⬜' => 'quadrado branco grande',
    '◼' => 'quadrado preto médio',
    '◻' => 'quadrado branco médio',
    '◾' => 'quadrado preto médio menor',
    '◽' => 'quadrado branco médio menor',
    '▪' => 'quadrado preto pequeno',
    '▫' => 'quadrado branco pequeno',
    '🔶' => 'losango laranja grande',
    '🔷' => 'losango azul grande',
    '🔸' => 'losango laranja pequeno',
    '🔹' => 'losango azul pequeno',
    '🔺' => 'triângulo vermelho para cima',
    '🔻' => 'triângulo vermelho para baixo',
    '💠' => 'diamante com um ponto',
    '🔘' => 'botão de opção',
    '🔳' => 'botão quadrado branco',
    '🔲' => 'botão quadrado preto',
    '🏁' => 'bandeira quadriculada',
    '🚩' => 'bandeira triangular',
    '🎌' => 'bandeiras cruzadas',
    '🏴' => 'bandeira preta',
    '🏳' => 'bandeira branca',
];
